Index: glib/gutils.h
===================================================================
--- glib/gutils.h	(revision 7087)
+++ glib/gutils.h	(working copy)
@@ -34,6 +34,14 @@
 #include <glib/gtypes.h>
 #include <stdarg.h>
 
+/**
+ * SECTION:misc_utils
+ * @Short_description: a selection of portable utility functions
+ * @Title: Miscellaneous Utility Functions
+ * 
+ * These are portable utility functions.
+ */
+
 G_BEGIN_DECLS
 
 #ifdef G_OS_WIN32
@@ -52,10 +60,45 @@
 
 /* Unix */
 
+/**
+ * G_DIR_SEPARATOR:
+ * 
+ * The directory separator character.
+ * This is '/' on UNIX machines and '\' under Windows.
+ */
 #define G_DIR_SEPARATOR '/'
+/**
+ * G_DIR_SEPARATOR_S:
+ * 
+ * The directory separator as a string.
+ * This is "/" on UNIX machines and "\" under Windows.
+ */
 #define G_DIR_SEPARATOR_S "/"
+
+/**
+ * G_IS_DIR_SEPARATOR:
+ * @c: a character
+ * 
+ * Checks whether a character is a directory 
+ * separator. It returns %TRUE for '/' on UNIX
+ * machines and for '\' or '/' under Windows.
+ * 
+ * Since: 2.6
+ */
 #define G_IS_DIR_SEPARATOR(c) ((c) == G_DIR_SEPARATOR)
+/**
+ * G_SEARCHPATH_SEPARATOR:
+ * 
+ * The search path separator character.
+ * This is ':' on UNIX machines and ';' under Windows.
+ */
 #define G_SEARCHPATH_SEPARATOR ':'
+/**
+ * G_SEARCHPATH_SEPARATOR_S:
+ * 
+ * The search path separator as a string.
+ * This is ":" on UNIX machines and ";" under Windows.
+ */
 #define G_SEARCHPATH_SEPARATOR_S ":"
 
 #endif /* !G_OS_WIN32 */
@@ -63,6 +106,17 @@
 /* Define G_VA_COPY() to do the right thing for copying va_list variables.
  * glibconfig.h may have already defined G_VA_COPY as va_copy or __va_copy.
  */
+/**
+ * G_VA_COPY:
+ * @ap1: the <type>va_list</type> variable to place a copy of @ap2 in.
+ * @ap2: a <type>va_list</type>.
+ * 
+ * Portable way to copy <type>va_list</type> variables.
+ * 
+ * In order to use this function, you must include <filename>string.h</filename> 
+ * yourself, because this macro may use <function>memmove()</function> and GLib 
+ * does not include <function>string.h</function> for you.
+ */
 #if !defined (G_VA_COPY)
 #  if defined (__GNUC__) && defined (__PPC__) && (defined (_CALL_SYSV) || defined (_WIN32))
 #    define G_VA_COPY(ap1, ap2)	  (*(ap1) = *(ap2))
@@ -186,6 +240,14 @@
 
 G_CONST_RETURN gchar* g_get_user_special_dir (GUserDirectory directory);
 
+/**
+ * GDebugKey:
+ * @key: the string
+ * @value: the flag
+ * 
+ * Associates a string with a bit flag.
+ * Used in g_parse_debug_string().
+ */
 typedef struct _GDebugKey	GDebugKey;
 struct _GDebugKey
 {
@@ -221,6 +283,20 @@
  * instead. Whatch out! The string returned by g_path_get_basename
  * must be g_freed, while the string returned by g_basename must not.*/
 G_CONST_RETURN gchar* g_basename           (const gchar *file_name);
+
+/**
+ * g_dirname:
+ * 
+ * This function is deprecated and will be removed in the next major
+ * release of GLib. Use g_path_get_dirname() instead.
+ * 
+ * 
+ * Gets the directory components of a file name.
+ * If the file name has no directory components "." is returned.
+ * The returned string should be freed when no longer needed.
+ * 
+ * Returns: the directory components of the file.
+ */
 #define g_dirname g_path_get_dirname
 
 #endif /* G_DISABLE_DEPRECATED */
@@ -261,6 +337,12 @@
  * not defined, but use is actually abandoned. people should
  * use g_atexit() instead.
  */
+/**
+ * GVoidFunc:
+ * 
+ * Declares a type of function which takes no arguments and has no return value.
+ * It is used to specify the type function passed to g_atexit().
+ */
 typedef	void		(*GVoidFunc)		(void);
 #ifndef ATEXIT
 # define ATEXIT(proc)	g_ATEXIT(proc)
@@ -314,6 +396,18 @@
 /* inline function implementations
  */
 #if defined (G_CAN_INLINE) || defined (__G_UTILS_C__)
+/**
+ * g_bit_nth_lsf:
+ * @mask: a #gulong containing flags.
+ * @nth_bit: the index of the bit to start the search from.
+ * 
+ * Find the position of the first bit set in @mask, searching from (but not
+ * including) @nth_bit upwards. Bits are numbered from 0 (least significant)
+ * to sizeof(#gulong) * 8 - 1 (31 or 63, usually). To start searching from the
+ * 0th bit, set @nth_bit to -1.
+ * 
+ * Returns: the index of the first bit set which is higher than @nth_bit.
+ */
 G_INLINE_FUNC gint
 g_bit_nth_lsf (gulong mask,
 	       gint   nth_bit)
@@ -328,6 +422,19 @@
     }
   return -1;
 }
+
+/**
+ * g_bit_nth_msf:
+ * @mask: a #gulong containing flags.
+ * @nth_bit: the index of the bit to start the search from.
+ * 
+ * Find the position of the first bit set in @mask, searching from (but not
+ * including) @nth_bit downwards. Bits are numbered from 0 (least significant)
+ * to sizeof(#gulong) * 8 - 1 (31 or 63, usually). To start searching from the
+ * last bit, set @nth_bit to -1 or GLIB_SIZEOF_LONG * 8.
+ * 
+ * Returns: the index of the first bit set which is lower than @nth_bit.
+ */
 G_INLINE_FUNC gint
 g_bit_nth_msf (gulong mask,
 	       gint   nth_bit)
@@ -342,6 +449,16 @@
     }
   return -1;
 }
+
+/**
+ * g_bit_storage:
+ * @number: a guint.
+ * 
+ * Gets the number of bits used to hold @number,
+ * e.g. if @number is 4, 3 bits are needed.
+ * 
+ * Returns: the number of bits used to hold @number.
+ */
 G_INLINE_FUNC guint
 g_bit_storage (gulong number)
 {
Index: glib/gmessages.c
===================================================================
--- glib/gmessages.c	(revision 7087)
+++ glib/gmessages.c	(working copy)
@@ -56,6 +56,19 @@
 #  undef STRICT
 #endif
 
+/**
+ * SECTION:messages
+ * @Short_description: versatile support for logging messages with different levels of importance
+ * @Title: Message Logging
+ * 
+ * These functions provide support for logging error messages or messages 
+ * used for debugging. 
+ * 
+ * 
+ * There are several built-in levels of messages, defined in #GLogLevelFlags.
+ * These can be extended with user-defined levels.
+ */
+
 /* --- structures --- */
 typedef struct _GLogDomain	GLogDomain;
 typedef struct _GLogHandler	GLogHandler;
@@ -243,6 +256,23 @@
   return default_log_func;
 }
 
+/**
+ * g_log_set_always_fatal:
+ * @fatal_mask: the mask containing bits set for each level of error which is
+ *  to be fatal.
+ * 
+ * Sets the message levels which are always fatal, in any log domain.
+ * When a message with any of these levels is logged the program terminates.
+ * You can only set the levels defined by GLib to be fatal.
+ * %G_LOG_LEVEL_ERROR is always fatal.
+ * 
+ * 
+ * You can also make some message levels
+ * fatal at runtime by setting the %G_DEBUG environment variable (see
+ * <ulink url="glib-running.html">Running GLib Applications</ulink>).
+ * 
+ * Returns: the old fatal mask.
+ */
 GLogLevelFlags
 g_log_set_always_fatal (GLogLevelFlags fatal_mask)
 {
@@ -265,6 +295,16 @@
   return old_mask;
 }
 
+/**
+ * g_log_set_fatal_mask:
+ * @log_domain: the log domain.
+ * @fatal_mask: the new fatal mask.
+ * 
+ * Sets the log levels which are fatal in the given domain.
+ * %G_LOG_LEVEL_ERROR is always fatal.
+ * 
+ * Returns: the old fatal mask for the log domain.
+ */
 GLogLevelFlags
 g_log_set_fatal_mask (const gchar   *log_domain,
 		      GLogLevelFlags fatal_mask)
@@ -295,6 +335,53 @@
   return old_flags;
 }
 
+/**
+ * g_log_set_handler:
+ * @log_domain: the log domain, or %NULL for the default "" application domain.
+ * @log_levels: the log levels to apply the log handler for. To handle fatal
+ *  and recursive messages as well, combine the log levels with the
+ *  #G_LOG_FLAG_FATAL and #G_LOG_FLAG_RECURSION bit flags.
+ * @log_func: the log handler function.
+ * @user_data: data passed to the log handler.
+ * 
+ * Sets the log handler for a domain and a set of log levels.
+ * To handle fatal and recursive messages the @log_levels parameter
+ * must be combined with the #G_LOG_FLAG_FATAL and #G_LOG_FLAG_RECURSION 
+ * bit flags.
+ * 
+ * Note that since the #G_LOG_LEVEL_ERROR log level is always fatal, if 
+ * you want to set a handler for this log level you must combine it with 
+ * #G_LOG_FLAG_FATAL.
+ * 
+ * 
+ * <example>
+ * <title>Adding a log handler for all warning messages in the default 
+ * (application) domain</title>
+ * <programlisting>
+ *   g_log_set_handler (NULL, G_LOG_LEVEL_WARNING | G_LOG_FLAG_FATAL
+ *                      | G_LOG_FLAG_RECURSION, my_log_handler, NULL);
+ * </programlisting>
+ * </example>
+ * 
+ * <example>
+ * <title>Adding a log handler for all critical messages from GTK+</title>
+ * <programlisting>
+ *   g_log_set_handler ("Gtk", G_LOG_LEVEL_CRITICAL | G_LOG_FLAG_FATAL
+ *                      | G_LOG_FLAG_RECURSION, my_log_handler, NULL);
+ * </programlisting>
+ * </example>
+ * 
+ * <example>
+ * <title>Adding a log handler for <emphasis>all</emphasis> messages from 
+ * GLib</title>
+ * <programlisting>
+ *   g_log_set_handler ("GLib", G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL
+ *                      | G_LOG_FLAG_RECURSION, my_log_handler, NULL);
+ * </programlisting>
+ * </example>
+ * 
+ * Returns: the id of the new handler.
+ */
 guint
 g_log_set_handler (const gchar	 *log_domain,
 		   GLogLevelFlags log_levels,
@@ -331,6 +418,19 @@
   return handler_id;
 }
 
+/**
+ * g_log_set_default_handler:
+ * @log_func: the log handler function.
+ * @user_data: data passed to the log handler.
+ * 
+ * Installs a default log handler which is used if no 
+ * log handler has been set for the particular log domain
+ * and log level combination. By default, GLib uses 
+ * g_log_default_handler() as default log handler.
+ * 
+ * Since: 2.6
+ * Returns: the previous default log handler
+ */
 GLogFunc
 g_log_set_default_handler (GLogFunc log_func,
 			   gpointer user_data)
@@ -346,6 +446,13 @@
   return old_log_func;
 }
 
+/**
+ * g_log_remove_handler:
+ * @log_domain: the log domain.
+ * @handler_id: the id of the handler, which was returned in g_log_set_handler().
+ * 
+ * Removes the log handler.
+ */
 void
 g_log_remove_handler (const gchar *log_domain,
 		      guint	   handler_id)
@@ -387,6 +494,18 @@
 	     G_STRLOC, handler_id, log_domain);
 }
 
+/**
+ * g_logv:
+ * @log_domain: the log domain.
+ * @log_level: the log level.
+ * @format: the message format. See the printf()
+ *  documentation.
+ * @args: the parameters to insert into the format string.
+ * 
+ * Logs an error or debugging message.
+ * If the log level has been set as fatal, the abort()
+ * function is called to terminate the program.
+ */
 void
 g_logv (const gchar   *log_domain,
 	GLogLevelFlags log_level,
@@ -505,6 +624,18 @@
     }
 }
 
+/**
+ * g_log:
+ * @log_domain: the log domain, usually #G_LOG_DOMAIN.
+ * @log_level: the log level, either from #GLogLevelFlags or a user-defined level.
+ * @format: the message format. See the printf()
+ *  documentation.
+ * @...: the parameters to insert into the format string.
+ * 
+ * Logs an error or debugging message.
+ * If the log level has been set as fatal, the abort()
+ * function is called to terminate the program.
+ */
 void
 g_log (const gchar   *log_domain,
        GLogLevelFlags log_level,
@@ -873,6 +1004,22 @@
     }
 }
 
+/**
+ * g_log_default_handler:
+ * @log_domain: the log domain of the message.
+ * @log_level: the level of the message.
+ * @message: the message.
+ * @unused_data: data passed from g_log() which is unused.
+ * 
+ * The default log handler set up by GLib; g_log_set_default_handler() 
+ * allows to install an alternate default log handler.
+ * This is used if no log handler has been set for the particular log domain
+ * and log level combination. It outputs the message to stderr or stdout
+ * and if the log level is fatal it calls abort().
+ * 
+ * stderr is used for levels %G_LOG_LEVEL_ERROR, %G_LOG_LEVEL_CRITICAL,
+ * %G_LOG_LEVEL_WARNING and %G_LOG_LEVEL_MESSAGE. stdout is used for the rest.
+ */
 void
 g_log_default_handler (const gchar   *log_domain,
 		       GLogLevelFlags log_level,
Index: glib/gatomic.c
===================================================================
--- glib/gatomic.c	(revision 7087)
+++ glib/gatomic.c	(working copy)
@@ -31,10 +31,76 @@
 #include "gthreadprivate.h"
 #include "galias.h"
 
+/**
+ * SECTION:atomic_operations
+ * @Short_description: basic atomic integer and pointer operations
+ * @Title: Atomic Operations
+ * @See_also:<variablelist>
+ *  
+ * <varlistentry>
+ * <term>#GMutex</term>
+ * <listitem><para>GLib mutual exclusions.</para></listitem>
+ * </varlistentry>
+ *  
+ * </variablelist>
+ * 
+ * The following functions can be used to atomically access integers and
+ * pointers. They are implemented as inline assembler function on most
+ * platforms and use slower fall-backs otherwise. Using them can sometimes
+ * save you from using a performance-expensive #GMutex to protect the
+ * integer or pointer.  
+ * 
+ * 
+ * The most important usage is reference counting. Using
+ * g_atomic_int_inc() and g_atomic_int_dec_and_test() makes reference
+ * counting a very fast operation.
+ * 
+ * 
+ * <note>
+ * You must not directly read integers or pointers concurrently accessed
+ * by multiple threads, but use the atomic accessor functions instead.
+ * That is, always use g_atomic_int_get() and g_atomic_pointer_get() for
+ * read outs.
+ * They provide the neccessary synchonization mechanisms like memory
+ * barriers to access memory locations concurrently.
+ * 
+ * </note>
+ * 
+ * <note>
+ * If you are using those functions for anything apart from simple
+ * reference counting, you should really be aware of the implications of
+ * doing that. There are literally thousands of ways to shoot yourself in
+ * the foot. So if in doubt, use a #GMutex. If you don't know, what
+ * memory barriers are, do not use anything but g_atomic_int_inc() and
+ * g_atomic_int_dec_and_test().
+ * 
+ * </note>
+ * 
+ * <note>
+ * It is not safe to set an integer or pointer just by assigning to it,
+ * when it is concurrently accessed by other threads with the following
+ * functions. Use g_atomic_int_compare_and_exchange() or
+ * g_atomic_pointer_compare_and_exchange() respectively.
+ * 
+ * </note>
+ */
+
 #if defined (__GNUC__)
 # if defined (G_ATOMIC_I486)
 /* Adapted from CVS version 1.10 of glibc's sysdeps/i386/i486/bits/atomic.h 
  */
+/**
+ * g_atomic_int_exchange_and_add:
+ * @atomic: a pointer to an integer.
+ * @val: the value to add to *@atomic.
+ * 
+ * Atomically adds @val to the integer pointed to by @atomic. It returns
+ * the value of *@atomic just before the addition took place.
+ * Also acts as a memory barrier.
+ * 
+ * Since: 2.4
+ * Returns: the value of *@atomic before the addition.
+ */
 gint
 g_atomic_int_exchange_and_add (volatile gint *atomic, 
 			       gint           val)
@@ -56,6 +122,19 @@
 			: "ir" (val), "m" (*atomic));
 }
 
+/**
+ * g_atomic_int_compare_and_exchange:
+ * @atomic: a pointer to an integer.
+ * @oldval: the assumed old value of *@atomic.
+ * @newval: the new value of *@atomic.
+ * 
+ * Compares @oldval with the integer pointed to by @atomic and
+ * if they are equal, atomically exchanges *@atomic with @newval.
+ * Also acts as a memory barrier.
+ * 
+ * Since: 2.4
+ * Returns: %TRUE, if *@atomic was equal @oldval. %FALSE otherwise.
+ */
 gboolean
 g_atomic_int_compare_and_exchange (volatile gint *atomic, 
 				   gint           oldval, 
@@ -73,7 +152,19 @@
 /* The same code as above, as on i386 gpointer is 32 bit as well.
  * Duplicating the code here seems more natural than casting the
  * arguments and calling the former function */
-
+/**
+ * g_atomic_pointer_compare_and_exchange:
+ * @atomic: a pointer to a #gpointer.
+ * @oldval: the assumed old value of *@atomic.
+ * @newval: the new value of *@atomic.
+ * 
+ * Compares @oldval with the pointer pointed to by @atomic and
+ * if they are equal, atomically exchanges *@atomic with @newval. 
+ * Also acts as a memory barrier.
+ * 
+ * Since: 2.4
+ * Returns: %TRUE, if *@atomic was equal @oldval. %FALSE otherwise.
+ */
 gboolean
 g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic, 
 				       gpointer           oldval, 
@@ -790,6 +881,17 @@
 }
 
 #ifdef G_ATOMIC_OP_MEMORY_BARRIER_NEEDED
+
+/**
+ * g_atomic_int_get:
+ * @atomic: a pointer to an integer
+ * 
+ * Reads the value of the integer pointed to by @atomic. Also acts as
+ * a memory barrier.
+ * 
+ * Since: 2.4
+ * Returns: the value of *@atomic
+ */
 gint
 g_atomic_int_get (volatile gint *atomic)
 {
@@ -802,6 +904,16 @@
   return result;
 }
 
+/**
+ * g_atomic_int_set:
+ * @atomic: a pointer to an integer
+ * @newval: the new value
+ * 
+ * Sets the value of the integer pointed to by @atomic. 
+ * Also acts as a memory barrier.
+ * 
+ * Since: 2.10
+ */
 void
 g_atomic_int_set (volatile gint *atomic,
                   gint           newval)
@@ -811,6 +923,16 @@
   g_mutex_unlock (g_atomic_mutex);
 }
 
+/**
+ * g_atomic_pointer_get:
+ * @atomic: a pointer to a #gpointer.
+ * 
+ * Reads the value of the pointer pointed to by @atomic. Also acts as
+ * a memory barrier.
+ * 
+ * Since: 2.4
+ * Returns: the value to add to *@atomic.
+ */
 gpointer
 g_atomic_pointer_get (volatile gpointer *atomic)
 {
@@ -823,6 +945,16 @@
   return result;
 }
 
+/**
+ * g_atomic_pointer_set:
+ * @atomic: a pointer to a #gpointer
+ * @newval: the new value
+ * 
+ * Sets the value of the pointer pointed to by @atomic. 
+ * Also acts as a memory barrier.
+ * 
+ * Since: 2.10
+ */
 void
 g_atomic_pointer_set (volatile gpointer *atomic,
                       gpointer           newval)
@@ -885,6 +1017,16 @@
   return result;
 }
  
+/**
+ * g_atomic_int_add:
+ * @atomic: a pointer to an integer.
+ * @val: the value to add to *@atomic.
+ * 
+ * Atomically adds @val to the integer pointed to by @atomic.
+ * Also acts as a memory barrier.
+ * 
+ * Since: 2.4
+ */
 void
 g_atomic_int_add (volatile gint *atomic,
 		  gint           val)
Index: glib/gmessages.h
===================================================================
--- glib/gmessages.h	(revision 7087)
+++ glib/gmessages.h	(working copy)
@@ -48,12 +48,31 @@
 gsize	g_printf_string_upper_bound (const gchar* format,
 				     va_list	  args);
 
-/* Log level shift offset for user defined
- * log levels (0-7 are used by GLib).
+/**
+ * G_LOG_LEVEL_USER_SHIFT:
+ * 
+ * Log level shift offset for user defined log levels (0-7 are used by GLib).
  */
 #define G_LOG_LEVEL_USER_SHIFT  (8)
 
-/* Glib log levels and flags.
+/**
+ * GLogLevelFlags:
+ * @G_LOG_FLAG_RECURSION: internal flag
+ * @G_LOG_FLAG_FATAL: internal flag
+ * @G_LOG_LEVEL_ERROR: log level for errors, see g_error(). 
+ *  This level is also used for messages produced by g_assert().
+ * @G_LOG_LEVEL_CRITICAL: log level for critical messages, see g_critical().
+ *  This level is also used for messages produced by g_return_if_fail() and 
+ *  g_return_val_if_fail().
+ * @G_LOG_LEVEL_WARNING: log level for warnings, see g_warning()
+ * @G_LOG_LEVEL_MESSAGE: log level for messages, see g_message()
+ * @G_LOG_LEVEL_INFO: log level for informational messages
+ * @G_LOG_LEVEL_DEBUG: log level for debug messages, see g_debug()
+ * @G_LOG_LEVEL_MASK: a mask including all log levels.
+ * 
+ * Flags specifying the level of log messages. It is possible to change
+ * how GLib treats messages of the various levels using g_log_set_handler()
+ * and g_log_set_fatal_mask().
  */
 typedef enum
 {
@@ -72,9 +91,23 @@
   G_LOG_LEVEL_MASK              = ~(G_LOG_FLAG_RECURSION | G_LOG_FLAG_FATAL)
 } GLogLevelFlags;
 
-/* GLib log levels that are considered fatal by default */
+/**
+ * G_LOG_FATAL_MASK:
+ * 
+ * GLib log levels that are considered fatal by default.
+ */
 #define G_LOG_FATAL_MASK        (G_LOG_FLAG_RECURSION | G_LOG_LEVEL_ERROR)
 
+/**
+ * GLogFunc:
+ * @log_domain: the log domain of the message.
+ * @log_level: the log level of the message (including the fatal and recursion
+ *  flags).
+ * @message: the message to process.
+ * @user_data: user data, set in g_log_set_handler().
+ * 
+ * Specifies the prototype of log handler functions.
+ */
 typedef void            (*GLogFunc)             (const gchar   *log_domain,
                                                  GLogLevelFlags log_level,
                                                  const gchar   *message,
@@ -129,7 +162,21 @@
 		               const char *expression) G_GNUC_NORETURN;
 #endif /* !G_DISABLE_DEPRECATED */
 
-
+/**
+ * G_LOG_DOMAIN:
+ * 
+ * Defines the log domain.
+ * For applications, this is typically left as the default %NULL (or "") domain.
+ * Libraries should define this so that any messages which they log can
+ * be differentiated from messages from other libraries and application code.
+ * But be careful not to define it in any public header files.
+ * 
+ * For example, GTK+ uses this in its Makefile.am:
+ * 
+ * <informalexample><programlisting>
+ * INCLUDES = -DG_LOG_DOMAIN=\"Gtk\"
+ * </programlisting></informalexample>
+ */
 #ifndef G_LOG_DOMAIN
 #define G_LOG_DOMAIN    ((gchar*) 0)
 #endif  /* G_LOG_DOMAIN */
@@ -175,6 +222,18 @@
                                        G_LOG_LEVEL_DEBUG,    \
                                        format)
 #else   /* no varargs macros */
+
+/**
+ * g_error:
+ * @...: format string, followed by parameters to insert into the format string (as with printf())
+ * 
+ * A convenience function/macro to log an error message.
+ * Error messages are always fatal, resulting in a call to
+ * abort() to terminate the application.
+ * This function will result in a core dump; don't use it for errors you
+ * expect. Using this function indicates a bug in your program, i.e. an
+ * assertion failure.
+ */
 static void
 g_error (const gchar *format,
          ...)
@@ -186,6 +245,13 @@
 
   for(;;);
 }
+
+/**
+ * g_message:
+ * @...: format string, followed by parameters to insert into the format string (as with printf())
+ * 
+ * A convenience function/macro to log a normal message.
+ */
 static void
 g_message (const gchar *format,
            ...)
@@ -195,6 +261,21 @@
   g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, format, args);
   va_end (args);
 }
+
+/**
+ * g_critical:
+ * @...: format string, followed by parameters to insert into the format string (as with printf())
+ * 
+ * Logs a "critical warning" (#G_LOG_LEVEL_CRITICAL). It's more or less
+ * application-defined what constitutes a critical vs. a regular
+ * warning. You could call g_log_set_always_fatal() to make critical
+ * warnings exit the program, then use g_critical() for fatal errors, for
+ * example.
+ * 
+ * You can also make critical warnings fatal at runtime by setting
+ * the %G_DEBUG environment variable (see
+ * <ulink url="glib-running.html">Running GLib Applications</ulink>).
+ */
 static void
 g_critical (const gchar *format,
             ...)
@@ -204,6 +285,16 @@
   g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, format, args);
   va_end (args);
 }
+
+/**
+ * g_warning:
+ * @...: format string, followed by parameters to insert into the format string (as with printf())
+ * 
+ * A convenience function/macro to log a warning message.
+ * 
+ * You can make warnings fatal at runtime by setting the %G_DEBUG environment
+ * variable (see <ulink url="glib-running.html">Running GLib Applications</ulink>).
+ */
 static void
 g_warning (const gchar *format,
            ...)
@@ -213,6 +304,15 @@
   g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING, format, args);
   va_end (args);
 }
+
+/**
+ * g_debug:
+ * @...: format string, followed by parameters to insert into the format string (as with printf())
+ * 
+ * A convenience function/macro to log a debug message.
+ * 
+ * Since: 2.6
+ */
 static void
 g_debug (const gchar *format,
          ...)
Index: glib/gatomic.h
===================================================================
--- glib/gatomic.h	(revision 7087)
+++ glib/gatomic.h	(working copy)
@@ -63,7 +63,26 @@
 # define g_atomic_pointer_set(atomic, newval)	((void) (*(atomic) = (newval)))
 #endif /* G_ATOMIC_OP_MEMORY_BARRIER_NEEDED */
 
+/**
+ * g_atomic_int_inc:
+ * @atomic: a pointer to an integer.
+ * 
+ * Atomically increments the integer pointed to by @atomic by 1.
+ * 
+ * Since: 2.4
+ */
 #define g_atomic_int_inc(atomic) (g_atomic_int_add ((atomic), 1))
+
+/**
+ * g_atomic_int_dec_and_test:
+ * @atomic: a pointer to an integer.
+ * 
+ * Atomically decrements the integer pointed to by @atomic by 1.
+ * 
+ * Since: 2.4
+ * Returns: %TRUE, if the integer pointed to by @atomic is 0 after
+ *  decrementing it.
+ */
 #define g_atomic_int_dec_and_test(atomic)				\
   (g_atomic_int_exchange_and_add ((atomic), -1) == 1)
 
Index: glib/gerror.c
===================================================================
--- glib/gerror.c	(revision 7087)
+++ glib/gerror.c	(working copy)
@@ -29,7 +29,354 @@
 #include "glib.h"
 #include "galias.h"
 
+/**
+ * SECTION:error_reporting
+ * @Short_description: a system for reporting errors
+ * @Title: Error Reporting
+ * 
+ * 
+ * GLib provides a standard method of reporting errors from a called function to
+ * the calling code. (This is the same problem solved by exceptions in other
+ * languages.) It's important to understand that this method is both a
+ * <emphasis>data type</emphasis> (the #GError object) and a <emphasis>set of
+ * rules.</emphasis> If you use #GError incorrectly, then your code will not
+ * properly interoperate with other code that uses #GError, and users of your API
+ * will probably get confused.
+ * 
+ * 
+ * First and foremost: <emphasis>#GError should only be used to report
+ * recoverable runtime errors, never to report programming errors.</emphasis> If
+ * the programmer has screwed up, then you should use g_warning(),
+ * g_return_if_fail(), g_assert(), g_error(), or some similar facility.
+ * (Incidentally, remember that the g_error() function should
+ * <emphasis>only</emphasis> be used for programming errors, it should not be used
+ * to print any error reportable via #GError.)
+ * 
+ * 
+ * Examples of recoverable runtime errors are "file not found" or "failed to parse
+ * input." Examples of programming errors are "NULL passed to strcmp()" or
+ * "attempted to free the same pointer twice." These two kinds of errors are
+ * fundamentally different: runtime errors should be handled or reported to the
+ * user, programming errors should be eliminated by fixing the bug in the program.
+ * This is why most functions in GLib and GTK+ do not use the #GError facility.
+ * 
+ * 
+ * Functions that can fail take a return location for a #GError as their last argument. 
+ * For example:
+ * <informalexample><programlisting>
+ * gboolean g_file_get_contents (const gchar *filename, 
+ * 	                      gchar      **contents,
+ *                               gsize       *length,
+ *                               GError     **error);
+ * </programlisting></informalexample>
+ * If you pass a non-%NULL value for the <literal>error</literal> argument, it should 
+ * point to a location where an error can be placed. For example:
+ * <informalexample><programlisting>
+ * gchar *contents;
+ * GError *err = NULL;
+ * g_file_get_contents ("foo.txt", &contents, NULL, &err);
+ * g_assert ((contents == NULL && err != NULL) || (contents != NULL && err == NULL));
+ * if (err != NULL)
+ *   {
+ *     // Report error to user, and free error
+ *     g_assert (contents == NULL);
+ *     fprintf (stderr, "Unable to read file: &percnt;s\n", err->message);
+ *     g_error_free (err);
+ *   } 
+ * else
+ *   {
+ *     // Use file contents
+ *     g_assert (contents != NULL);
+ *   }
+ * </programlisting></informalexample>
+ * Note that <literal>err != NULL</literal> in this example is a
+ * <emphasis>reliable</emphasis> indicator of whether
+ * g_file_get_contents() failed. Additionally, g_file_get_contents() returns
+ * a boolean which indicates whether it was successful.
+ * 
+ * 
+ * Because g_file_get_contents() returns %FALSE on failure, if you are only
+ * interested in whether it failed and don't need to display an error message, you
+ * can pass %NULL for the <literal>error</literal> argument:
+ * <informalexample><programlisting>
+ * if (g_file_get_contents ("foo.txt", &contents, NULL, NULL)) // ignore errors
+ *   // no error occurred ;
+ * else
+ *   // error ;
+ * </programlisting></informalexample>
+ * 
+ * 
+ * The #GError object contains three fields: <literal>domain</literal> indicates
+ * the module the error-reporting function is located in, <literal>code</literal>
+ * indicates the specific error that occurred, and <literal>message</literal> is a
+ * user-readable error message with as many details as possible. Several functions
+ * are provided to deal with an error received from a called function:
+ * g_error_matches() returns %TRUE if the error matches a given domain and code,
+ * g_propagate_error() copies an error into an error location (so the calling
+ * function will receive it), and g_clear_error() clears an error location by
+ * freeing the error and resetting the location to %NULL. To display an error to the
+ * user, simply display <literal>error->message</literal>, perhaps along with
+ * additional context known only to the calling function (the file being opened, or
+ * whatever -- though in the g_file_get_contents() case,
+ * <literal>error->message</literal> already contains a filename).
+ * 
+ * 
+ * When implementing a function that can report errors, the basic tool is
+ * g_set_error(). Typically, if a fatal error occurs you want to g_set_error(),
+ * then return immediately. g_set_error() does nothing if the error location passed
+ * to it is %NULL. Here's an example:
+ * <informalexample><programlisting>
+ * gint
+ * foo_open_file (GError **error)
+ * {
+ *   gint fd;
+ * 
+ *   fd = open ("file.txt", O_RDONLY);
+ * 
+ *   if (fd < 0)
+ *     {
+ *       g_set_error (error,
+ *                    FOO_ERROR,                 // error domain
+ *                    FOO_ERROR_BLAH,            // error code
+ *                    "Failed to open file: &percnt;s", // error message format string
+ *                    g_strerror (errno));
+ *       return -1;
+ *     }
+ *   else
+ *     return fd;
+ * }
+ * </programlisting></informalexample>
+ * 
+ * 
+ * Things are somewhat more complicated if you yourself call another function that
+ * can report a #GError. If the sub-function indicates fatal errors in some way
+ * other than reporting a #GError, such as by returning %TRUE on success, you can
+ * simply do the following:
+ * <informalexample><programlisting>
+ * gboolean
+ * my_function_that_can_fail (GError **err)
+ * {
+ *   g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+ * 
+ *   if (!sub_function_that_can_fail (err))
+ *     {
+ *        // assert that error was set by the sub-function
+ *        g_assert (err == NULL || *err != NULL);  
+ *        return FALSE;
+ *     }
+ * 
+ *   // otherwise continue, no error occurred
+ *   g_assert (err == NULL || *err == NULL);
+ * }
+ * </programlisting></informalexample>
+ * 
+ * 
+ * If the sub-function does not indicate errors other than by reporting a #GError, 
+ * you need to create a temporary #GError since the passed-in one may be %NULL.
+ * g_propagate_error() is intended for use in this case.
+ * <informalexample><programlisting>
+ * gboolean
+ * my_function_that_can_fail (GError **err)
+ * {
+ *   GError *tmp_error;
+ * 
+ *   g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+ * 
+ *   tmp_error = NULL;
+ *   sub_function_that_can_fail (&tmp_error);
+ * 
+ *   if (tmp_error != NULL)
+ *     {
+ *        /<!-- -->* store tmp_error in err, if err != NULL,
+ *         * otherwise call g_error_free(<!-- -->) on tmp_error 
+ *         *<!-- -->/
+ *        g_propagate_error (err, tmp_error);
+ *        return FALSE;
+ *     }
+ * 
+ *   // otherwise continue, no error occurred
+ * }
+ * </programlisting></informalexample>
+ * 
+ * 
+ * Error pileups are always a bug. For example, this code is incorrect:
+ * <informalexample><programlisting>
+ * gboolean
+ * my_function_that_can_fail (GError **err)
+ * {
+ *   GError *tmp_error;
+ * 
+ *   g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+ * 
+ *   tmp_error = NULL;
+ *   sub_function_that_can_fail (&tmp_error);
+ *   other_function_that_can_fail (&tmp_error);
+ * 
+ *   if (tmp_error != NULL)
+ *     {
+ *        g_propagate_error (err, tmp_error);
+ *        return FALSE;
+ *     }
+ * }
+ * </programlisting></informalexample>
+ * <literal>tmp_error</literal> should be checked immediately after
+ * <function>sub_function_that_can_fail()</function>, and either cleared or propagated upward.  The rule
+ * is: <emphasis>after each error, you must either handle the error, or return it to the
+ * calling function</emphasis>.  Note that passing %NULL for the error location is the
+ * equivalent of handling an error by always doing nothing about it. So the
+ * following code is fine, assuming errors in <function>sub_function_that_can_fail()</function> are not
+ * fatal to <function>my_function_that_can_fail()</function>:
+ * <informalexample><programlisting>
+ * gboolean
+ * my_function_that_can_fail (GError **err)
+ * {
+ *   GError *tmp_error;
+ * 
+ *   g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+ * 
+ *   sub_function_that_can_fail (NULL); // ignore errors
+ * 
+ *   tmp_error = NULL;
+ *   other_function_that_can_fail (&tmp_error);
+ * 
+ *   if (tmp_error != NULL)
+ *     {
+ *        g_propagate_error (err, tmp_error);
+ *        return FALSE;
+ *     }
+ * }
+ * </programlisting></informalexample>
+ * 
+ * 
+ * Note that passing %NULL for the error location <emphasis>ignores</emphasis>
+ * errors; it's equivalent to <literal>try { sub_function_that_can_fail (); } catch
+ * (...) {}</literal> in C++. It does <emphasis>not</emphasis> mean to leave errors
+ * unhandled; it means to handle them by doing nothing.
+ * 
+ * 
+ * Error domains and codes are conventionally named as follows:
+ * <itemizedlist>
+ * <listitem>
+ * The error domain is called 
+ * <literal><NAMESPACE>_<MODULE>_ERROR</literal>, for example
+ * %G_SPAWN_ERROR or %G_THREAD_ERROR:
+ * <informalexample><programlisting>
+ * #define G_SPAWN_ERROR g_spawn_error_quark (<!-- -->)
+ * 
+ * GQuark
+ * g_spawn_error_quark (void)
+ * {
+ *   return g_quark_from_static_string ("g-spawn-error-quark");
+ * }
+ * </programlisting></informalexample>
+ * 
+ * </listitem>
+ * <listitem>
+ * The error codes are in an enumeration called 
+ * <literal><Namespace><Module>Error</literal>; for example,
+ * #GThreadError or #GSpawnError.
+ * 
+ * </listitem>
+ * <listitem>
+ * Members of the error code enumeration are called <literal><NAMESPACE>_<MODULE>_ERROR_<CODE></literal>, for example %G_SPAWN_ERROR_FORK or %G_THREAD_ERROR_AGAIN. 
+ * 
+ * </listitem>
+ * <listitem>
+ * If there's a "generic" or "unknown" error code for unrecoverable errors it
+ * doesn't make sense to distinguish with specific codes, it should be called 
+ * <literal><NAMESPACE>_<MODULE>_ERROR_FAILED</literal>, for 
+ * example %G_SPAWN_ERROR_FAILED or %G_THREAD_ERROR_FAILED.
+ * 
+ * </listitem>
+ * </itemizedlist>
+ * 
+ * 
+ * Summary of rules for use of #GError:
+ *       <itemizedlist>
+ * 	<listitem>
+ *            Do not report programming errors via #GError.
+ * 
+ * 	</listitem>
+ * 
+ *       <listitem>
+ *           The last argument of a function that returns an error should be a
+ *           location where a #GError can be placed (i.e. "#GError** error").  If
+ *           #GError is used with varargs, the #GError** should be the last
+ *           argument before the "...".
+ * 
+ *       </listitem>
+ * 
+ *       <listitem>
+ *           The caller may pass %NULL for the #GError** if they are not interested
+ *           in details of the exact error that occurred.
+ * 
+ *       </listitem>
+ * 
+ * 	<listitem>
+ *            If %NULL is passed for the #GError** argument, then errors should 
+ *            not be returned to the caller, but your function should still 
+ *            abort and return if an error occurs. That is, control flow should
+ *            not be affected by whether the caller wants to get a #GError.
+ * 
+ * 	</listitem>
+ * 
+ *       <listitem>
+ *           If a #GError is reported, then your function by definition  
+ *           <emphasis>had a fatal failure and did not complete whatever it was supposed
+ *             to do</emphasis>. If the failure was not fatal, then you handled it
+ *           and you should not report it. If it was fatal, then you must report it 
+ *           and discontinue whatever you were doing immediately.
+ * 
+ *       </listitem>
+ * 
+ * 	<listitem>
+ *           A #GError* must be initialized to %NULL before passing its address to
+ *           a function that can report errors.
+ * 
+ * 	</listitem>
+ * 
+ * 	<listitem>
+ *           "Piling up" errors is always a bug. That is, if you assign a new
+ *           #GError to a #GError* that is non-%NULL, thus overwriting the previous
+ *           error, it indicates that you should have aborted the operation instead
+ *           of continuing. If you were able to continue, you should have cleared
+ *           the previous error with g_clear_error(). g_set_error() will complain
+ *           if you pile up errors.
+ * 
+ * 	</listitem>
+ * 
+ * 
+ * 	<listitem>
+ *           By convention, if you return a boolean value indicating success 
+ *           then %TRUE means success and %FALSE means failure. If %FALSE is returned,
+ *           the error <emphasis>must</emphasis> be set to a non-%NULL value. 
+ * 
+ * 	</listitem>
+ * 
+ * 
+ * 	<listitem>
+ *           A %NULL return value is also frequently used to mean that an error
+ *           occurred.  You should make clear in your documentation whether %NULL is
+ *           a valid return value in non-error cases; if %NULL is a valid value,
+ *           then users must check whether an error was returned to see if the
+ *           function succeeded.
+ * 
+ * 	</listitem>
+ * 
+ * 	<listitem>
+ *           When implementing a function that can report errors, you may want to
+ *           add a check at the top of your function that the error return location
+ *           is either %NULL or contains a %NULL error
+ *           (e.g. <literal>g_return_if_fail (error == NULL || *error ==
+ *           NULL);</literal>).
+ * 
+ * 	</listitem>
+ * 
+ * 
+ * </itemizedlist>
+ */
 
+
 static GError* 
 g_error_new_valist (GQuark         domain,
                     gint           code,
Index: glib/gerror.h
===================================================================
--- glib/gerror.h	(revision 7087)
+++ glib/gerror.h	(working copy)
@@ -29,6 +29,15 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GError:
+ * @domain: error domain, e.g. #G_FILE_ERROR.
+ * @code: error code, e.g. %G_FILE_ERROR_NOENT.
+ * @message: human-readable informative error message.
+ * 
+ * The <structname>GError</structname> structure contains 
+ * information about an error that has occurred.
+ */
 typedef struct _GError GError;
 
 struct _GError
Index: glib/gfileutils.c
===================================================================
--- glib/gfileutils.c	(revision 7087)
+++ glib/gfileutils.c	(working copy)
@@ -54,6 +54,35 @@
 
 #include "galias.h"
 
+/**
+ * SECTION:fileutils
+ * @Short_description: various file-related functions
+ * @Title: File Utilities
+ * 
+ * There is a group of functions which wrap the common POSIX functions 
+ * dealing with filenames (g_open(), g_rename(), g_mkdir(), g_stat(), 
+ * g_unlink(), g_remove(), g_fopen(), g_freopen()). The point of these 
+ * wrappers is to make it possible to handle file names with any Unicode 
+ * characters in them on Windows without having to use ifdefs and the 
+ * wide character API in the application code.
+ * 
+ * The pathname argument should be in the GLib file name encoding. On
+ * POSIX this is the actual on-disk encoding which might correspond to
+ * the locale settings of the process (or the 
+ * <envar>G_FILENAME_ENCODING</envar> environment variable), or not.
+ * 
+ * On Windows the GLib file name encoding is UTF-8. Note that the
+ * Microsoft C library does not use UTF-8, but has separate APIs for
+ * current system code page and wide characters (UTF-16). The GLib
+ * wrappers call the wide character API if present (on modern Windows
+ * systems), otherwise convert to/from the system code page.
+ * 
+ * 
+ * Another group of functions allows to open and read directories
+ * in the GLib file name encoding. These are g_dir_open(), 
+ * g_dir_read_name(), g_dir_rewind(), g_dir_close().
+ */
+
 static gint create_temp_file (gchar *tmpl, 
 			      int    permissions);
 
Index: glib/gfileutils.h
===================================================================
--- glib/gfileutils.h	(revision 7087)
+++ glib/gfileutils.h	(working copy)
@@ -29,8 +29,99 @@
 
 G_BEGIN_DECLS
 
+/**
+ * G_FILE_ERROR:
+ * 
+ * Error domain for file operations. Errors in this domain will
+ * be from the #GFileError enumeration. See #GError for information on 
+ * error domains.
+ */
 #define G_FILE_ERROR g_file_error_quark ()
 
+/**
+ * GFileError:
+ * @G_FILE_ERROR_EXIST: Operation not permitted; only the owner of the
+ *  file (or other resource) or processes with special privileges can
+ *  perform the operation.
+ * @G_FILE_ERROR_ISDIR: File is a directory; you cannot open a directory
+ *  for writing, or create or remove hard links to it.
+ * @G_FILE_ERROR_ACCES: Permission denied; the file permissions do not
+ *  allow the attempted operation.
+ * @G_FILE_ERROR_NAMETOOLONG: Filename too long.
+ * @G_FILE_ERROR_NOENT: No such file or directory.  This is a "file
+ *  doesn't exist" error for ordinary files that are referenced in
+ *  contexts where they are expected to already exist.
+ * @G_FILE_ERROR_NOTDIR: A file that isn't a directory was specified when
+ *  a directory is required.
+ * @G_FILE_ERROR_NXIO: No such device or address.  The system tried to
+ *  use the device represented by a file you specified, and it
+ *  couldn't find the device.  This can mean that the device file was
+ *  installed incorrectly, or that the physical device is missing or
+ *  not correctly attached to the computer.
+ * @G_FILE_ERROR_NODEV: This file is of a type that doesn't support
+ *  mapping.
+ * @G_FILE_ERROR_ROFS: The directory containing the new link can't be
+ *  modified because it's on a read-only file system.
+ * @G_FILE_ERROR_TXTBSY: Text file busy.
+ * @G_FILE_ERROR_FAULT: You passed in a pointer to bad memory.
+ *  (GLib won't reliably return this, don't pass in pointers to bad
+ *  memory.)
+ * @G_FILE_ERROR_LOOP: Too many levels of symbolic links were encountered
+ *  in looking up a file name.  This often indicates a cycle of symbolic
+ *  links.
+ * @G_FILE_ERROR_NOSPC: No space left on device; write operation on a
+ *  file failed because the disk is full.
+ * @G_FILE_ERROR_NOMEM: No memory available.  The system cannot allocate
+ *  more virtual memory because its capacity is full.
+ * @G_FILE_ERROR_MFILE: The current process has too many files open and
+ *  can't open any more.  Duplicate descriptors do count toward this
+ *  limit.
+ * @G_FILE_ERROR_NFILE: There are too many distinct file openings in the
+ *  entire system.
+ * @G_FILE_ERROR_BADF: Bad file descriptor; for example, I/O on a
+ *  descriptor that has been closed or reading from a descriptor open
+ *  only for writing (or vice versa).
+ * @G_FILE_ERROR_INVAL: Invalid argument.  This is used to indicate
+ *  various kinds of problems with passing the wrong argument to a
+ *  library function.
+ * @G_FILE_ERROR_PIPE: Broken pipe; there is no process reading from the
+ *  other end of a pipe.  Every library function that returns this
+ *  error code also generates a `SIGPIPE' signal; this signal
+ *  terminates the program if not handled or blocked.  Thus, your
+ *  program will never actually see this code unless it has handled or
+ *  blocked `SIGPIPE'.
+ * @G_FILE_ERROR_AGAIN: Resource temporarily unavailable; the call might
+ *  work if you try again later.
+ * @G_FILE_ERROR_INTR: Interrupted function call; an asynchronous signal
+ *  occurred and prevented completion of the call.  When this
+ *  happens, you should try the call again.
+ * @G_FILE_ERROR_IO: Input/output error; usually used for physical read
+ *  or write errors. i.e. the disk or other physical device hardware
+ *  is returning errors.
+ * @G_FILE_ERROR_PERM: Operation not permitted; only the owner of the
+ *  file (or other resource) or processes with special privileges can
+ *  perform the operation.
+ * @G_FILE_ERROR_NOSYS: Function not implemented; this indicates that the
+ *  system is missing some functionality.
+ * @G_FILE_ERROR_FAILED: Does not correspond to a UNIX error code; this
+ *  is the standard "failed for unspecified reason" error code present in 
+ *  all #GError error code enumerations. Returned if no specific
+ *  code applies.
+ * 
+ * Values corresponding to <literal>errno</literal> codes returned from file operations
+ * on UNIX. Unlike <literal>errno</literal> codes, #GFileError values are available on 
+ * all systems, even Windows. The exact meaning of each code depends on what
+ * sort of file operation you were performing; the UNIX documentation
+ * gives more details. The following error code descriptions come 
+ * from the GNU C Library manual, and are under the copyright
+ * of that manual.
+ * 
+ * 
+ * It's not very portable to make detailed assumptions about exactly
+ * which errors will be returned from a given operation. Some errors
+ * don't occur on some systems, etc., sometimes there are subtle
+ * differences in when a system will report a given error, etc.
+ */
 typedef enum
 {
   G_FILE_ERROR_EXIST,
@@ -64,6 +155,19 @@
  * anonymous enum in libgnome. But don't use that enum
  * in new code.
  */
+/**
+ * GFileTest:
+ * @G_FILE_TEST_IS_REGULAR: %TRUE if the file is a regular file (not a directory).
+ *  Note that this test will also return %TRUE if the tested file is a symlink
+ *  to a regular file.
+ * @G_FILE_TEST_IS_SYMLINK: %TRUE if the file is a symlink.
+ * @G_FILE_TEST_IS_DIR: %TRUE if the file is a directory.
+ * @G_FILE_TEST_IS_EXECUTABLE: %TRUE if the file is executable.
+ * @G_FILE_TEST_EXISTS: %TRUE if the file exists. 
+ *  It may or may not be a regular file.
+ * 
+ * A test to perform on a file using g_file_test().
+ */
 typedef enum
 {
   G_FILE_TEST_IS_REGULAR    = 1 << 0,
Index: glib/ghash.c
===================================================================
--- glib/ghash.c	(revision 7087)
+++ glib/ghash.c	(working copy)
@@ -33,7 +33,46 @@
 #include "glib.h"
 #include "galias.h"
 
+/**
+ * SECTION:hash_tables
+ * @Short_description: associations between keys and values so that given a key
+ *     the value can be found quickly
+ * @Title: Hash Tables
+ * 
+ * A #GHashTable provides associations between keys and values which
+ * is optimized so that given a key, the associated value can be found
+ * very quickly.
+ * 
+ * Note that neither keys nor values are copied when inserted into the
+ * #GHashTable, so they must exist for the lifetime of the #GHashTable.
+ * This means that the use of static strings is OK, but temporary
+ * strings (i.e. those created in buffers and those returned by GTK+ widgets)
+ * should be copied with g_strdup() before being inserted.
+ * 
+ * If keys or values are dynamically allocated, you must be careful to ensure
+ * that they are freed when they are removed from the #GHashTable, and also
+ * when they are overwritten by new insertions into the #GHashTable.
+ * It is also not advisable to mix static strings and dynamically-allocated
+ * strings in a #GHashTable, because it then becomes difficult to determine
+ * whether the string should be freed.
+ * 
+ * To create a #GHashTable, use g_hash_table_new().
+ * 
+ * To insert a key and value into a #GHashTable, use g_hash_table_insert().
+ * 
+ * To lookup a value corresponding to a given key, use g_hash_table_lookup()
+ * and g_hash_table_lookup_extended().
+ * 
+ * To remove a key and value, use g_hash_table_remove().
+ * 
+ * To call a function for each key and value pair use g_hash_table_foreach()
+ * or use a iterator to iterate over the key/value pairs in the hash table, see
+ * #GHashTableIter.
+ * 
+ * To destroy a #GHashTable use g_hash_table_destroy().
+ */
 
+
 #define HASH_TABLE_MIN_SIZE 11
 #define HASH_TABLE_MAX_SIZE 13845163
 
Index: glib/ghash.h
===================================================================
--- glib/ghash.h	(revision 7087)
+++ glib/ghash.h	(working copy)
@@ -36,12 +36,41 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GHashTable:
+ * 
+ * The <structname>GHashTable</structname> struct is an opaque data structure 
+ * to represent a <link linkend="glib-Hash-Tables">Hash Table</link>.
+ * It should only be accessed via the following functions.
+ */
 typedef struct _GHashTable  GHashTable;
 
+/**
+ * GHRFunc:
+ * @key: a key.
+ * @value: the value associated with the key.
+ * @user_data: user data passed to g_hash_table_remove().
+ * 
+ * Specifies the type of the function passed to g_hash_table_foreach_remove().
+ * It is called with each key/value pair, together with the @user_data parameter
+ * passed to g_hash_table_foreach_remove().
+ * It should return %TRUE if the key/value pair should be removed from the
+ * #GHashTable.
+ * 
+ * Returns: %TRUE if the key/value pair should be removed from the #GHashTable.
+ */
 typedef gboolean  (*GHRFunc)  (gpointer  key,
                                gpointer  value,
                                gpointer  user_data);
 
+/**
+ * GHashTableIter:
+ * 
+ * A GHashTableIter structure represents an iterator that can be
+ * used to iterate over the elements of a #GHashTable. GHashTableIter
+ * structures are typically allocated on the stack and then initialized
+ * with g_hash_table_iter_init().
+ */
 typedef struct _GHashTableIter GHashTableIter;
 
 struct _GHashTableIter
@@ -113,9 +142,22 @@
 
 #ifndef G_DISABLE_DEPRECATED
 
-/* The following two functions are deprecated and will be removed in
- * the next major release. They do no good. */
+/**
+ * g_hash_table_freeze:
+ * @hash_table: a #GHashTable
+ * 
+ * This function is deprecated and will be removed in the next major
+ *  release of GLib. It does nothing.
+ */
 #define g_hash_table_freeze(hash_table) ((void)0)
+
+/**
+ * g_hash_table_thaw:
+ * @hash_table: a #GHashTable
+ * 
+ * This function is deprecated and will be removed in the next major
+ *  release of GLib. It does nothing.
+ */
 #define g_hash_table_thaw(hash_table) ((void)0)
 
 #endif /* G_DISABLE_DEPRECATED */
Index: glib/gchecksum.c
===================================================================
--- glib/gchecksum.c	(revision 7087)
+++ glib/gchecksum.c	(working copy)
@@ -29,6 +29,28 @@
 
 #include "galias.h"
 
+/**
+ * SECTION:checksum
+ * @Short_description: Computes the checksum for data
+ * @Title: Data Checksums
+ * 
+ * GLib provides a generic API for computing checksums (or "digests") for a
+ * sequence of arbitrary bytes, using various hashing algorithms like MD5,
+ * SHA-1 and SHA-256. Checksums are commonly used in various environments and
+ * specifications.
+ * 
+ * 
+ * GLib supports incremental checksums using the GChecksum data structure, by
+ * calling g_checksum_update() as long as there's data available and then using
+ * g_checksum_get_string() or g_checksum_get_digest() to compute the checksum
+ * and return it either as a string in hexadecimal form, or as a raw sequence
+ * of bytes. To compute the checksum for binary blobs and NUL-terminated strings
+ * in one go, use the convenience functions g_compute_checksum_for_data() and
+ * g_compute_checksum_for_string(), respectively.
+ * 
+ * Support for checksums has been added in GLib 2.16
+ */
+
 #define IS_VALID_TYPE(type)     ((type) >= G_CHECKSUM_MD5 && (type) <= G_CHECKSUM_SHA256)
 
 static const gchar hex_digits[] = "0123456789abcdef";
Index: glib/gtypes.h
===================================================================
--- glib/gtypes.h	(revision 7087)
+++ glib/gtypes.h	(working copy)
@@ -35,6 +35,26 @@
 
 G_BEGIN_DECLS
 
+/**
+ * SECTION:types
+ * @Short_description: standard GLib types, defined for ease-of-use and portability
+ * @Title: Basic Types
+ * 
+ * GLib defines a number of commonly used types, which can be divided into
+ * 4 groups:
+ * 
+ * New types which are not part of standard C - #gboolean, #gsize, #gssize.
+ * 
+ * Integer types which are guaranteed to be the same size across all platforms -
+ * #gint8, #guint8, #gint16, #guint16, #gint32, #guint32, #gint64, #guint64.
+ * 
+ * Types which are easier to use than their standard C counterparts -
+ * #gpointer, #gconstpointer, #guchar, #guint, #gushort, #gulong.
+ * 
+ * Types which correspond exactly to standard C types, but are included
+ * for completeness - #gchar, #gint, #gshort, #glong, #gfloat, #gdouble.
+ */
+
 /* Provide type definitions for commonly used types.
  *  These are useful because a "gint8" can be adjusted
  *  to be 1 byte (8 bits) on all platforms. Similarly and
@@ -42,20 +62,168 @@
  *  4 bytes (32 bits) on all platforms.
  */
 
+/**
+ * gchar:
+ * 
+ * Corresponds to the standard C <type>char</type> type.
+ */
 typedef char   gchar;
+
+/**
+ * gshort:
+ * 
+ * Corresponds to the standard C <type>short</type> type.
+ * Values of this type can range from #G_MINSHORT to #G_MAXSHORT.
+ */
 typedef short  gshort;
+
+/**
+ * glong:
+ * 
+ * Corresponds to the standard C <type>long</type> type.
+ * Values of this type can range from #G_MINLONG to #G_MAXLONG.
+ */
 typedef long   glong;
+
+/**
+ * gint:
+ * 
+ * Corresponds to the standard C <type>int</type> type.
+ * Values of this type can range from #G_MININT to #G_MAXINT.
+ */
 typedef int    gint;
+
+/**
+ * gboolean:
+ * 
+ * A standard <type>boolean</type> type.
+ * Variables of this type should only contain the value %TRUE or %FALSE.
+ */
 typedef gint   gboolean;
 
+/**
+ * guchar:
+ * 
+ * Corresponds to the standard C <type>unsigned char</type> type.
+ */
 typedef unsigned char   guchar;
+
+/**
+ * gushort:
+ * 
+ * Corresponds to the standard C <type>unsigned short</type> type.
+ * Values of this type can range from 0 to #G_MAXUSHORT.
+ */
 typedef unsigned short  gushort;
+
+/**
+ * gulong:
+ * 
+ * Corresponds to the standard C <type>unsigned long</type> type.
+ * Values of this type can range from 0 to #G_MAXULONG.
+ */
 typedef unsigned long   gulong;
+
+/**
+ * guint:
+ * 
+ * Corresponds to the standard C <type>unsigned int</type> type.
+ * Values of this type can range from 0 to #G_MAXUINT.
+ */
 typedef unsigned int    guint;
 
+/**
+ * gfloat:
+ * 
+ * Corresponds to the standard C <type>float</type> type.
+ * Values of this type can range from -#G_MAXFLOAT to #G_MAXFLOAT.
+ */
 typedef float   gfloat;
+
+/**
+ * gdouble:
+ * 
+ * Corresponds to the standard C <type>double</type> type.
+ * Values of this type can range from -#G_MAXDOUBLE to #G_MAXDOUBLE.
+ */
 typedef double  gdouble;
 
+/* Note: The following exists within glibconfig.h, 
+ * but we can't comment them there due to that file being automatically
+ * generated. */
+/**
+ * gint8:
+ * 
+ * A signed integer guaranteed to be 8 bits on all platforms.
+ * Values of this type can range from -128 to 127.
+ */
+/**
+ * gint16:
+ * 
+ * A signed integer guaranteed to be 16 bits on all platforms.
+ * Values of this type can range from -32,768 to 32,767.
+ */
+/**
+ * gint32:
+ * 
+ * A signed integer guaranteed to be 32 bits on all platforms.
+ * Values of this type can range from -2,147,483,648 to 2,147,483,647.
+ */
+/**
+ * gint64:
+ * 
+ * A signed integer guaranteed to be 64 bits on all platforms.
+ * Values of this type can range from -9,223,372,036,854,775,808 to
+ * 9,223,372,036,854,775,807.
+ */
+
+/**
+ * guint8:
+ * 
+ * An unsigned integer guaranteed to be 8 bits on all platforms.
+ * Values of this type can range from 0 to 255.
+ */
+/**
+ * guint16:
+ * 
+ * An unsigned integer guaranteed to be 16 bits on all platforms.
+ * Values of this type can range from 0 to 65,535.
+ */
+/**
+ * guint32:
+ * 
+ * An unsigned integer guaranteed to be 32 bits on all platforms.
+ * Values of this type can range from 0 to 4,294,967,295.
+ */
+/**
+ * guint64:
+ * 
+ * An unsigned integer guaranteed to be 64 bits on all platforms.
+ * Values of this type can range from 0 to 18,446,744,073,709,551,615.
+ */
+
+/**
+ * gsize:
+ * 
+ * An unsigned integer type of the result of the sizeof operator, corresponding
+ * to the size_t type defined in C99. This type is wide enough to hold the numeric
+ * value of a pointer, so it is usually 32bit wide on a 32bit platform and
+ * 64bit wide on a 64bit platform.
+ */
+/**
+ * gssize:
+ * 
+ * A signed variant of gsize, corresponding to the ssize_t defined on most platforms.
+ */
+/**
+ * goffset:
+ * 
+ * A signed integer type that is used for file offsets, corresponding to the 
+ * C99 type off64_t.
+ * 
+ * Since: 2.14
+ */
+
 /* Define min and max constants for the fixed size numerical types */
 #define G_MININT8	((gint8)  0x80)
 #define G_MAXINT8	((gint8)  0x7f)
@@ -73,23 +241,137 @@
 #define G_MAXINT64	G_GINT64_CONSTANT(0x7fffffffffffffff)
 #define G_MAXUINT64	G_GINT64_CONSTANT(0xffffffffffffffffU)
 
+/**
+ * gpointer:
+ * 
+ * An untyped pointer.
+ * #gpointer looks better and is easier to use than <type>void*</type>.
+ */
 typedef void* gpointer;
+
+/**
+ * gconstpointer:
+ * 
+ * An untyped pointer to constant data.
+ * The data pointed to should not be changed.
+ * 
+ * This is typically used in function prototypes to indicate that the
+ * data pointed to will not be altered by the function.
+ */
 typedef const void *gconstpointer;
 
+/**
+ * GCompareDataFunc:
+ * @a: a value.
+ * @b: a value to compare with.
+ * @user_data: user data to pass to comparison function.
+ * 
+ * Specifies the type of a comparison function used to compare two
+ * values.  The function should return a negative integer if the first
+ * value comes before the second, 0 if they are equal, or a positive
+ * integer if the first value comes after the second.
+ * 
+ * Returns: negative value if @a &lt; @b; zero if @a = @b; positive value
+ *  if @a > @b.
+ */
 typedef gint            (*GCompareFunc)         (gconstpointer  a,
                                                  gconstpointer  b);
+
+/**
+ * GCompareFunc:
+ * @a: a value.
+ * @b: a value to compare with.
+ * 
+ * Specifies the type of a comparison function used to compare two
+ * values.  The function should return a negative integer if the first
+ * value comes before the second, 0 if they are equal, or a positive
+ * integer if the first value comes after the second.
+ * 
+ * Returns: negative value if @a &lt; @b; zero if @a = @b; positive value
+ *  if @a > @b.
+ */
 typedef gint            (*GCompareDataFunc)     (gconstpointer  a,
                                                  gconstpointer  b,
 						 gpointer       user_data);
+/**
+ * GEqualFunc:
+ * @a: a value.
+ * @b: a value to compare with.
+ * 
+ * Specifies the type of a function used to test two values for
+ * equality. The function should return %TRUE if both values are equal and
+ * %FALSE otherwise.
+ * 
+ * Returns: %TRUE if @a = @b; %FALSE otherwise.
+ */
 typedef gboolean        (*GEqualFunc)           (gconstpointer  a,
                                                  gconstpointer  b);
+
+/**
+ * GDestroyNotify:
+ * @data: the data element.
+ * 
+ * Specifies the type of function which is called when a data element is
+ * destroyed. It is passed the pointer to the data element and should free
+ * any memory and resources allocated for it.
+ */
 typedef void            (*GDestroyNotify)       (gpointer       data);
+
+/**
+ * GFunc:
+ * @data: the element's data.
+ * @user_data: user data passed to g_list_foreach() or g_slist_foreach().
+ * 
+ * Specifies the type of functions passed to g_list_foreach() and
+ * g_slist_foreach().
+ */
 typedef void            (*GFunc)                (gpointer       data,
                                                  gpointer       user_data);
+                                                 
+/**
+ * GHashFunc:
+ * @key: a key.
+ * 
+ * Specifies the type of the hash function which is passed to
+ * g_hash_table_new() when a #GHashTable is created.
+ * 
+ * The function is passed a key and should return a #guint hash value.
+ * The functions g_direct_hash(), g_int_hash() and g_str_hash() provide
+ * hash functions which can be used when the key is a #gpointer, #gint, and 
+ * #gchar* respectively.
+ * 
+ * <!-- FIXME: Need more here. -->
+ * The hash values should be evenly distributed over a fairly large range?
+ * The modulus is taken with the hash table size (a prime number)
+ * to find the 'bucket' to place each key into.
+ * The function should also be very fast, since it is called for each key
+ * lookup.
+ * 
+ * Returns: the hash value corresponding to the key.
+ */
 typedef guint           (*GHashFunc)            (gconstpointer  key);
+
+/**
+ * GHFunc:
+ * @key: a key.
+ * @value: the value corresponding to the key.
+ * @user_data: user data passed to g_hash_table_foreach().
+ * 
+ * Specifies the type of the function passed to g_hash_table_foreach().
+ * It is called with each key/value pair, together with the @user_data parameter
+ * which is passed to g_hash_table_foreach().
+ */
 typedef void            (*GHFunc)               (gpointer       key,
                                                  gpointer       value,
                                                  gpointer       user_data);
+
+/**
+ * GFreeFunc:
+ * @data: a data pointer.
+ * 
+ * Declares a type of function which takes an arbitrary data pointer argument
+ * and has no return value. It is not currently used in GLib or GTK+.
+ */
 typedef void            (*GFreeFunc)            (gpointer       data);
 typedef const gchar *   (*GTranslateFunc)       (const gchar   *str,
 						 gpointer       data);
@@ -396,6 +678,15 @@
 #error unknown ENDIAN type
 #endif /* !G_LITTLE_ENDIAN && !G_BIG_ENDIAN */
 
+/**
+ * GTimeVal:
+ * @tv_sec: seconds
+ * @tv_usec: microseconds
+ * 
+ * Represents a precise time, with seconds and microseconds. 
+ * Similar to the <structname>struct timeval</structname> returned by 
+ * the <function>gettimeofday()</function> UNIX call.
+ */
 typedef struct _GTimeVal                GTimeVal;
 
 struct _GTimeVal
Index: glib/gcompletion.c
===================================================================
--- glib/gcompletion.c	(revision 7087)
+++ glib/gcompletion.c	(working copy)
@@ -35,9 +35,44 @@
 #include "glib.h"
 #include "galias.h"
 
+/**
+ * SECTION:completion
+ * @Short_description: support for automatic completion using a group of target strings
+ * @Title: Automatic String Completion
+ * 
+ * #GCompletion provides support for automatic completion of a string using
+ * any group of target strings. It is typically used for file name completion
+ * as is common in many UNIX shells.
+ * 
+ * A #GCompletion is created using g_completion_new().
+ * Target items are added and removed with
+ * g_completion_add_items(), g_completion_remove_items() and
+ * g_completion_clear_items().
+ * A completion attempt is requested with g_completion_complete() or 
+ * g_completion_complete_utf8().
+ * When no longer needed, the #GCompletion is freed with g_completion_free().
+ * 
+ * Items in the completion can be simple strings (e.g. filenames),
+ * or pointers to arbitrary data structures. If data structures are used
+ * you must provide a #GCompletionFunc in g_completion_new(),
+ * which retrieves the item's string from the data structure.
+ * You can change the way in which strings are compared by setting
+ * a different #GCompletionStrncmpFunc in g_completion_set_compare().
+ */
+
 static void completion_check_cache (GCompletion* cmp,
 				    gchar**	 new_prefix);
 
+/**
+ * g_completion_new:
+ * @func: the function to be called to return the string representing an item
+ *  in the #GCompletion, or %NULL if strings are going to be used as the
+ *  #GCompletion items.
+ * 
+ * Creates a new #GCompletion.
+ * 
+ * Returns: the new #GCompletion.
+ */
 GCompletion* 
 g_completion_new (GCompletionFunc func)
 {
@@ -53,6 +88,13 @@
   return gcomp;
 }
 
+/**
+ * g_completion_add_items:
+ * @cmp: the #GCompletion.
+ * @items: the list of items to add.
+ * 
+ * Adds items to the #GCompletion.
+ */
 void 
 g_completion_add_items (GCompletion* cmp,
 			GList*	     items)
@@ -82,6 +124,13 @@
     }
 }
 
+/**
+ * g_completion_remove_items:
+ * @cmp: the #GCompletion.
+ * @items: the items to remove.
+ * 
+ * Removes items from a #GCompletion.
+ */
 void 
 g_completion_remove_items (GCompletion* cmp,
 			   GList*	items)
@@ -105,6 +154,12 @@
     }
 }
 
+/**
+ * g_completion_clear_items:
+ * @cmp: the #GCompletion.
+ * 
+ * Removes all items from the #GCompletion.
+ */
 void 
 g_completion_clear_items (GCompletion* cmp)
 {
@@ -213,6 +268,20 @@
   return list;
 }
 
+/**
+ * g_completion_complete:
+ * @cmp: the #GCompletion.
+ * @prefix: the prefix string, typically typed by the user, which is compared
+ *  with each of the items.
+ * @new_prefix: if non-%NULL, returns the longest prefix which is common to all
+ *  items that matched @prefix, or %NULL if no items matched @prefix.
+ *  This string should be freed when no longer needed.
+ * 
+ * Attempts to complete the string @prefix using the #GCompletion target items.
+ * 
+ * Returns: the list of items whose strings begin with @prefix. This should
+ *  not be changed.
+ */
 GList* 
 g_completion_complete (GCompletion* cmp,
 		       const gchar* prefix,
@@ -275,6 +344,12 @@
   return *prefix ? cmp->cache : cmp->items;
 }
 
+/**
+ * g_completion_free:
+ * @cmp: the #GCompletion.
+ * 
+ * Frees all memory used by the #GCompletion.
+ */
 void 
 g_completion_free (GCompletion* cmp)
 {
@@ -284,6 +359,14 @@
   g_free (cmp);
 }
 
+/**
+ * g_completion_set_compare:
+ * @cmp: a #GCompletion.
+ * @strncmp_func: the string comparison function.
+ * 
+ * Sets the function to use for string comparisons. The default
+ * string comparison function is strncmp().
+ */
 void
 g_completion_set_compare(GCompletion *cmp,
 			 GCompletionStrncmpFunc strncmp_func)
Index: glib/gdate.c
===================================================================
--- glib/gdate.c	(revision 7087)
+++ glib/gdate.c	(working copy)
@@ -48,6 +48,68 @@
 
 #include "galias.h"
 
+/**
+ * SECTION:date
+ * @Short_description: calendrical calculations and miscellaneous time stuff
+ * @Title: Date and Time Functions
+ * 
+ * The #GDate data structure represents a day between January 1, Year 1,
+ * and sometime a few thousand years in the future (right now it will go
+ * to the year 65535 or so, but g_date_set_parse() only parses up to the
+ * year 8000 or so - just count on "a few thousand"). #GDate is meant to
+ * represent everyday dates, not astronomical dates or historical dates
+ * or ISO timestamps or the like. It extrapolates the current Gregorian
+ * calendar forward and backward in time; there is no attempt to change
+ * the calendar to match time periods or locations. #GDate does not store
+ * time information; it represents a <emphasis>day</emphasis>.
+ * 
+ * 
+ * The #GDate implementation has several nice features; it is only a
+ * 64-bit struct, so storing large numbers of dates is very efficient. It
+ * can keep both a Julian and day-month-year representation of the date,
+ * since some calculations are much easier with one representation or the
+ * other. A Julian representation is simply a count of days since some
+ * fixed day in the past; for #GDate the fixed day is January 1, 1 AD.
+ * ("Julian" dates in the #GDate API aren't really Julian dates in the
+ * technical sense; technically, Julian dates count from the start of the
+ * Julian period, Jan 1, 4713 BC).
+ * 
+ * 
+ * #GDate is simple to use. First you need a "blank" date; you can get a
+ * dynamically allocated date from g_date_new(), or you can declare an
+ * automatic variable or array and initialize it to a sane state by
+ * calling g_date_clear(). A cleared date is sane; it's safe to call
+ * g_date_set_dmy() and the other mutator functions to initialize the
+ * value of a cleared date. However, a cleared date is initially
+ * <emphasis>invalid</emphasis>, meaning that it doesn't represent a day
+ * that exists. It is undefined to call any of the date calculation
+ * routines on an invalid date. If you obtain a date from a user or other
+ * unpredictable source, you should check its validity with the
+ * g_date_valid() predicate. g_date_valid() is also used to check for
+ * errors with g_date_set_parse() and other functions that can
+ * fail. Dates can be invalidated by calling g_date_clear() again.
+ * 
+ * 
+ * <emphasis>It is very important to use the API to access the #GDate
+ * struct.</emphasis> Often only the day-month-year or only the Julian
+ * representation is valid. Sometimes neither is valid. Use the API.
+ * 
+ * 
+ * GLib doesn't contain any time-manipulation functions; however, there
+ * is a #GTime typedef and a #GTimeVal struct which represents a more 
+ * precise time (with microseconds). You can request the current time as 
+ * a #GTimeVal with g_get_current_time().
+ */
+
+/**
+ * g_date_new:
+ * 
+ * Allocates a #GDate and initializes it to a sane state. The new date will
+ * be cleared (as if you'd called g_date_clear()) but invalid (it won't
+ * represent an existing day). Free the return value with g_date_free().
+ * 
+ * Returns: a newly-allocated #GDate
+ */
 GDate*
 g_date_new (void)
 {
@@ -56,6 +118,18 @@
   return d;
 }
 
+/**
+ * g_date_new_dmy:
+ * @day: day of the month
+ * @month: month of the year
+ * @year: year
+ * 
+ * Like g_date_new(), but also sets the value of the date. Assuming the
+ * day-month-year triplet you pass in represents an existing day, the
+ * returned date will be valid.
+ * 
+ * Returns: a newly-allocated #GDate initialized with @day, @month, and @year
+ */
 GDate*
 g_date_new_dmy (GDateDay   day, 
                 GDateMonth m, 
@@ -78,6 +152,16 @@
   return d;
 }
 
+/**
+ * g_date_new_julian:
+ * @julian_day: days since January 1, Year 1
+ * 
+ * Like g_date_new(), but also sets the value of the date. Assuming the
+ * Julian day number you pass in is valid (greater than 0, less than an
+ * unreasonably large number), the returned date will be valid.
+ * 
+ * Returns: a newly-allocated #GDate initialized with @julian_day
+ */
 GDate*
 g_date_new_julian (guint32 j)
 {
@@ -96,6 +180,13 @@
   return d;
 }
 
+
+/**
+ * g_date_free:
+ * @date: a #GDate
+ * 
+ * Frees a #GDate returned from g_date_new().
+ */
 void
 g_date_free (GDate *d)
 {
@@ -104,6 +195,16 @@
   g_free (d);
 }
 
+/**
+ * g_date_valid:
+ * @date: a #GDate to check
+ * 
+ * Returns %TRUE if the #GDate represents an existing day. The date must not
+ * contain garbage; it should have been initialized with g_date_clear()
+ * if it wasn't allocated by one of the g_date_new() variants.
+ * 
+ * Returns: Whether the date is valid
+ */
 gboolean     
 g_date_valid (const GDate *d)
 {
@@ -124,36 +225,94 @@
   {  0, 0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335, 366 }
 };
 
+/**
+ * g_date_valid_month:
+ * @month: month
+ * 
+ * Returns %TRUE if the month value is valid. The 12 #GDateMonth
+ * enumeration values are the only valid months.
+ * 
+ * Returns: %TRUE if the month is valid
+ */
 gboolean     
 g_date_valid_month (GDateMonth m)
 { 
   return ( (m > G_DATE_BAD_MONTH) && (m < 13) );
 }
 
+/**
+ * g_date_valid_year:
+ * @year: year
+ * 
+ * Returns %TRUE if the year is valid. Any year greater than 0 is valid,
+ * though there is a 16-bit limit to what #GDate will understand.
+ * 
+ * Returns: %TRUE if the year is valid
+ */
 gboolean     
 g_date_valid_year (GDateYear y)
 {
   return ( y > G_DATE_BAD_YEAR );
 }
 
+/**
+ * g_date_valid_day:
+ * @day: day to check
+ * 
+ * Returns %TRUE if the day of the month is valid (a day is valid if it's
+ * between 1 and 31 inclusive).
+ * 
+ * Returns: %TRUE if the day is valid
+ */
 gboolean     
 g_date_valid_day (GDateDay d)
 {
   return ( (d > G_DATE_BAD_DAY) && (d < 32) );
 }
 
+/**
+ * g_date_valid_weekday:
+ * @weekday: weekday
+ * 
+ * Returns %TRUE if the weekday is valid. The seven #GDateWeekday enumeration
+ * values are the only valid weekdays.
+ * 
+ * Returns: %TRUE if the weekday is valid
+ */
 gboolean     
 g_date_valid_weekday (GDateWeekday w)
 {
   return ( (w > G_DATE_BAD_WEEKDAY) && (w < 8) );
 }
 
+/**
+ * g_date_valid_julian:
+ * @julian_date: Julian day to check
+ * 
+ * Returns %TRUE if the Julian day is valid. Anything greater than zero 
+ * is basically a valid Julian, though there is a 32-bit limit.
+ * 
+ * Returns: %TRUE if the Julian day is valid
+ */
 gboolean     
 g_date_valid_julian (guint32 j)
 {
   return (j > G_DATE_BAD_JULIAN);
 }
 
+
+/**
+ * g_date_valid_dmy:
+ * @day: day
+ * @month: month
+ * @year: year
+ * 
+ * Returns %TRUE if the day-month-year triplet forms a valid, existing day
+ * in the range of days #GDate understands (Year 1 or later, no more than
+ * a few thousand years in the future).
+ * 
+ * Returns: %TRUE if the date is a valid one
+ */
 gboolean     
 g_date_valid_dmy (GDateDay   d, 
                   GDateMonth m, 
@@ -253,6 +412,14 @@
   d->dmy = TRUE;
 }
 
+/**
+ * g_date_get_weekday:
+ * @date: a #GDate.
+ * 
+ * Returns the day of the week for a #GDate. The date must be valid.
+ * 
+ * Returns: day of the week as a #GDateWeekday.
+ */
 GDateWeekday 
 g_date_get_weekday (const GDate *d)
 {
@@ -266,6 +433,14 @@
   return ((d->julian_days - 1) % 7) + 1;
 }
 
+/**
+ * g_date_get_month:
+ * @date: a #GDate to get the month from
+ * 
+ * Returns the month of the year. The date must be valid.
+ * 
+ * Returns: month of the year as a #GDateMonth
+ */
 GDateMonth   
 g_date_get_month (const GDate *d)
 {
@@ -279,6 +454,14 @@
   return d->month;
 }
 
+/**
+ * g_date_get_year:
+ * @date: a #GDate
+ * 
+ * Returns the year of a #GDate. The date must be valid.
+ * 
+ * Returns: year in which the date falls
+ */
 GDateYear    
 g_date_get_year (const GDate *d)
 {
@@ -292,6 +475,14 @@
   return d->year;
 }
 
+/**
+ * g_date_get_day:
+ * @date: a #GDate to extract the day of the month from
+ * 
+ * Returns the day of the month. The date must be valid.
+ * 
+ * Returns: day of the month
+ */
 GDateDay     
 g_date_get_day (const GDate *d)
 {
@@ -305,6 +496,18 @@
   return d->day;
 }
 
+
+/**
+ * g_date_get_julian:
+ * @date: a #GDate to extract the Julian day from
+ * 
+ * Returns the Julian day or "serial number" of the #GDate. The
+ * Julian day is simply the number of days since January 1, Year 1; i.e.,
+ * January 1, Year 1 is Julian day 1; January 2, Year 1 is Julian day 2,
+ * etc. The date must be valid.
+ * 
+ * Returns: Julian day
+ */
 guint32      
 g_date_get_julian (const GDate *d)
 {
@@ -318,6 +521,15 @@
   return d->julian_days;
 }
 
+/**
+ * g_date_get_day_of_year:
+ * @date: a #GDate to extract day of year from
+ * 
+ * Returns the day of the year, where Jan 1 is the first day of the
+ * year. The date must be valid.
+ * 
+ * Returns: day of the year
+ */
 guint        
 g_date_get_day_of_year (const GDate *d)
 {
@@ -335,6 +547,16 @@
   return (days_in_year[index][d->month] + d->day);
 }
 
+/**
+ * g_date_get_monday_week_of_year:
+ * @date: a #GDate
+ * 
+ * Returns the week of the year, where weeks are understood to start on
+ * Monday. If the date is before the first Monday of the year, return
+ * 0. The date must be valid.
+ * 
+ * Returns: week of the year
+ */
 guint        
 g_date_get_monday_week_of_year (const GDate *d)
 {
@@ -359,6 +581,16 @@
   return ((day + wd)/7U + (wd == 0 ? 1 : 0));
 }
 
+/**
+ * g_date_get_sunday_week_of_year:
+ * @date: a #GDate
+ * 
+ * Returns the week of the year during which this date falls, if weeks 
+ * are understood to being on Sunday. The date must be valid. Can return 0 if 
+ * the day is before the first Sunday of the year.
+ * 
+ * Returns: week number
+ */
 guint        
 g_date_get_sunday_week_of_year (const GDate *d)
 {
@@ -420,6 +652,17 @@
   return w;
 }
 
+/**
+ * g_date_days_between:
+ * @date1: the first date
+ * @date2: the second date
+ * 
+ * Computes the number of days between two dates.
+ * If @date2 is prior to @date1, the returned value is negative.
+ * Both dates must be valid.
+ * 
+ * Returns: the number of days between @date1 and @date2
+ */
 gint
 g_date_days_between (const GDate *d1,
 		     const GDate *d2)
@@ -430,6 +673,16 @@
   return (gint)g_date_get_julian (d2) - (gint)g_date_get_julian (d1);
 }
 
+/**
+ * g_date_clear:
+ * @date: pointer to one or more dates to clear
+ * @n_dates: number of dates to clear
+ * 
+ * Initializes one or more #GDate structs to a sane but invalid
+ * state. The cleared dates will not represent an existing date, but will
+ * not contain garbage. Useful to init a date declared on the stack.
+ * Validity can be tested with g_date_valid().
+ */
 void         
 g_date_clear (GDate *d, guint ndates)
 {
@@ -704,6 +957,24 @@
   g_date_fill_parse_tokens (str, pt);
 }
 
+/**
+ * g_date_set_parse:
+ * @date: a #GDate to fill in
+ * @str: string to parse
+ * 
+ * Parses a user-inputted string @str, and try to figure out what date it
+ * represents, taking the <link linkend="setlocale">current locale</link> 
+ * into account. If the string is successfully parsed, the date will be 
+ * valid after the call. Otherwise, it will be invalid. You should check 
+ * using g_date_valid() to see whether the parsing succeeded.
+ * 
+ * 
+ * This function is not appropriate for file formats and the like; it
+ * isn't very precise, and its exact behavior varies with the
+ * locale. It's intended to be a heuristic routine that guesses what the
+ * user means by a given string (and it does work pretty well in that
+ * capacity).
+ */
 void         
 g_date_set_parse (GDate       *d, 
                   const gchar *str)
@@ -948,6 +1219,14 @@
   g_date_set_time_t (date, (time_t) timeval->tv_sec);
 }
 
+/**
+ * g_date_set_month:
+ * @date: a #GDate
+ * @month: month to set
+ * 
+ * Sets the month of the year for a #GDate.  If the resulting
+ * day-month-year triplet is invalid, the date will be invalid.
+ */
 void         
 g_date_set_month (GDate     *d, 
                   GDateMonth m)
@@ -966,6 +1245,14 @@
     d->dmy = FALSE;
 }
 
+/**
+ * g_date_set_day:
+ * @date: a #GDate
+ * @day: day to set
+ * 
+ * Sets the day of the month for a #GDate. If the resulting day-month-year
+ * triplet is invalid, the date will be invalid.
+ */
 void         
 g_date_set_day (GDate    *d, 
                 GDateDay  day)
@@ -984,6 +1271,14 @@
     d->dmy = FALSE;
 }
 
+/**
+ * g_date_set_year:
+ * @date: a #GDate
+ * @year: year to set
+ * 
+ * Sets the year for a #GDate. If the resulting day-month-year triplet is
+ * invalid, the date will be invalid.
+ */
 void         
 g_date_set_year (GDate     *d, 
                  GDateYear  y)
@@ -1002,6 +1297,17 @@
     d->dmy = FALSE;
 }
 
+/**
+ * g_date_set_dmy:
+ * @date: a #GDate
+ * @day: day
+ * @month: month
+ * @y: year
+ * 
+ * Sets the value of a #GDate from a day, month, and year. The day-month-year 
+ * triplet must be valid; if you aren't sure it is, call g_date_valid_dmy() to
+ * check before you set it.
+ */
 void         
 g_date_set_dmy (GDate      *d, 
                 GDateDay    day, 
@@ -1020,6 +1326,13 @@
   d->dmy = TRUE;
 }
 
+/**
+ * g_date_set_julian:
+ * @date: a #GDate
+ * @julian_date: Julian day number (days since January 1, Year 1)
+ * 
+ * Sets the value of a #GDate from a Julian day number.
+ */
 void         
 g_date_set_julian (GDate   *d, 
                    guint32  j)
@@ -1032,7 +1345,14 @@
   d->dmy = FALSE;
 }
 
-
+/**
+ * g_date_is_first_of_month:
+ * @date: a #GDate to check
+ * 
+ * Returns %TRUE if the date is on the first of a month. The date must be valid.
+ * 
+ * Returns: %TRUE if the date is the first of the month
+ */
 gboolean     
 g_date_is_first_of_month (const GDate *d)
 {
@@ -1047,6 +1367,15 @@
   else return FALSE;
 }
 
+/**
+ * g_date_is_last_of_month:
+ * @date: a #GDate to check
+ * 
+ * Returns %TRUE if the date is the last day of the month. 
+ * The date must be valid.
+ * 
+ * Returns: %TRUE if the date is the last day of the month
+ */
 gboolean     
 g_date_is_last_of_month (const GDate *d)
 {
@@ -1065,6 +1394,14 @@
   else return FALSE;
 }
 
+/**
+ * g_date_add_days:
+ * @date: a #GDate to increment
+ * @n_days: number of days to move the date forward
+ * 
+ * Increments a date some number of days. To move forward by weeks, add
+ * weeks*7 days. The date must be valid.
+ */
 void         
 g_date_add_days (GDate *d, 
                  guint  ndays)
@@ -1080,6 +1417,14 @@
   d->dmy = FALSE;
 }
 
+/**
+ * g_date_subtract_days:
+ * @date: a #GDate to decrement
+ * @n_days: number of days to move
+ * 
+ * Moves a date some number of days into the past. To move by weeks, just
+ * move by weeks*7 days. The date must be valid.
+ */
 void         
 g_date_subtract_days (GDate *d, 
                       guint  ndays)
@@ -1096,6 +1441,16 @@
   d->dmy = FALSE;
 }
 
+/**
+ * g_date_add_months:
+ * @date: a #GDate to increment
+ * @n_months: number of months to move forward
+ * 
+ * Increments a date by some number of months. If the day of the month is
+ * greater than 28, this routine may change the day of the month (because
+ * the destination month may not have the current day in it). The date
+ * must be valid.
+ */
 void         
 g_date_add_months (GDate *d, 
                    guint  nmonths)
@@ -1128,6 +1483,15 @@
   g_return_if_fail (g_date_valid (d));
 }
 
+/**
+ * g_date_subtract_months:
+ * @date: a #GDate to decrement
+ * @n_months: number of months to move
+ * 
+ * Moves a date some number of months into the past. If the current day of
+ * the month doesn't exist in the destination month, the day of the month
+ * may change. The date must be valid.
+ */
 void         
 g_date_subtract_months (GDate *d, 
                         guint  nmonths)
@@ -1167,6 +1531,15 @@
   g_return_if_fail (g_date_valid (d));
 }
 
+/**
+ * g_date_add_years:
+ * @date: a #GDate to increment
+ * @n_years: number of years to move forward
+ * 
+ * Increments a date by some number of years. If the date is February 29,
+ * and the destination year is not a leap year, the date will be changed
+ * to February 28. The date must be valid.
+ */
 void         
 g_date_add_years (GDate *d, 
                   guint  nyears)
@@ -1189,6 +1562,16 @@
   d->julian = FALSE;
 }
 
+/**
+ * g_date_subtract_years:
+ * @date: a #GDate to decrement
+ * @n_years: number of years to move
+ * 
+ * Moves a date some number of years into the past. If the current day
+ * doesn't exist in the destination year (i.e. it's February 29 and you
+ * move to a non-leap-year) then the day is changed to February 29. The date
+ * must be valid.
+ */
 void         
 g_date_subtract_years (GDate *d, 
                        guint  nyears)
@@ -1212,6 +1595,16 @@
   d->julian = FALSE;
 }
 
+/**
+ * g_date_is_leap_year:
+ * @year: year to check
+ * 
+ * For the purposes of this function, leap year is every year divisible by
+ * 4 unless that year is divisible by 100. If it is divisible by 100 it would 
+ * be a leap year only if that year is also divisible by 400.</para></footnote>
+ * 
+ * Returns: %TRUE if the year is a leap year
+ */
 gboolean     
 g_date_is_leap_year (GDateYear year)
 {
@@ -1221,6 +1614,15 @@
            (year % 400) == 0 );
 }
 
+/**
+ * g_date_get_days_in_month:
+ * @month: month
+ * @year: year
+ * 
+ * Returns the number of days in a month, taking leap years into account.
+ * 
+ * Returns: number of days in @month during the @year
+ */
 guint8         
 g_date_get_days_in_month (GDateMonth month, 
                           GDateYear  year)
@@ -1235,6 +1637,19 @@
   return days_in_months[index][month];
 }
 
+/**
+ * g_date_get_monday_weeks_in_year:
+ * @year: a year
+ * 
+ * Returns the number of weeks in the year, where weeks are taken to start
+ * on Monday. Will be 52 or 53. The date must be valid. (Years always have 52
+ * 7-day periods, plus 1 or 2 extra days depending on whether it's a leap
+ * year. This function is basically telling you how many Mondays are in
+ * the year, i.e. there are 53 Mondays if one of the extra days happens
+ * to be a Monday.)
+ * 
+ * Returns: number of Mondays in the year
+ */
 guint8       
 g_date_get_monday_weeks_in_year (GDateYear year)
 {
@@ -1257,6 +1672,19 @@
   return 52;
 }
 
+/**
+ * g_date_get_sunday_weeks_in_year:
+ * @year: year to count weeks in
+ * 
+ * Returns the number of weeks in the year, where weeks are taken to start
+ * on Sunday. Will be 52 or 53. The date must be valid. (Years always have 52
+ * 7-day periods, plus 1 or 2 extra days depending on whether it's a leap
+ * year. This function is basically telling you how many Sundays are in
+ * the year, i.e. there are 53 Sundays if one of the extra days happens
+ * to be a Sunday.)
+ * 
+ * Returns: number of weeks
+ */
 guint8       
 g_date_get_sunday_weeks_in_year (GDateYear year)
 {
@@ -1279,6 +1707,17 @@
   return 52;
 }
 
+/**
+ * g_date_compare:
+ * @lhs: first date to compare
+ * @rhs: second date to compare
+ * 
+ * qsort()-style comparsion function for dates. Both
+ * dates must be valid.
+ * 
+ * Returns: 0 for equal, less than zero if @lhs is less than @rhs,
+ *  greater than zero if @lhs is greater than @rhs
+ */
 gint         
 g_date_compare (const GDate *lhs, 
                 const GDate *rhs)
@@ -1328,7 +1767,15 @@
   return 0; /* warnings */
 }
 
-
+/**
+ * g_date_to_struct_tm:
+ * @date: a #GDate to set the <structname>struct tm</structname> from.
+ * @tm: <structname>struct tm</structname> to fill.
+ * 
+ * Fills in the date-related bits of a <structname>struct tm</structname>
+ * using the @date value. Initializes the non-date parts with something
+ * sane but meaningless.
+ */
 void        
 g_date_to_struct_tm (const GDate *d, 
                      struct tm   *tm)
@@ -1366,6 +1813,18 @@
   tm->tm_isdst = -1; /* -1 means "information not available" */
 }
 
+/**
+ * g_date_clamp:
+ * @date: a #GDate to clamp
+ * @min_date: minimum accepted value for @date
+ * @max_date: maximum accepted value for @date
+ * 
+ * If @date is prior to @min_date, sets @date equal to @min_date.
+ * If @date falls after @max_date, sets @date equal to @max_date.
+ * Otherwise, @date is unchanged.
+ * Either of @min_date and @max_date may be %NULL.  All non-%NULL dates
+ * must be valid.
+ */
 void
 g_date_clamp (GDate       *date,
 	      const GDate *min_date,
@@ -1389,6 +1848,14 @@
     *date = *max_date;
 }
 
+/**
+ * g_date_order:
+ * @date1: the first date
+ * @date2: the second date
+ * 
+ * Checks if @date1 is less than or equal to @date2,
+ * and swap the values if this is not the case.
+ */
 void
 g_date_order (GDate *date1,
               GDate *date2)
@@ -1782,6 +2249,28 @@
 
 #endif
 
+/**
+ * g_date_strftime:
+ * @s: destination buffer
+ * @slen: buffer size
+ * @format: format string
+ * @date: valid #GDate
+ * 
+ * Generates a printed representation of the date, in a 
+ * <link linkend="setlocale">locale</link>-specific way. Works just like 
+ * the platform's C library strftime() function, but only accepts date-related 
+ * formats; time-related formats give undefined results. Date must be valid. 
+ * Unlike strftime() (which uses the locale encoding), works on a UTF-8 format 
+ * string and stores a UTF-8 result.
+ * 
+ * 
+ * This function does not provide any conversion specifiers in addition
+ * to those implemented by the platform's C library. For example, don't
+ * expect that using g_date_strftime() would make the %F provided by the C99 
+ * strftime() work on Windows where the C library only complies to C89.
+ * 
+ * Returns: number of characters written to the buffer, or 0 the buffer was too small
+ */
 gsize     
 g_date_strftime (gchar       *s, 
                  gsize        slen, 
Index: glib/gcompletion.h
===================================================================
--- glib/gcompletion.h	(revision 7087)
+++ glib/gcompletion.h	(working copy)
@@ -35,13 +35,46 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GCompletion:
+ * @items: list of target items (strings or data structures).
+ * @func: function which is called to get the string associated with a target 
+ *  item. It is %NULL if the target items are strings.
+ * @prefix: the last prefix passed to g_completion_complete() or 
+ *  g_completion_complete_utf8().
+ * @cache: the list of items which begin with @prefix.
+ * @strncmp_func: The function to use when comparing strings. 
+ *  Use g_completion_set_compare() to modify this function.
+ * 
+ * The data structure used for automatic completion.
+ */
 typedef struct _GCompletion     GCompletion;
 
+/**
+ * GCompletionFunc:
+ * @Param1: the completion item.
+ * 
+ * Specifies the type of the function passed to g_completion_new().
+ * It should return the string corresponding to the given target item.
+ * This is used when you use data structures as #GCompletion items.
+ * 
+ * Returns: the string corresponding to the item.
+ */
 typedef gchar*          (*GCompletionFunc)      (gpointer);
 
-/* GCompletion
+/**
+ * GCompletionStrncmpFunc:
+ * @s1: string to compare with @s2.
+ * @s2: string to compare with @s1.
+ * @n: maximal number of bytes to compare.
+ * 
+ * Specifies the type of the function passed to g_completion_set_compare().
+ * This is used when you use strings as #GCompletion items.
+ * 
+ * Returns: an integer less than, equal to, or greater than zero if the 
+ *  first @n bytes of @s1 is found, respectively, to be less than, to match, 
+ *  or to be greater than the first @n bytes of @s2.
  */
-
 typedef gint (*GCompletionStrncmpFunc) (const gchar *s1,
 					const gchar *s2,
 					gsize        n);
Index: glib/gdate.h
===================================================================
--- glib/gdate.h	(revision 7087)
+++ glib/gdate.h	(working copy)
@@ -47,12 +47,80 @@
  * Pennington <hp@pobox.com>
  */
 
+/**
+ * GTime:
+ * 
+ * Simply a replacement for <type>time_t</type>. It has been deprecated
+ * since it is <emphasis>not</emphasis> equivalent to <type>time_t</type> 
+ * on 64-bit platforms with a 64-bit <type>time_t</type>. 
+ * Unrelated to #GTimer.
+ * 
+ * Note that <type>GTime</type> is defined to always be a 32bit integer,
+ * unlike <type>time_t</type> which may be 64bit on some systems. 
+ * Therefore, <type>GTime</type> will overflow in the year 2038, and
+ * you cannot use the address of a <type>GTime</type> variable as argument 
+ * to the UNIX time() function. Instead, do the following:
+ * <informalexample>
+ * <programlisting>
+ * time_t ttime;
+ * GTime gtime;
+ * 
+ * time (&ttime);
+ * gtime = (GTime)ttime;
+ * </programlisting>
+ * </informalexample>
+ */
 typedef gint32  GTime;
+
+/**
+ * GDateYear:
+ * 
+ * Integer representing a year; #G_DATE_BAD_YEAR is the invalid
+ * value. The year must be 1 or higher; negative (BC) years are not
+ * allowed. The year is represented with four digits.
+ */
 typedef guint16 GDateYear;
-typedef guint8  GDateDay;   /* day of the month */
+
+/**
+ * GDateDay:
+ * 
+ * Integer representing a day of the month; between 1 and
+ * 31. #G_DATE_BAD_DAY represents an invalid day of the month.
+ */
+typedef guint8  GDateDay;
+
+/**
+ * GDate:
+ * @julian_days: the Julian representation of the date
+ * @julian: this bit is set if @julian_days is valid
+ * @dmy: this is set if @day, @month and @year are valid
+ * @day: the day of the day-month-year representation of the date, as 
+ *  a number between 1 and 31
+ * @month: the day of the day-month-year representation of the date, as 
+ *  a number between 1 and 12
+ * @year: the day of the day-month-year representation of the date
+ * 
+ * Represents a day between January 1, Year 1 and a few thousand years in
+ * the future. None of its members should be accessed directly. If the
+ * <structname>GDate</structname> is obtained from g_date_new(), it will
+ * be safe to mutate but invalid and thus not safe for calendrical computations.
+ * If it's declared on the stack, it will contain garbage so must be
+ * initialized with g_date_clear(). g_date_clear() makes the date invalid
+ * but sane. An invalid date doesn't represent a day, it's "empty." A
+ * date becomes valid after you set it to a Julian day or you set a day,
+ * month, and year.
+ */
 typedef struct _GDate GDate;
 
-/* enum used to specify order of appearance in parsed date strings */
+/**
+ * GDateDMY:
+ * @G_DATE_DAY: a day
+ * @G_DATE_MONTH: a month
+ * @G_DATE_YEAR: a year
+ * 
+ * This enumeration isn't used in the API, but may be useful if you need
+ * to mark a number as a day, month, or year.
+ */
 typedef enum
 {
   G_DATE_DAY   = 0,
@@ -60,7 +128,20 @@
   G_DATE_YEAR  = 2
 } GDateDMY;
 
-/* actual week and month values */
+/**
+ * GDateWeekday:
+ * @G_DATE_BAD_WEEKDAY: invalid value
+ * @G_DATE_MONDAY: Monday
+ * @G_DATE_TUESDAY: Tuesday
+ * @G_DATE_WEDNESDAY: Wednesday
+ * @G_DATE_THURSDAY: Thursday
+ * @G_DATE_FRIDAY: Friday
+ * @G_DATE_SATURDAY: Saturday
+ * @G_DATE_SUNDAY: Sunday
+ * 
+ * Enumeration representing a day of the week; #G_DATE_MONDAY,
+ * #G_DATE_TUESDAY, etc. #G_DATE_BAD_WEEKDAY is an invalid weekday.
+ */
 typedef enum
 {
   G_DATE_BAD_WEEKDAY  = 0,
@@ -72,6 +153,26 @@
   G_DATE_SATURDAY     = 6,
   G_DATE_SUNDAY       = 7
 } GDateWeekday;
+
+/**
+ * GDateMonth:
+ * @G_DATE_BAD_MONTH: invalid value
+ * @G_DATE_JANUARY: January
+ * @G_DATE_FEBRUARY: February
+ * @G_DATE_MARCH: March
+ * @G_DATE_APRIL: April
+ * @G_DATE_MAY: May
+ * @G_DATE_JUNE: June
+ * @G_DATE_JULY: July
+ * @G_DATE_AUGUST: August
+ * @G_DATE_SEPTEMBER: September
+ * @G_DATE_OCTOBER: October
+ * @G_DATE_NOVEMBER: November
+ * @G_DATE_DECEMBER: December
+ * 
+ * Enumeration representing a month; values are #G_DATE_JANUARY,
+ * #G_DATE_FEBRUARY, etc. #G_DATE_BAD_MONTH is the invalid value.
+ */
 typedef enum
 {
   G_DATE_BAD_MONTH = 0,
@@ -89,8 +190,25 @@
   G_DATE_DECEMBER  = 12
 } GDateMonth;
 
+/**
+ * G_DATE_BAD_JULIAN:
+ * 
+ * Represents an invalid Julian day number.
+ */
 #define G_DATE_BAD_JULIAN 0U
+
+/**
+ * G_DATE_BAD_DAY:
+ * 
+ * Represents an invalid #GDateDay.
+ */
 #define G_DATE_BAD_DAY    0U
+
+/**
+ * G_DATE_BAD_YEAR:
+ * 
+ * Represents an invalid year.
+ */
 #define G_DATE_BAD_YEAR   0U
 
 /* Note: directly manipulating structs is generally a bad idea, but
Index: glib/gdataset.c
===================================================================
--- glib/gdataset.c	(revision 7087)
+++ glib/gdataset.c	(working copy)
@@ -38,7 +38,75 @@
 #include "gdatasetprivate.h"
 #include "galias.h"
 
+/**
+ * SECTION:datasets
+ * @Short_description: associate groups of data elements with particular memory locations
+ * @Title: Datasets
+ * 
+ * Datasets associate groups of data elements with particular memory locations.
+ * These are useful if you need to associate data with a structure returned
+ * from an external library. Since you cannot modify the structure, you use
+ * its location in memory as the key into a dataset, where you can associate
+ * any number of data elements with it.
+ * 
+ * There are two forms of most of the dataset functions.
+ * The first form uses strings to identify the data elements associated with
+ * a location. The second form uses #GQuark identifiers, which are created
+ * with a call to g_quark_from_string() or g_quark_from_static_string().
+ * The second form is quicker, since it does not require looking up the string
+ * in the hash table of #GQuark identifiers.
+ * 
+ * There is no function to create a dataset. It is automatically created as
+ * soon as you add elements to it.
+ * 
+ * To add data elements to a dataset use g_dataset_id_set_data(),
+ * g_dataset_id_set_data_full(), g_dataset_set_data()
+ * and g_dataset_set_data_full().
+ * 
+ * To get data elements from a dataset use g_dataset_id_get_data() and
+ * g_dataset_get_data().
+ * 
+ * To iterate over all data elements in a dataset use g_dataset_foreach() (not thread-safe).
+ * 
+ * To remove data elements from a dataset use g_dataset_id_remove_data() and
+ * g_dataset_remove_data().
+ * 
+ * To destroy a dataset, use g_dataset_destroy().
+ */
 
+/**
+ * SECTION:datalist
+ * @Short_description: lists of data elements which are accessible by a string or GQuark identifier
+ * @Title: Keyed Data Lists
+ * 
+ * Keyed data lists provide lists of arbitrary data elements which can be accessed
+ * either with a string or with a #GQuark corresponding to the
+ * string.
+ * 
+ * The #GQuark methods are quicker, since the strings have to be converted to
+ * #GQuarks anyway.
+ * 
+ * Data lists are used for associating arbitrary data with
+ * #GObjects, using g_object_set_data() and related functions.
+ * 
+ * 
+ * To create a datalist, use g_datalist_init().
+ * 
+ * To add data elements to a datalist use g_datalist_id_set_data(),
+ * g_datalist_id_set_data_full(), g_datalist_set_data()
+ * and g_datalist_set_data_full().
+ * 
+ * To get data elements from a datalist use g_datalist_id_get_data() and
+ * g_datalist_get_data().
+ * 
+ * To iterate over all data elements in a datalist use g_datalist_foreach() (not thread-safe).
+ * 
+ * To remove data elements from a datalist use g_datalist_id_remove_data() and
+ * g_datalist_remove_data().
+ * 
+ * To remove all data elements from a datalist, use g_datalist_clear().
+ */
+
 /* --- defines --- */
 #define	G_QUARK_BLOCK_SIZE			(512)
 
@@ -125,6 +193,13 @@
     }
 }
 
+/**
+ * g_datalist_clear:
+ * @datalist: a datalist.
+ * 
+ * Frees all the data elements of the datalist.
+ * The data elements' destroy functions are called if they have been set.
+ */
 void
 g_datalist_clear (GData **datalist)
 {
@@ -178,6 +253,14 @@
     }
 }
 
+
+/**
+ * g_dataset_destroy:
+ * @dataset_location: the location identifying the dataset.
+ * 
+ * Destroys the dataset, freeing all memory allocated, and calling any
+ * destroy functions set for data elements.
+ */
 void
 g_dataset_destroy (gconstpointer  dataset_location)
 {
@@ -300,6 +383,20 @@
   return NULL;
 }
 
+/**
+ * g_dataset_id_set_data_full:
+ * @dataset_location: the location identifying the dataset.
+ * @key_id: the #GQuark id to identify the data element.
+ * @data: the data element.
+ * @destroy_func: the function to call when the data element is removed. This
+ *  function will be called with the data element and can be used to free any
+ *  memory allocated for it.
+ * 
+ * Sets the data element associated with the given #GQuark id, and also the
+ * function to call when the data element is destroyed.
+ * Any previous data with the same key is removed, and its
+ * destroy function is called.
+ */
 void
 g_dataset_id_set_data_full (gconstpointer  dataset_location,
 			    GQuark         key_id,
@@ -338,6 +435,22 @@
   G_UNLOCK (g_dataset_global);
 }
 
+/**
+ * g_datalist_id_set_data_full:
+ * @datalist: a datalist.
+ * @key_id: the #GQuark to identify the data element.
+ * @data: the data element or %NULL to remove any previous element
+ *  corresponding to @key_id.
+ * @destroy_func: the function to call when the data element is removed. This
+ *  function will be called with the data element and can be used to free any
+ *  memory allocated for it. If @data is %NULL, then @destroy_func must
+ *  also be %NULL.
+ * 
+ * Sets the data corresponding to the given #GQuark id, and the function to
+ * be called when the element is removed from the datalist.
+ * Any previous data with the same key is removed, and its
+ * destroy function is called.
+ */
 void
 g_datalist_id_set_data_full (GData	  **datalist,
 			     GQuark         key_id,
@@ -363,6 +476,16 @@
   G_UNLOCK (g_dataset_global);
 }
 
+
+/**
+ * g_dataset_id_remove_no_notify:
+ * @dataset_location: the location identifying the dataset.
+ * @key_id: the #GQuark ID identifying the data element.
+ * 
+ * Removes an element, without calling its destroy notification function.
+ * 
+ * Returns: the data previously stored at @key_id, or %NULL if none.
+ */
 gpointer
 g_dataset_id_remove_no_notify (gconstpointer  dataset_location,
 			       GQuark         key_id)
@@ -385,6 +508,15 @@
   return ret_data;
 }
 
+/**
+ * g_datalist_id_remove_no_notify:
+ * @datalist: a datalist.
+ * @key_id: the #GQuark identifying a data element.
+ * 
+ * Removes an element, without calling its destroy notification function.
+ * 
+ * Returns: the data previously stored at @key_id, or %NULL if none.
+ */
 gpointer
 g_datalist_id_remove_no_notify (GData	**datalist,
 				GQuark    key_id)
@@ -401,6 +533,16 @@
   return ret_data;
 }
 
+/**
+ * g_dataset_id_get_data:
+ * @dataset_location: the location identifying the dataset.
+ * @key_id: the #GQuark id to identify the data element.
+ * 
+ * Gets the data element corresponding to a #GQuark.
+ * 
+ * Returns: the data element corresponding to the #GQuark, 
+ *     or %NULL if it is not found.
+ */
 gpointer
 g_dataset_id_get_data (gconstpointer  dataset_location,
 		       GQuark         key_id)
@@ -430,6 +572,15 @@
   return NULL;
 }
 
+/**
+ * g_datalist_id_get_data:
+ * @datalist: a datalist.
+ * @key_id: the #GQuark identifying a data element.
+ * 
+ * Retrieves the data element corresponding to @key_id. 
+ * 
+ * Returns: the data element, or %NULL if it is not found.
+ */
 gpointer
 g_datalist_id_get_data (GData	 **datalist,
 			GQuark     key_id)
@@ -451,6 +602,18 @@
   return data;
 }
 
+/**
+ * g_dataset_foreach:
+ * @dataset_location: the location identifying the dataset.
+ * @func: the function to call for each data element.
+ * @user_data: user data to pass to the function.
+ * 
+ * Calls the given function for each data element which is associated with the
+ * given location.
+ * Note that this function is NOT thread-safe. So unless @datalist
+ * can be protected from any modifications during invocation of this
+ * function, it should not be called.
+ */
 void
 g_dataset_foreach (gconstpointer    dataset_location,
 		   GDataForeachFunc func,
@@ -483,6 +646,19 @@
     }
 }
 
+/**
+ * g_datalist_foreach:
+ * @datalist: a datalist.
+ * @func: the function to call for each data element.
+ * @user_data: user data to pass to the function.
+ * 
+ * Calls the given function for each data element of the datalist.
+ * The function is called with each data element's #GQuark id and data,
+ * together with the given @user_data parameter.
+ * Note that this function is NOT thread-safe. So unless @datalist
+ * can be protected from any modifications during invocation of this
+ * function, it should not be called.
+ */
 void
 g_datalist_foreach (GData	   **datalist,
 		    GDataForeachFunc func,
@@ -500,6 +676,13 @@
     }
 }
 
+/**
+ * g_datalist_init:
+ * @datalist: a pointer to a pointer to a datalist.
+ * 
+ * Resets the datalist to %NULL.
+ * It does not free any memory or call any destroy functions.
+ */
 void
 g_datalist_init (GData **datalist)
 {
Index: glib/gdataset.h
===================================================================
--- glib/gdataset.h	(revision 7087)
+++ glib/gdataset.h	(working copy)
@@ -35,8 +35,25 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GData:
+ * 
+ * The #GData struct is an opaque data structure to represent a
+ * <link linkend="glib-Keyed-Data-Lists">Keyed Data List</link>.
+ * It should only be accessed via the following functions.
+ */
 typedef struct _GData           GData;
 
+/**
+ * GDataForeachFunc:
+ * @key_id: the #GQuark id to identifying the data element.
+ * @data: the data element.
+ * @user_data: user data passed to g_dataset_foreach().
+ * 
+ * Specifies the type of function passed to g_dataset_foreach().
+ * It is called with each #GQuark id and associated data element,
+ * together with the @user_data parameter supplied to g_dataset_foreach().
+ */
 typedef void            (*GDataForeachFunc)     (GQuark         key_id,
                                                  gpointer       data,
                                                  gpointer       user_data);
@@ -72,18 +89,90 @@
 					 guint              flags);
 guint    g_datalist_get_flags           (GData            **datalist);
 
+/**
+ * g_datalist_id_set_data:
+ * @dl: a datalist.
+ * @q: the #GQuark to identify the data element.
+ * @d: the data element, or %NULL to remove any previous element
+ *  corresponding to @q.
+ * 
+ * Sets the data corresponding to the given #GQuark id.
+ * Any previous data with the same key is removed, and its
+ * destroy function is called.
+ */
 #define   g_datalist_id_set_data(dl, q, d)      \
      g_datalist_id_set_data_full ((dl), (q), (d), NULL)
+
+/**
+ * g_datalist_id_remove_data:
+ * @dl: a datalist.
+ * @q: the #GQuark identifying the data element.
+ * 
+ * Removes an element, using its #GQuark identifier.
+ */
 #define   g_datalist_id_remove_data(dl, q)      \
      g_datalist_id_set_data ((dl), (q), NULL)
+     
+/**
+ * g_datalist_get_data:
+ * @dl: a datalist.
+ * @k: the string identifying a data element.
+ * 
+ * Gets a data element, using its string identifer.
+ * This is slower than g_datalist_id_get_data() because the string is first
+ * converted to a #GQuark.
+ * 
+ * Returns: the data element, or %NULL if it is not found.
+ */
 #define   g_datalist_get_data(dl, k)            \
      (g_datalist_id_get_data ((dl), g_quark_try_string (k)))
+     
+/**
+ * g_datalist_set_data_full:
+ * @dl: a datalist.
+ * @k: the string to identify the data element.
+ * @d: the data element, or %NULL to remove any previous element corresponding to
+ *  @k.
+ * @f: the function to call when the data element is removed. This
+ *  function will be called with the data element and can be used to free any
+ *  memory allocated for it. If @d is %NULL, then @f must also be %NULL.
+ * 
+ * Sets the data element corresponding to the given string identifier, and the
+ * function to be called when the data element is removed.
+ */
 #define   g_datalist_set_data_full(dl, k, d, f) \
      g_datalist_id_set_data_full ((dl), g_quark_from_string (k), (d), (f))
+
+/**
+ * g_datalist_remove_no_notify:
+ * @dl: a datalist.
+ * @k: the string identifying the data element.
+ * 
+ * Removes an element, without calling its destroy notifier.
+ */
 #define   g_datalist_remove_no_notify(dl, k)    \
      g_datalist_id_remove_no_notify ((dl), g_quark_try_string (k))
+
+/**
+ * g_datalist_set_data:
+ * @dl: a datalist.
+ * @k: the string to identify the data element.
+ * @d: the data element, or %NULL to remove any previous element
+ *  corresponding to @k.
+ * 
+ * Sets the data element corresponding to the given string identifier.
+ */
 #define   g_datalist_set_data(dl, k, d)         \
      g_datalist_set_data_full ((dl), (k), (d), NULL)
+
+/**
+ * g_datalist_remove_data:
+ * @dl: a datalist.
+ * @k: the string identifying the data element.
+ * 
+ * Removes an element using its string identifier.
+ * The data element's destroy function is called if it has been set.
+ */
 #define   g_datalist_remove_data(dl, k)         \
      g_datalist_id_set_data ((dl), g_quark_try_string (k), NULL)
 
@@ -102,18 +191,90 @@
 void      g_dataset_foreach             (gconstpointer    dataset_location,
                                          GDataForeachFunc func,
                                          gpointer         user_data);
+
+
+
+/**
+ * g_dataset_id_set_data:
+ * @l: the location identifying the dataset.
+ * @k: the #GQuark id to identify the data element.
+ * @d: the data element.
+ * 
+ * Sets the data element associated with the given #GQuark id.
+ * Any previous data with the same key is removed, and its destroy function
+ * is called.
+ */
 #define   g_dataset_id_set_data(l, k, d)        \
      g_dataset_id_set_data_full ((l), (k), (d), NULL)
+
+/**
+ * g_dataset_id_remove_data:
+ * @l: the location identifying the dataset.
+ * @k: the #GQuark id identifying the data element.
+ * 
+ * Removes a data element from a dataset.
+ * The data element's destroy function is called if it has been set.
+ */
 #define   g_dataset_id_remove_data(l, k)        \
      g_dataset_id_set_data ((l), (k), NULL)
+
+/**
+ * g_dataset_get_data:
+ * @l: the location identifying the dataset.
+ * @k: the string identifying the data element.
+ * 
+ * Gets the data element corresponding to a string.
+ * 
+ * Returns: the data element corresponding to the string, or %NULL if it is not
+ *  found.
+ */
 #define   g_dataset_get_data(l, k)              \
      (g_dataset_id_get_data ((l), g_quark_try_string (k)))
+
+/**
+ * g_dataset_set_data_full:
+ * @l: the location identifying the dataset.
+ * @k: the string to identify the data element.
+ * @d: the data element.
+ * @f: the function to call when the data element is removed. This
+ *  function will be called with the data element and can be used to free any
+ *  memory allocated for it.
+ * 
+ * Sets the data corresponding to the given string identifier, and the function
+ * to call when the data element is destroyed.
+ */
 #define   g_dataset_set_data_full(l, k, d, f)   \
      g_dataset_id_set_data_full ((l), g_quark_from_string (k), (d), (f))
+
+/**
+ * g_dataset_remove_no_notify:
+ * @l: the location identifying the dataset.
+ * @k: the string identifying the data element.
+ * 
+ * Removes an element, without calling its destroy notifier.
+ */
 #define   g_dataset_remove_no_notify(l, k)      \
      g_dataset_id_remove_no_notify ((l), g_quark_try_string (k))
+
+/**
+ * g_dataset_set_data:
+ * @l: the location identifying the dataset.
+ * @k: the string to identify the data element.
+ * @d: the data element.
+ * 
+ * Sets the data corresponding to the given string identifier.
+ */
 #define   g_dataset_set_data(l, k, d)           \
      g_dataset_set_data_full ((l), (k), (d), NULL)
+
+/**
+ * g_dataset_remove_data:
+ * @l: the location identifying the dataset.
+ * @k: the string identifying the data element.
+ * 
+ * Removes a data element corresponding to a string.
+ * Its destroy function is called if it has been set.
+ */
 #define   g_dataset_remove_data(l, k)           \
      g_dataset_id_set_data ((l), g_quark_try_string (k), NULL)
 
Index: glib/gslist.c
===================================================================
--- glib/gslist.c	(revision 7087)
+++ glib/gslist.c	(working copy)
@@ -33,14 +33,95 @@
 #include "glib.h"
 #include "galias.h"
 
+/**
+ * SECTION:linked_lists_single
+ * @Short_description: linked lists containing integer values or pointers 
+ * to data, limited to iterating over the list in one direction
+ * @Title: Singly-Linked Lists
+ * 
+ * The #GSList structure and its associated functions provide a standard
+ * singly-linked list data structure.
+ * 
+ * Each element in the list contains a piece of data, together with a pointer
+ * which links to the next element in the list.
+ * Using this pointer it is possible to move through the list in one
+ * direction only (unlike the
+ * <link linkend="glib-Doubly-Linked-lists">Doubly-Linked Lists</link>
+ * which allow movement in both directions).
+ * 
+ * The data contained in each element can be either integer values, by using one
+ * of the
+ * <link linkend="glib-Type-Conversion-Macros">Type Conversion Macros</link>,
+ * or simply pointers to any type of data.
+ * 
+ * List elements are allocated from the <link linkend="glib-Memory-Slices">slice
+ * allocator</link>, which is more efficient than allocating elements 
+ * individually.
+ * 
+ * Note that most of the #GSList functions expect to be passed a pointer to
+ * the first element in the list. The functions which insert elements return
+ * the new start of the list, which may have changed.
+ * 
+ * There is no function to create a #GSList. %NULL is considered to be the empty
+ * list so you simply set a #GSList* to %NULL.
+ * 
+ * To add elements, use g_slist_append(), g_slist_prepend(), g_slist_insert()
+ * and g_slist_insert_sorted().
+ * 
+ * To remove elements, use g_slist_remove().
+ * 
+ * To find elements in the list use g_slist_last(), g_slist_next(),
+ * g_slist_nth(), g_slist_nth_data(), g_slist_find() and
+ * g_slist_find_custom().
+ * 
+ * To find the index of an element use g_slist_position() and g_slist_index().
+ * 
+ * To call a function for each element in the list use g_slist_foreach().
+ * 
+ * To free the entire list, use g_slist_free().
+ */
 
+/**
+ * g_slist_push_allocator:
+ * @dummy: the #GAllocator to use when allocating #GSList elements.
+ * 
+ * Sets the allocator to use to allocate #GSList elements.
+ * Use g_slist_pop_allocator() to restore the previous allocator.
+ * 
+ * Note that this function is not available if GLib has been compiled
+ * with <option>--disable-mem-pools</option>
+ * 
+ * Deprecated: 2.10: It does nothing, since #GSList has been
+ *  converted to the <link linkend="glib-Memory-Slices">slice allocator</link>
+ */
 void g_slist_push_allocator (gpointer dummy) { /* present for binary compat only */ }
+
+/**
+ * g_slist_pop_allocator:
+ * 
+ * Restores the previous #GAllocator, used when allocating #GSList elements.
+ * 
+ * Note that this function is not available if GLib has been compiled
+ * with <option>--disable-mem-pools</option>
+ * 
+ * Deprecated: 2.10: It does nothing, since #GSList has been
+ *  converted to the <link linkend="glib-Memory-Slices">slice allocator</link>
+ */
 void g_slist_pop_allocator  (void)           { /* present for binary compat only */ }
 
 #define _g_slist_alloc0()       g_slice_new0 (GSList)
 #define _g_slist_alloc()        g_slice_new (GSList)
 #define _g_slist_free1(slist)   g_slice_free (GSList, slist)
 
+/**
+ * g_slist_alloc:
+ * 
+ * Allocates space for one #GSList element.
+ * It is called by the g_slist_append(), g_slist_prepend(), g_slist_insert() and
+ * g_slist_insert_sorted() functions and so is rarely used on its own.
+ * 
+ * Returns: a pointer to the newly-allocated #GSList element.
+ */
 GSList*
 g_slist_alloc (void)
 {
Index: glib/galloca.h
===================================================================
--- glib/galloca.h	(revision 7087)
+++ glib/galloca.h	(working copy)
@@ -57,7 +57,50 @@
 # endif /* !_MSC_VER && !__DMC__ */
 #endif /* !__GNUC__ && !GLIB_HAVE_ALLOCA_H */
 
+/**
+ * g_alloca:
+ * @size: number of bytes to allocate.
+ * 
+ * Allocates @size bytes on the stack; these bytes will be freed when the current
+ * stack frame is cleaned up. This macro essentially just wraps the alloca() 
+ * function present on most UNIX variants. 
+ * Thus it provides the same advantages and pitfalls as alloca():
+ * <variablelist>
+ *     + alloca() is very fast, as on most systems it's implemented by just adjusting
+ *     the stack pointer register.
+ *   </para></listitem></varlistentry>
+ *     + It doesn't cause any memory fragmentation, within its scope, separate alloca()
+ *     blocks just build up and are released together at function end.
+ *   </para></listitem></varlistentry>
+ *     - Allocation sizes have to fit into the current stack frame. For instance in a
+ *       threaded environment on Linux, the per-thread stack size is limited to 2 Megabytes,
+ *       so be sparse with alloca() uses.
+ *   </para></listitem></varlistentry>
+ *     - Allocation failure due to insufficient stack space is not indicated with a %NULL
+ *       return like e.g. with malloc(). Instead, most systems probably handle it the same
+ *       way as out of stack space situations from infinite function recursion, i.e.
+ *       with a segmentation fault.
+ *   </para></listitem></varlistentry>
+ *     - Special care has to be taken when mixing alloca() with GNU C variable sized arrays.
+ *       Stack space allocated with alloca() in the same scope as a variable sized array
+ *       will be freed together with the variable sized array upon exit of that scope, and
+ *       not upon exit of the enclosing function scope.
+ *   </para></listitem></varlistentry>
+ * </variablelist>
+ * 
+ * Returns: space for @size bytes, allocated on the stack
+ */
 #define g_alloca(size)		 alloca (size)
+
+/**
+ * g_newa:
+ * @struct_type: Type of memory chunks to be allocated
+ * @n_structs: Number of chunks to be allocated
+ * 
+ * Wraps g_alloca() in a more typesafe manner.
+ * 
+ * Returns: Pointer to stack space for @n_structs chunks of type @struct_type
+ */
 #define g_newa(struct_type, n_structs)	((struct_type*) g_alloca (sizeof (struct_type) * (gsize) (n_structs)))
 
 #endif /* __G_ALLOCA_H__ */
Index: glib/gcache.c
===================================================================
--- glib/gcache.c	(revision 7087)
+++ glib/gcache.c	(working copy)
@@ -33,6 +33,23 @@
 #include "glib.h"
 #include "galias.h"
 
+/**
+ * SECTION:caches
+ * @Short_description: caches allow sharing of complex data structures to save resources
+ * @Title: Caches
+ * 
+ * A #GCache allows sharing of complex data structures, in order to save
+ * system resources.
+ * 
+ * GTK+ uses caches for #GtkStyles and #GdkGCs. These consume a lot of
+ * resources, so a #GCache is used to see if a #GtkStyle or #GdkGC with the
+ * required properties already exists. If it does, then the existing
+ * object is used instead of creating a new one.
+ * 
+ * #GCache uses keys and values.
+ * A #GCache key describes the properties of a particular resource.
+ * A #GCache value is the actual resource.
+ */
 
 typedef struct _GCacheNode  GCacheNode;
 
@@ -79,6 +96,28 @@
   g_slice_free (GCacheNode, node);
 }
 
+/**
+ * g_cache_new:
+ * @value_new_func: a function to create a new object given a key.
+ *  This is called by g_cache_insert() if an object with the given key
+ *  does not already exist.
+ * @value_destroy_func: a function to destroy an object. It is
+ *  called by g_cache_remove() when the object is no longer needed (i.e. its
+ *  reference count drops to 0).
+ * @key_dup_func: a function to copy a key. It is called by
+ *  g_cache_insert() if the key does not already exist in the #GCache.
+ * @key_destroy_func: a function to destroy a key. It is
+ *  called by g_cache_remove() when the object is no longer needed (i.e. its
+ *  reference count drops to 0).
+ * @hash_key_func: a function to create a hash value from a key.
+ * @hash_value_func: a function to create a hash value from a value.
+ * @key_equal_func: a function to compare two keys. It should return %TRUE if
+ *  the two keys are equivalent.
+ * 
+ * Creates a new #GCache.
+ * 
+ * Returns: a new #GCache.
+ */
 GCache*
 g_cache_new (GCacheNewFunc      value_new_func,
 	     GCacheDestroyFunc  value_destroy_func,
@@ -109,6 +148,15 @@
   return cache;
 }
 
+/**
+ * g_cache_destroy:
+ * @cache: a #GCache.
+ * 
+ * Frees the memory allocated for the #GCache.
+ * 
+ * Note that it does not destroy the keys and values which were contained in the
+ * #GCache.
+ */
 void
 g_cache_destroy (GCache *cache)
 {
@@ -119,6 +167,23 @@
   g_slice_free (GCache, cache);
 }
 
+/**
+ * g_cache_insert:
+ * @cache: a #GCache.
+ * @key: a key describing a #GCache object.
+ * 
+ * Gets the value corresponding to the given key, creating it if necessary.
+ * It first checks if the value already exists in the #GCache, by using
+ * the @key_equal_func function passed to g_cache_new().
+ * If it does already exist it is returned, and its reference count is increased
+ * by one.
+ * If the value does not currently exist, if is created by calling the
+ * @value_new_func. The key is duplicated by calling
+ * @key_dup_func and the duplicated key and value are inserted
+ * into the #GCache.
+ * 
+ * Returns: a pointer to a #GCache value.
+ */
 gpointer
 g_cache_insert (GCache   *cache,
 		gpointer  key)
@@ -145,6 +210,15 @@
   return node->value;
 }
 
+/**
+ * g_cache_remove:
+ * @cache: a #GCache.
+ * @value: the value to remove.
+ * 
+ * Decreases the reference count of the given value.
+ * If it drops to 0 then the value and its corresponding key are destroyed,
+ * using the @value_destroy_func and @key_destroy_func passed to g_cache_new().
+ */
 void
 g_cache_remove (GCache        *cache,
 		gconstpointer  value)
@@ -171,6 +245,20 @@
     }
 }
 
+/**
+ * g_cache_key_foreach:
+ * @cache: a #GCache.
+ * @func: the function to call with each #GCache key.
+ * @user_data: user data to pass to the function.
+ * 
+ * Calls the given function for each of the keys in the #GCache.
+ * 
+ * <note><para>@func is passed three parameters, the value and key of a
+ * cache entry and the @user_data. The order of value and key is different
+ * from the order in which g_hash_table_foreach() passes key-value pairs
+ * to its callback function !
+ * </para></note>
+ */
 void
 g_cache_key_foreach (GCache   *cache,
 		     GHFunc    func,
@@ -182,6 +270,17 @@
   g_hash_table_foreach (cache->value_table, func, user_data);
 }
 
+/**
+ * g_cache_value_foreach:
+ * @cache: a #GCache.
+ * @func: the function to call with each #GCache value.
+ * @user_data: user data to pass to the function.
+ * 
+ * Calls the given function for each of the values in the #GCache.
+ * 
+ * Deprecated: 2.10: The reason is that it passes pointers to internal data 
+ *  structures to @func; use g_cache_key_foreach() instead
+ */
 void
 g_cache_value_foreach (GCache   *cache,
 		       GHFunc    func,
Index: glib/gslist.h
===================================================================
--- glib/gslist.h	(revision 7087)
+++ glib/gslist.h	(working copy)
@@ -35,6 +35,15 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GSList:
+ * @data: holds the element's data, which can be a pointer to any kind of data, 
+ *  or any integer value using the 
+ *  <link linkend="glib-Type-Conversion-Macros">Type Conversion Macros</link>.
+ * @next: contains the link to the next element in the list.
+ * 
+ * The #GSList struct is used for each element in the singly-linked list.
+ */
 typedef struct _GSList GSList;
 
 struct _GSList
@@ -48,6 +57,14 @@
 GSList*  g_slist_alloc                   (void) G_GNUC_WARN_UNUSED_RESULT;
 void     g_slist_free                    (GSList           *list);
 void     g_slist_free_1                  (GSList           *list);
+
+/**
+ * g_slist_free1:
+ * 
+ * A macro which does the same as g_slist_free_1().
+ * 
+ * Since: 2.10
+ */
 #define	 g_slist_free1		         g_slist_free_1
 GSList*  g_slist_append                  (GSList           *list,
 					  gpointer          data) G_GNUC_WARN_UNUSED_RESULT;
@@ -102,6 +119,14 @@
 gpointer g_slist_nth_data                (GSList           *list,
 					  guint             n);
 
+/**
+ * g_slist_next:
+ * @slist: an element in a #GSList.
+ * 
+ * A convenience macro to gets the next element in a #GSList.
+ * 
+ * Returns: the next element, or %NULL if there are no more elements.
+ */
 #define  g_slist_next(slist)	         ((slist) ? (((GSList *)(slist))->next) : NULL)
 
 #ifndef G_DISABLE_DEPRECATED
Index: glib/gcache.h
===================================================================
--- glib/gcache.h	(revision 7087)
+++ glib/gcache.h	(working copy)
@@ -35,10 +35,46 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GCache:
+ * 
+ * The #GCache struct is an opaque data structure containing information about
+ * a #GCache. It should only be accessed via the following functions.
+ */
 typedef struct _GCache          GCache;
+/**
+ * GCacheNewFunc:
+ * @key: a #GCache key.
+ * 
+ * Specifies the type of the @value_new_func function passed to g_cache_new().
+ * It is passed a #GCache key and should create the value corresponding to the
+ * key.
+ * 
+ * Returns: a new #GCache value corresponding to the key.
+ */
+typedef gpointer        (*GCacheNewFunc)        (gpointer       key);
 
-typedef gpointer        (*GCacheNewFunc)        (gpointer       key);
+/**
+ * GCacheDupFunc:
+ * @value: the #GCache key to destroy (<emphasis>not</emphasis> a #GCache value as it seems).
+ * 
+ * Specifies the type of the @key_dup_func function passed to g_cache_new().
+ * The function is passed a key (<emphasis>not</emphasis> a value as the prototype implies) and
+ * should return a duplicate of the key.
+ * 
+ * Returns: a copy of the #GCache key.
+ */
 typedef gpointer        (*GCacheDupFunc)        (gpointer       value);
+
+/**
+ * GCacheDestroyFunc:
+ * @value: the #GCache value to destroy.
+ * 
+ * Specifies the type of the @value_destroy_func and @key_destroy_func functions
+ * passed to g_cache_new().
+ * The functions are passed a pointer to the #GCache key or #GCache value and
+ * should free any memory and other resources associated with it.
+ */
 typedef void            (*GCacheDestroyFunc)    (gpointer       value);
 
 /* Caches
Index: glib/gtimer.c
===================================================================
--- glib/gtimer.c	(revision 7087)
+++ glib/gtimer.c	(working copy)
@@ -55,6 +55,23 @@
 
 #define GETTIME(v) (v = g_thread_gettime ())
 
+/**
+ * SECTION:timers
+ * @Short_description: keep track of elapsed time
+ * @Title: Timers
+ * 
+ * #GTimer records a start time, and counts microseconds elapsed since that time.
+ * This is done somewhat differently on different platforms, and can be tricky to
+ * get exactly right, so #GTimer provides a portable/convenient interface.
+ * 
+ * #GTimer uses a higher-quality clock when thread support is available. 
+ * Therefore, calling g_thread_init() while timers are running may lead to
+ * unreliable results. It is best to call g_thread_init() before starting
+ * any timers, if you are using threads at all.
+ * </para></note>
+ */
+
+
 struct _GTimer
 {
   guint64 start;
@@ -63,7 +80,14 @@
   guint active : 1;
 };
 
-
+/**
+ * g_timer_new:
+ * 
+ * Creates a new timer, and starts timing (i.e. g_timer_start() is implicitly
+ * called for you).
+ * 
+ * Returns: a new #GTimer.
+ */
 GTimer*
 g_timer_new (void)
 {
@@ -77,6 +101,12 @@
   return timer;
 }
 
+/**
+ * g_timer_destroy:
+ * @timer: a #GTimer to destroy.
+ * 
+ * Destroys a timer, freeing associated resources.
+ */
 void
 g_timer_destroy (GTimer *timer)
 {
@@ -85,6 +115,15 @@
   g_free (timer);
 }
 
+/**
+ * g_timer_start:
+ * @timer: a #GTimer.
+ * 
+ * Marks a start time, so that future calls to g_timer_elapsed() will report the
+ * time since g_timer_start() was called. g_timer_new() automatically marks the
+ * start time, so no need to call g_timer_start() immediately after creating the
+ * timer.
+ */
 void
 g_timer_start (GTimer *timer)
 {
@@ -95,6 +134,13 @@
   GETTIME (timer->start);
 }
 
+/**
+ * g_timer_stop:
+ * @timer: a #GTimer.
+ * 
+ * Marks an end time, so calls to g_timer_elapsed() will return the difference
+ * between this end time and the start time.
+ */
 void
 g_timer_stop (GTimer *timer)
 {
@@ -105,6 +151,14 @@
   GETTIME (timer->end);
 }
 
+/**
+ * g_timer_reset:
+ * @timer: a #GTimer.
+ * 
+ * This function is useless; it's fine to call g_timer_start() on an
+ * already-started timer to reset the start time, so g_timer_reset() serves no
+ * purpose.
+ */
 void
 g_timer_reset (GTimer *timer)
 {
@@ -113,6 +167,15 @@
   GETTIME (timer->start);
 }
 
+/**
+ * g_timer_continue:
+ * @timer: a #GTimer.
+ * 
+ * Resumes a timer that has previously been stopped with g_timer_stop().
+ * g_timer_stop() must be called before using this function.
+ * 
+ * Since: 2.4
+ */
 void
 g_timer_continue (GTimer *timer)
 {
@@ -135,6 +198,25 @@
   timer->active = TRUE;
 }
 
+/**
+ * g_timer_elapsed:
+ * @timer: a #GTimer.
+ * @microseconds: return location for the fractional part of seconds elapsed, 
+ *  in microseconds (that is, the total number of microseconds elapsed, modulo 
+ *  1000000), or %NULL
+ * 
+ * If @timer has been started but not stopped, obtains the time since the timer was
+ * started. If @timer has been stopped, obtains the elapsed time between the time
+ * it was started and the time it was stopped. The return value is the number of
+ * seconds elapsed, including any fractional part. The @microseconds
+ * out parameter is essentially useless.
+ * <warning><para>Calling initialization functions, in particular g_thread_init(),
+ * while a timer is running will cause invalid return values from this function.
+ * </para></warning>
+ * 
+ * Returns: seconds elapsed as a floating point value, including 
+ *  any fractional part.
+ */
 gdouble
 g_timer_elapsed (GTimer *timer,
 		 gulong *microseconds)
@@ -157,6 +239,16 @@
   return total;
 }
 
+/**
+ * g_usleep:
+ * @microseconds: number of microseconds to pause
+ * 
+ * Pauses the current thread for the given number of microseconds. There
+ * are 1 million microseconds per second (represented by the
+ * #G_USEC_PER_SEC macro). g_usleep() may have limited precision,
+ * depending on hardware and operating system; don't rely on the exact
+ * length of the sleep.
+ */
 void
 g_usleep (gulong microseconds)
 {
Index: glib/gtimer.h
===================================================================
--- glib/gtimer.h	(revision 7087)
+++ glib/gtimer.h	(working copy)
@@ -35,12 +35,19 @@
 
 G_BEGIN_DECLS
 
-/* Timer
+/**
+ * GTimer:
+ * 
+ * Opaque datatype that records a start time.
  */
-
-/* microseconds per second */
 typedef struct _GTimer		GTimer;
 
+/**
+ * G_USEC_PER_SEC:
+ * 
+ * Number of microseconds in one second (1 million). This macro is provided for
+ * code readability.
+ */
 #define G_USEC_PER_SEC 1000000
 
 GTimer*  g_timer_new	         (void);
Index: glib/gprimes.c
===================================================================
--- glib/gprimes.c	(revision 7087)
+++ glib/gprimes.c	(working copy)
@@ -74,6 +74,20 @@
 
 static const guint g_nprimes = sizeof (g_primes) / sizeof (g_primes[0]);
 
+/**
+ * g_spaced_primes_closest:
+ * @num: a #guint.
+ * 
+ * Gets the smallest prime number from a built-in array of primes which
+ * is larger than @num. This is used within GLib to calculate the optimum
+ * size of a #GHashTable.
+ * 
+ * The built-in array of primes ranges from 11 to 13845163 such that
+ * each prime is approximately 1.5-2 times the previous prime.
+ * 
+ * Returns: the smallest prime number from a built-in array of primes which is
+ *  larger than @num.
+ */
 guint
 g_spaced_primes_closest (guint num)
 {
Index: glib/giochannel.c
===================================================================
--- glib/giochannel.c	(revision 7087)
+++ glib/giochannel.c	(working copy)
@@ -50,6 +50,60 @@
 
 #include "galias.h"
 
+/**
+ * SECTION:iochannels
+ * @Short_description: portable support for using files, pipes and sockets
+ * @Title: IO Channels
+ * @See_also:<variablelist>
+ * 
+ * <varlistentry>
+ * <term>gtk_input_add_full(), gtk_input_remove(), gdk_input_add(),
+ * gdk_input_add_full(), gdk_input_remove()</term>
+ * Convenience functions for creating #GIOChannel instances and adding them to the
+ * <link linkend="glib-The-Main-Event-Loop">main event loop</link>.
+ * </para></listitem>
+ * </varlistentry>
+ * 
+ * </variablelist>
+ * 
+ * The #GIOChannel data type aims to provide a portable method for using file
+ * descriptors, pipes, and sockets, and integrating them into the
+ * <link linkend="glib-The-Main-Event-Loop">main event loop</link>.
+ * Currently full support is available on UNIX platforms, support for
+ * Windows is only partially complete.
+ * 
+ * To create a new #GIOChannel on UNIX systems use g_io_channel_unix_new().
+ * This works for plain file descriptors, pipes and sockets.
+ * Alternatively, a channel can be created for a file in a system independent
+ * manner using g_io_channel_new_file().
+ * 
+ * Once a #GIOChannel has been created, it can be used in a generic manner
+ * with the functions g_io_channel_read_chars(), g_io_channel_write_chars(),
+ * g_io_channel_seek_position(), and g_io_channel_shutdown().
+ * 
+ * To add a #GIOChannel to the 
+ * <link linkend="glib-The-Main-Event-Loop">main event loop</link>
+ * use g_io_add_watch() or g_io_add_watch_full(). Here you specify which events
+ * you are interested in on the #GIOChannel, and provide a function to be
+ * called whenever these events occur.
+ * 
+ * #GIOChannel instances are created with an initial reference count of 1.
+ * g_io_channel_ref() and g_io_channel_unref() can be used to increment or
+ * decrement the reference count respectively. When the reference count falls
+ * to 0, the #GIOChannel is freed. (Though it isn't closed automatically,
+ * unless it was created using g_io_channel_new_from_file().)
+ * Using g_io_add_watch() or g_io_add_watch_full() increments a channel's
+ * reference count.
+ * 
+ * The new functions g_io_channel_read_chars(), g_io_channel_read_line(),
+ * g_io_channel_read_line_string(), g_io_channel_read_to_end(),
+ * g_io_channel_write_chars(), g_io_channel_seek_position(),
+ * and g_io_channel_flush() should not be mixed with the
+ * deprecated functions g_io_channel_read(), g_io_channel_write(),
+ * and g_io_channel_seek() on the same channel.
+ */
+
+
 #define G_IO_NICE_BUF_SIZE	1024
 
 /* This needs to be as wide as the largest character in any possible encoding */
@@ -73,6 +127,15 @@
 							 gsize       *terminator_pos,
 							 GError     **error);
 
+/**
+ * g_io_channel_init:
+ * @channel: a #GIOChannel
+ * 
+ * Initializes a #GIOChannel struct. This is called by each of the 
+ * above functions when creating a #GIOChannel, and so is not often 
+ * needed by the application programmer (unless you are creating a 
+ * new type of #GIOChannel).
+ */
 void
 g_io_channel_init (GIOChannel *channel)
 {
@@ -92,6 +155,14 @@
   channel->close_on_unref = FALSE;
 }
 
+/**
+ * g_io_channel_ref:
+ * @channel: a #GIOChannel.
+ * 
+ * Increments the reference count of a #GIOChannel.
+ * 
+ * Returns: the @channel that was passed in (since 2.6)
+ */
 GIOChannel *
 g_io_channel_ref (GIOChannel *channel)
 {
@@ -102,6 +173,12 @@
   return channel;
 }
 
+/**
+ * g_io_channel_unref:
+ * @channel: a #GIOChannel.
+ * 
+ * Decrements the reference count of a #GIOChannel.
+ */
 void 
 g_io_channel_unref (GIOChannel *channel)
 {
@@ -465,6 +542,23 @@
     }
 }
 
+/**
+ * g_io_create_watch:
+ * @channel: a #GIOChannel to watch
+ * @condition: conditions to watch for
+ * 
+ * Creates a #GSource that's dispatched when @condition is met for the given
+ * @channel. For example, if condition is #G_IO_IN, the source will be dispatched
+ * when there's data available for reading.  g_io_add_watch() is a simpler
+ * interface to this same functionality, for the case where you want to add the
+ * source to the default main loop at the default priority.
+ * 
+ * On Windows, polling a #GSource created to watch a channel for a socket
+ * puts the socket in non-blocking mode. This is a side-effect of the
+ * implementation and unavoidable.
+ * 
+ * Returns: a new #GSource
+ */
 GSource *
 g_io_create_watch (GIOChannel   *channel,
 		   GIOCondition  condition)
@@ -474,6 +568,21 @@
   return channel->funcs->io_create_watch (channel, condition);
 }
 
+/**
+ * g_io_add_watch_full:
+ * @channel: a #GIOChannel
+ * @priority: the priority of the #GIOChannel source
+ * @condition: the condition to watch for
+ * @func: the function to call when the condition is satisfied
+ * @user_data: user data to pass to @func
+ * @notify: the function to call when the source is removed
+ * 
+ * Adds the #GIOChannel into the
+ * <link linkend="glib-The-Main-Event-Loop">main event loop</link>
+ * with the given priority.
+ * 
+ * Returns: the event source id
+ */
 guint 
 g_io_add_watch_full (GIOChannel    *channel,
 		     gint           priority,
@@ -499,6 +608,19 @@
   return id;
 }
 
+/**
+ * g_io_add_watch:
+ * @channel: a #GIOChannel
+ * @condition: the condition to watch for
+ * @func: the function to call when the condition is satisfied
+ * @user_data: user data to pass to @func
+ * 
+ * Adds the #GIOChannel into the
+ * <link linkend="glib-The-Main-Event-Loop">main event loop</link>
+ * with the default priority.
+ * 
+ * Returns: the event source id
+ */
 guint 
 g_io_add_watch (GIOChannel   *channel,
 		GIOCondition  condition,
Index: glib/ghook.c
===================================================================
--- glib/ghook.c	(revision 7087)
+++ glib/ghook.c	(working copy)
@@ -36,6 +36,15 @@
 #include "glib.h"
 #include "galias.h"
 
+/**
+ * SECTION:hooks
+ * @Short_description: support for manipulating lists of hook functions
+ * @Title: Hook Functions
+ * 
+ * The #GHookList, #GHook and their related functions provide support for
+ * lists of hook functions. Functions can be added and removed from the lists,
+ * and the list of hook functions can be invoked.
+ */
 
 /* --- functions --- */
 static void
@@ -51,6 +60,15 @@
     }
 }
 
+/**
+ * g_hook_list_init:
+ * @hook_list: a #GHookList
+ * @hook_size: the size of each element in the #GHookList, typically
+ *  <literal>sizeof (GHook)</literal>
+ * 
+ * Initializes a #GHookList.
+ * This must be called before the #GHookList is used.
+ */
 void
 g_hook_list_init (GHookList *hook_list,
 		  guint	     hook_size)
@@ -68,6 +86,12 @@
   hook_list->dummy[1] = NULL;
 }
 
+/**
+ * g_hook_list_clear:
+ * @hook_list: a #GHookList
+ * 
+ * Removes all the #GHook elements from a #GHookList.
+ */
 void
 g_hook_list_clear (GHookList *hook_list)
 {
@@ -99,6 +123,14 @@
     }
 }
 
+/**
+ * g_hook_alloc:
+ * @hook_list: a #GHookList
+ * 
+ * Allocates space for a #GHook and initializes it.
+ * 
+ * Returns: a new #GHook
+ */
 GHook*
 g_hook_alloc (GHookList *hook_list)
 {
@@ -120,6 +152,14 @@
   return hook;
 }
 
+/**
+ * g_hook_free:
+ * @hook_list: a #GHookList
+ * @hook: the #GHook to free
+ * 
+ * Calls the #GHookList @finalize_hook function if it exists, and frees the memory
+ * allocated for the #GHook.
+ */
 void
 g_hook_free (GHookList *hook_list,
 	     GHook     *hook)
@@ -135,6 +175,14 @@
   g_slice_free1 (hook_list->hook_size, hook);
 }
 
+/**
+ * g_hook_destroy_link:
+ * @hook_list: a #GHookList
+ * @hook: the #GHook to remove
+ * 
+ * Removes one #GHook from a #GHookList, marking it inactive and calling
+ * g_hook_unref() on it. 
+ */
 void
 g_hook_destroy_link (GHookList *hook_list,
 		     GHook     *hook)
@@ -150,6 +198,15 @@
     }
 }
 
+/**
+ * g_hook_destroy:
+ * @hook_list: a #GHookList
+ * @hook_id: a hook ID
+ * 
+ * Destroys a #GHook, given its ID.
+ * 
+ * Returns: %TRUE if the #GHook was found in the #GHookList and destroyed
+ */
 gboolean
 g_hook_destroy (GHookList   *hook_list,
 		gulong	     hook_id)
@@ -169,6 +226,15 @@
   return FALSE;
 }
 
+/**
+ * g_hook_unref:
+ * @hook_list: a #GHookList
+ * @hook: the #GHook to unref
+ * 
+ * Decrements the reference count of a #GHook.
+ * If the reference count falls to 0, the #GHook is removed from the #GHookList
+ * and g_hook_free() is called to free it.
+ */
 void
 g_hook_unref (GHookList *hook_list,
 	      GHook	*hook)
@@ -210,6 +276,15 @@
     }
 }
 
+/**
+ * g_hook_ref:
+ * @hook_list: a #GHookList
+ * @hook: the #GHook to increment the reference count of
+ * 
+ * Increments the reference count for a #GHook.
+ * 
+ * Returns: the @hook that was passed in (since 2.6)
+ */
 GHook *
 g_hook_ref (GHookList *hook_list,
 	    GHook     *hook)
@@ -223,6 +298,13 @@
   return hook;
 }
 
+/**
+ * g_hook_prepend:
+ * @hook_list: a #GHookList
+ * @hook: the #GHook to add to the start of @hook_list
+ * 
+ * Prepends a #GHook on the start of a #GHookList.
+ */
 void
 g_hook_prepend (GHookList *hook_list,
 		GHook	  *hook)
@@ -232,6 +314,14 @@
   g_hook_insert_before (hook_list, hook_list->hooks, hook);
 }
 
+/**
+ * g_hook_insert_before:
+ * @hook_list: a #GHookList
+ * @sibling: the #GHook to insert the new #GHook before
+ * @hook: the #GHook to insert
+ * 
+ * Inserts a #GHook into a #GHookList, before a given #GHook.
+ */
 void
 g_hook_insert_before (GHookList *hook_list,
 		      GHook	*sibling,
@@ -277,6 +367,14 @@
     }
 }
 
+/**
+ * g_hook_list_invoke:
+ * @hook_list: a #GHookList
+ * @may_recurse: %TRUE if functions which are already running (e.g. in another
+ *  thread) can be called. If set to %FALSE, these are skipped
+ * 
+ * Calls all of the #GHook functions in a #GHookList.
+ */
 void
 g_hook_list_invoke (GHookList *hook_list,
 		    gboolean   may_recurse)
@@ -304,6 +402,15 @@
     }
 }
 
+/**
+ * g_hook_list_invoke_check:
+ * @hook_list: a #GHookList
+ * @may_recurse: %TRUE if functions which are already running (e.g. in another
+ *  thread) can be called. If set to %FALSE, these are skipped
+ * 
+ * Calls all of the #GHook functions in a #GHookList.
+ * Any function which returns %FALSE is removed from the #GHookList.
+ */
 void
 g_hook_list_invoke_check (GHookList *hook_list,
 			  gboolean   may_recurse)
@@ -334,6 +441,17 @@
     }
 }
 
+/**
+ * g_hook_list_marshal_check:
+ * @hook_list: a #GHookList
+ * @may_recurse: %TRUE if hooks which are currently running (e.g. in another
+ *  thread) are considered valid. If set to %FALSE, these are skipped
+ * @marshaller: the function to call for each #GHook
+ * @marshal_data: data to pass to @marshaller
+ * 
+ * Calls a function on each valid #GHook and destroys it if the 
+ * function returns %FALSE.
+ */
 void
 g_hook_list_marshal_check (GHookList	       *hook_list,
 			   gboolean		may_recurse,
@@ -364,6 +482,16 @@
     }
 }
 
+/**
+ * g_hook_list_marshal:
+ * @hook_list: a #GHookList
+ * @may_recurse: %TRUE if hooks which are currently running (e.g. in another
+ *  thread) are considered valid. If set to %FALSE, these are skipped
+ * @marshaller: the function to call for each #GHook
+ * @marshal_data: data to pass to @marshaller
+ * 
+ * Calls a function on each valid #GHook. 
+ */
 void
 g_hook_list_marshal (GHookList		     *hook_list,
 		     gboolean		      may_recurse,
@@ -391,6 +519,19 @@
     }
 }
 
+/**
+ * g_hook_first_valid:
+ * @hook_list: a #GHookList
+ * @may_be_in_call: %TRUE if hooks which are currently running (e.g. in another
+ *  thread) are considered valid. If set to %FALSE, these are skipped
+ * 
+ * Returns the first #GHook in a #GHookList which has not been destroyed.
+ * The reference count for the #GHook is incremented, so you must call
+ * g_hook_unref() to restore it when no longer needed. (Or call
+ * g_hook_next_valid() if you are stepping through the #GHookList.)
+ * 
+ * Returns: the first valid #GHook, or %NULL if none are valid
+ */
 GHook*
 g_hook_first_valid (GHookList *hook_list,
 		    gboolean   may_be_in_call)
@@ -415,6 +556,20 @@
   return NULL;
 }
 
+/**
+ * g_hook_next_valid:
+ * @hook_list: a #GHookList
+ * @hook: the current #GHook
+ * @may_be_in_call: %TRUE if hooks which are currently running (e.g. in another
+ *  thread) are considered valid. If set to %FALSE, these are skipped
+ * 
+ * Returns the next #GHook in a #GHookList which has not been destroyed.
+ * The reference count for the #GHook is incremented, so you must call
+ * g_hook_unref() to restore it when no longer needed. (Or continue to call
+ * g_hook_next_valid() until %NULL is returned.)
+ * 
+ * Returns: the next valid #GHook, or %NULL if none are valid
+ */
 GHook*
 g_hook_next_valid (GHookList *hook_list,
 		   GHook     *hook,
@@ -444,6 +599,15 @@
   return NULL;
 }
 
+/**
+ * g_hook_get:
+ * @hook_list: a #GHookList
+ * @hook_id: a hook id
+ * 
+ * Returns the #GHook with the given id, or %NULL if it is not found.
+ * 
+ * Returns: the #GHook with the given id, or %NULL if it is not found
+ */
 GHook*
 g_hook_get (GHookList *hook_list,
 	    gulong     hook_id)
@@ -464,6 +628,19 @@
   return NULL;
 }
 
+/**
+ * g_hook_find:
+ * @hook_list: a #GHookList
+ * @need_valids: %TRUE if #GHook elements which have been destroyed should be
+ *  skipped
+ * @func: the function to call for each #GHook, which should return %TRUE when
+ *  the #GHook has been found
+ * @data: the data to pass to @func
+ * 
+ * Finds a #GHook in a #GHookList using the given function to test for a match.
+ * 
+ * Returns: the found #GHook or %NULL if no matching #GHook is found
+ */
 GHook*
 g_hook_find (GHookList	  *hook_list,
 	     gboolean	   need_valids,
@@ -504,6 +681,18 @@
   return NULL;
 }
 
+/**
+ * g_hook_find_data:
+ * @hook_list: a #GHookList
+ * @need_valids: %TRUE if #GHook elements which have been destroyed should be
+ *  skipped
+ * @data: the data to find
+ * 
+ * Finds a #GHook in a #GHookList with the given data.
+ * 
+ * Returns: the #GHook with the given @data or %NULL if no matching
+ *  #GHook is found
+ */
 GHook*
 g_hook_find_data (GHookList *hook_list,
 		  gboolean   need_valids,
@@ -528,6 +717,18 @@
   return NULL;
 }
 
+/**
+ * g_hook_find_func:
+ * @hook_list: a #GHookList
+ * @need_valids: %TRUE if #GHook elements which have been destroyed should be
+ *  skipped
+ * @func: the function to find
+ * 
+ * Finds a #GHook in a #GHookList with the given function.
+ * 
+ * Returns: the #GHook with the given @func or %NULL if no matching
+ *  #GHook is found
+ */
 GHook*
 g_hook_find_func (GHookList *hook_list,
 		  gboolean   need_valids,
@@ -553,6 +754,19 @@
   return NULL;
 }
 
+/**
+ * g_hook_find_func_data:
+ * @hook_list: a #GHookList
+ * @need_valids: %TRUE if #GHook elements which have been destroyed should be
+ *  skipped
+ * @func: the function to find
+ * @data: the data to find
+ * 
+ * Finds a #GHook in a #GHookList with the given function and data.
+ * 
+ * Returns: the #GHook with the given @func and @data or %NULL if no matching
+ *  #GHook is found
+ */
 GHook*
 g_hook_find_func_data (GHookList *hook_list,
 		       gboolean	  need_valids,
@@ -580,6 +794,14 @@
   return NULL;
 }
 
+/**
+ * g_hook_insert_sorted:
+ * @hook_list: a #GHookList
+ * @hook: the #GHook to insert
+ * @func: the comparison function used to sort the #GHook elements
+ * 
+ * Inserts a #GHook into a #GHookList, sorted by the given function.
+ */
 void
 g_hook_insert_sorted (GHookList	      *hook_list,
 		      GHook	      *hook,
@@ -622,6 +844,16 @@
   g_hook_insert_before (hook_list, sibling, hook);
 }
 
+/**
+ * g_hook_compare_ids:
+ * @new_hook: a #GHook
+ * @sibling: a #GHook to compare with @new_hook
+ * 
+ * Compares the ids of two #GHook elements, returning a negative value
+ * if the second id is greater than the first.
+ * 
+ * Returns: a value &lt;= 0 if the id of @sibling is >= the id of @new_hook
+ */
 gint
 g_hook_compare_ids (GHook *new_hook,
 		    GHook *sibling)
Index: glib/giochannel.h
===================================================================
--- glib/giochannel.h	(revision 7087)
+++ glib/giochannel.h	(working copy)
@@ -37,12 +37,40 @@
 
 G_BEGIN_DECLS
 
-/* GIOChannel
+/**
+ * GIOChannel:
+ * 
+ * A data structure representing an IO Channel. The fields should be considered
+ * private and should only be accessed with the following functions.
  */
+typedef struct _GIOChannel	GIOChannel;
 
-typedef struct _GIOChannel	GIOChannel;
+/**
+ * GIOFuncs:
+ * @io_read: 
+ * @io_write: 
+ * @io_seek: 
+ * @io_close: 
+ * @io_create_watch: 
+ * @io_free: 
+ * @io_set_flags: 
+ * @io_get_flags: 
+ * 
+ * A table of functions used to handle different types of #GIOChannel 
+ * in a generic way.
+ */
 typedef struct _GIOFuncs        GIOFuncs;
 
+/**
+ * GIOError:
+ * @G_IO_ERROR_NONE: no error
+ * @G_IO_ERROR_AGAIN: an EAGAIN error occurred
+ * @G_IO_ERROR_INVAL: an EINVAL error occurred
+ * @G_IO_ERROR_UNKNOWN: another error occurred
+ * 
+ * #GIOError is only used by the deprecated functions g_io_channel_read(),
+ * g_io_channel_write(), and g_io_channel_seek().
+ */
 typedef enum
 {
   G_IO_ERROR_NONE,
@@ -51,8 +79,29 @@
   G_IO_ERROR_UNKNOWN
 } GIOError;
 
+/**
+ * G_IO_CHANNEL_ERROR:
+ * 
+ * Error domain for #GIOChannel operations. Errors in this domain will
+ * be from the #GIOChannelError enumeration. See #GError for information on
+ * error domains.
+ */
 #define G_IO_CHANNEL_ERROR g_io_channel_error_quark()
 
+/**
+ * GIOChannelError:
+ * @G_IO_CHANNEL_ERROR_FBIG: File too large.
+ * @G_IO_CHANNEL_ERROR_INVAL: Invalid argument.
+ * @G_IO_CHANNEL_ERROR_IO: IO error.
+ * @G_IO_CHANNEL_ERROR_ISDIR: File is a directory.
+ * @G_IO_CHANNEL_ERROR_NOSPC: No space left on device.
+ * @G_IO_CHANNEL_ERROR_NXIO: No such device or address.
+ * @G_IO_CHANNEL_ERROR_OVERFLOW: Value too large for defined datatype.
+ * @G_IO_CHANNEL_ERROR_PIPE: Broken pipe.
+ * @G_IO_CHANNEL_ERROR_FAILED: Some other error.
+ * 
+ * Error codes returned by #GIOChannel operations.
+ */
 typedef enum
 {
   /* Derived from errno */
@@ -68,6 +117,15 @@
   G_IO_CHANNEL_ERROR_FAILED
 } GIOChannelError;
 
+/**
+ * GIOStatus:
+ * @G_IO_STATUS_ERROR: An error occurred.
+ * @G_IO_STATUS_NORMAL: Success.
+ * @G_IO_STATUS_EOF: End of file.
+ * @G_IO_STATUS_AGAIN: Resource temporarily unavailable.
+ * 
+ * Stati returned by most of the #GIOFuncs functions. 
+ */
 typedef enum
 {
   G_IO_STATUS_ERROR,
@@ -76,6 +134,15 @@
   G_IO_STATUS_AGAIN
 } GIOStatus;
 
+/**
+ * GSeekType:
+ * @G_SEEK_CUR: the current position in the file.
+ * @G_SEEK_SET: the start of the file.
+ * @G_SEEK_END: the end of the file.
+ * 
+ * An enumeration specifying the base position for a 
+ * g_io_channel_seek_position() operation.
+ */
 typedef enum
 {
   G_SEEK_CUR,
@@ -83,6 +150,19 @@
   G_SEEK_END
 } GSeekType;
 
+/**
+ * GIOCondition:
+ * @G_IO_IN: There is data to read.
+ * @G_IO_OUT: Data can be written (without blocking).
+ * @G_IO_PRI: There is urgent data to read.
+ * @G_IO_ERR: Error condition.
+ * @G_IO_HUP: Hung up (the connection has been broken, usually for pipes 
+ *  and sockets).
+ * @G_IO_NVAL: Invalid request. The file descriptor is not open.
+ * 
+ * A bitwise combination representing a condition to watch for on 
+ * an event source.
+ */
 typedef enum
 {
   G_IO_IN	GLIB_SYSDEF_POLLIN,
@@ -93,6 +173,28 @@
   G_IO_NVAL	GLIB_SYSDEF_POLLNVAL
 } GIOCondition;
 
+/**
+ * GIOFlags:
+ * @G_IO_FLAG_APPEND: turns on append mode, corresponds to %O_APPEND 
+ *  (see the documentation of the UNIX open() syscall).
+ * @G_IO_FLAG_NONBLOCK: turns on nonblocking mode, corresponds to 
+ *  %O_NONBLOCK/%O_NDELAY (see the documentation of the UNIX open() 
+ *  syscall).
+ * @G_IO_FLAG_IS_READABLE: indicates that the io channel is readable. 
+ *  This flag can not be changed.
+ * @G_IO_FLAG_IS_WRITEABLE: indicates that the io channel is writable. 
+ *  This flag can not be changed.
+ * @G_IO_FLAG_IS_SEEKABLE: indicates that the io channel is seekable, 
+ *  i.e. that g_io_channel_seek_position() can be used on it. 
+ *  This flag can not be changed.
+ * @G_IO_FLAG_MASK: 
+ * @G_IO_FLAG_GET_MASK: 
+ * @G_IO_FLAG_SET_MASK: 
+ * 
+ * Specifies properties of a #GIOChannel. Some of the flags can only
+ * be read with g_io_channel_get_flags(), but not changed with
+ * g_io_channel_set_flags(). 
+ */
 typedef enum
 {
   G_IO_FLAG_APPEND = 1 << 0,
@@ -136,6 +238,19 @@
   gpointer reserved2;	
 };
 
+/**
+ * GIOFunc:
+ * @source: the #GIOChannel event source
+ * @condition: the condition which has been satisfied
+ * @data: user data set in g_io_add_watch() or g_io_add_watch_full()
+ * 
+ * Specifies the type of function passed to g_io_add_watch() or
+ * g_io_add_watch_full(), which is called when the requested 
+ * condition on a #GIOChannel is satisfied.
+ * 
+ * Returns: the function should return %FALSE if the event source 
+ *  should be removed
+ */
 typedef gboolean (*GIOFunc) (GIOChannel   *source,
 			     GIOCondition  condition,
 			     gpointer      data);
Index: glib/ghook.h
===================================================================
--- glib/ghook.h	(revision 7087)
+++ glib/ghook.h	(working copy)
@@ -36,28 +36,142 @@
 G_BEGIN_DECLS
 
 
-/* --- typedefs --- */
+/**
+ * GHook:
+ * @data: data which is passed to func when this hook is invoked
+ * @next: pointer to the next hook in the list
+ * @prev: pointer to the previous hook in the list
+ * @ref_count: the reference count of this hook
+ * @hook_id: the id of this hook, which is unique within its list
+ * @flags: flags which are set for this hook. See #GHookFlagMask for
+ *  predefined flags
+ * @func: the function to call when this hook is invoked. The possible 
+ *  signatures for this function are #GHookFunc and #GHookCheckFunc
+ * @destroy: the default <function>finalize_hook</function> function of a 
+ *  #GHookList calls this member of the hook that is being finalized
+ * 
+ * The <structname>GHook</structname> struct represents a single hook 
+ * function in a #GHookList.
+ */
 typedef struct _GHook		GHook;
+
+/**
+ * GHookList:
+ * @seq_id: the next free #GHook id
+ * @hook_size: the size of the #GHookList elements, in bytes
+ * @is_setup: 1 if the #GHookList has been initialized
+ * @hooks: the first #GHook element in the list
+ * @dummy3: unused
+ * @finalize_hook: the function to call to finalize a #GHook element. The
+ *  default behaviour is to call the hooks <function>destroy</function> function
+ * @dummy: unused
+ * 
+ * The <structname>GHookList</structname> struct represents a 
+ * list of hook functions.
+ */
 typedef struct _GHookList	GHookList;
 
+/**
+ * GHookCompareFunc:
+ * @new_hook: the #GHook being inserted
+ * @sibling: the #GHook to compare with @new_hook
+ * 
+ * Defines the type of function used to compare #GHook elements in
+ * g_hook_insert_sorted().
+ * 
+ * Returns: a value &lt;= 0 if @new_hook should be before @sibling
+ */
 typedef gint		(*GHookCompareFunc)	(GHook		*new_hook,
 						 GHook		*sibling);
+/**
+ * GHookFindFunc:
+ * @hook: a #GHook
+ * @data: user data passed to g_hook_find_func()
+ * 
+ * Defines the type of the function passed to g_hook_find().
+ * 
+ * Returns: %TRUE if the required #GHook has been found
+ */
 typedef gboolean	(*GHookFindFunc)	(GHook		*hook,
 						 gpointer	 data);
+
+/**
+ * GHookMarshaller:
+ * @hook: a #GHook
+ * @marshal_data: user data
+ * 
+ * Defines the type of function used by g_hook_list_marshal().
+ */
 typedef void		(*GHookMarshaller)	(GHook		*hook,
 						 gpointer	 marshal_data);
+
+/**
+ * GHookCheckMarshaller:
+ * @hook: a #GHook
+ * @marshal_data: user data
+ * 
+ * Defines the type of function used by g_hook_list_marshal_check().
+ * 
+ * Returns: %FALSE if @hook should be destroyed
+ */
 typedef gboolean	(*GHookCheckMarshaller)	(GHook		*hook,
 						 gpointer	 marshal_data);
+
+/**
+ * GHookFunc:
+ * @data: the data field of the #GHook is passed to the hook function here
+ * 
+ * Defines the type of a hook function that can be invoked
+ * by g_hook_list_invoke().
+ */
 typedef void		(*GHookFunc)		(gpointer	 data);
+
+/**
+ * GHookCheckFunc:
+ * @data: the data field of the #GHook is passed to the hook function here
+ * 
+ * Defines the type of a hook function that can be invoked
+ * by g_hook_list_invoke_check().
+ * 
+ * Returns: %FALSE if the #GHook should be destroyed
+ */
 typedef gboolean	(*GHookCheckFunc)	(gpointer	 data);
+
+/**
+ * GHookFinalizeFunc:
+ * @hook_list: a #GHookList
+ * @hook: the hook in @hook_list that gets finalized
+ * 
+ * Defines the type of function to be called when a hook in a 
+ * list of hooks gets finalized.
+ */
 typedef void		(*GHookFinalizeFunc)	(GHookList      *hook_list,
 						 GHook          *hook);
+
+/**
+ * GHookFlagMask:
+ * @G_HOOK_FLAG_ACTIVE: set if the hook has not been destroyed
+ * @G_HOOK_FLAG_IN_CALL: set if the hook is currently being run
+ * @G_HOOK_FLAG_MASK: A mask covering all bits reserved for
+ *  hook flags; see #G_HOOK_FLAGS_USER_SHIFT
+ * 
+ * Flags used internally in the #GHook implementation.
+ */
 typedef enum
 {
   G_HOOK_FLAG_ACTIVE	    = 1 << 0,
   G_HOOK_FLAG_IN_CALL	    = 1 << 1,
   G_HOOK_FLAG_MASK	    = 0x0f
 } GHookFlagMask;
+
+/**
+ * G_HOOK_FLAG_USER_SHIFT:
+ * 
+ * The position of the first bit which is not reserved for internal
+ * use be the #GHook implementation, i.e. 
+ * <literal>1 << G_HOOK_FLAG_USER_SHIFT</literal> is the first bit
+ * which can be used for application-defined flags.
+ */
 #define G_HOOK_FLAG_USER_SHIFT	(4)
 
 
@@ -86,15 +200,65 @@
 
 
 /* --- macros --- */
+/**
+ * G_HOOK:
+ * @hook: a pointer
+ * 
+ * Casts a pointer to a <literal>GHook*</literal>.
+ */
 #define	G_HOOK(hook)			((GHook*) (hook))
+
+/**
+ * G_HOOK_FLAGS:
+ * @hook: a #GHook
+ * 
+ * Returns the flags of a hook.
+ */
 #define	G_HOOK_FLAGS(hook)		(G_HOOK (hook)->flags)
+
+/**
+ * G_HOOK_ACTIVE:
+ * @hook: a #GHook
+ * 
+ * Returns %TRUE if the #GHook is active, which is normally %TRUE until the #GHook
+ * is destroyed.
+ * 
+ * Returns: %TRUE if the #GHook is active
+ */
 #define	G_HOOK_ACTIVE(hook)		((G_HOOK_FLAGS (hook) & \
 					  G_HOOK_FLAG_ACTIVE) != 0)
+/**
+ * G_HOOK_IN_CALL:
+ * @hook: a #GHook
+ * 
+ * Returns %TRUE if the #GHook function is currently executing.
+ * 
+ * Returns: %TRUE if the #GHook function is currently executing
+ */
 #define	G_HOOK_IN_CALL(hook)		((G_HOOK_FLAGS (hook) & \
 					  G_HOOK_FLAG_IN_CALL) != 0)
+
+/**
+ * G_HOOK_IS_VALID:
+ * @hook: a #GHook
+ * 
+ * Returns %TRUE if the #GHook is valid, i.e. it is in a #GHookList, it is active
+ * and it has not been destroyed.
+ * 
+ * Returns: %TRUE if the #GHook is valid
+ */
 #define G_HOOK_IS_VALID(hook)		(G_HOOK (hook)->hook_id != 0 && \
 					 (G_HOOK_FLAGS (hook) & \
                                           G_HOOK_FLAG_ACTIVE))
+
+/**
+ * G_HOOK_IS_UNLINKED:
+ * @hook: a #GHook
+ * 
+ * Returns %TRUE if the #GHook is not in a #GHookList.
+ * 
+ * Returns: %TRUE if the #GHook is not in a #GHookList
+ */
 #define G_HOOK_IS_UNLINKED(hook)	(G_HOOK (hook)->next == NULL && \
 					 G_HOOK (hook)->prev == NULL && \
 					 G_HOOK (hook)->hook_id == 0 && \
@@ -154,6 +318,13 @@
 gint	 g_hook_compare_ids		(GHook			*new_hook,
 					 GHook			*sibling);
 /* convenience macros */
+/**
+ * g_hook_append:
+ * @hook_list: a #GHookList
+ * @hook: the #GHook to add to the end of @hook_list
+ * 
+ * Appends a #GHook onto the end of a #GHookList.
+ */
 #define	 g_hook_append( hook_list, hook )  \
      g_hook_insert_before ((hook_list), NULL, (hook))
 /* invoke all valid hooks with the (*GHookFunc) signature.
Index: glib/gstrfuncs.c
===================================================================
--- glib/gstrfuncs.c	(revision 7087)
+++ glib/gstrfuncs.c	(working copy)
@@ -98,6 +98,18 @@
   return new_str;
 }
 
+
+/**
+ * g_memdup:
+ * @mem: the memory to copy.
+ * @byte_size: the number of bytes to copy.
+ * 
+ * Allocates @byte_size bytes of memory, and copies @byte_size bytes into it
+ * from @mem. If @mem is %NULL it returns %NULL.
+ * 
+ * Returns: a pointer to the newly-allocated copy of the memory, or %NULL if @mem
+ *  is %NULL.
+ */
 gpointer
 g_memdup (gconstpointer mem,
 	  guint         byte_size)
Index: glib/garray.c
===================================================================
--- glib/garray.c	(revision 7087)
+++ glib/garray.c	(working copy)
@@ -45,6 +45,51 @@
 
 #define MIN_ARRAY_SIZE  16
 
+/**
+ * SECTION:arrays
+ * @Short_description: arrays of arbitrary elements which grow automatically as elements are added
+ * @Title: Arrays
+ * 
+ * Arrays are similar to standard C arrays, except that they grow automatically
+ * as elements are added.
+ * 
+ * Array elements can be of any size (though all elements of one array are the
+ * same size), and the array can be automatically cleared to '0's and
+ * zero-terminated.
+ * 
+ * To create a new array use g_array_new().
+ * 
+ * To add elements to an array, use g_array_append_val(), g_array_append_vals(),
+ * g_array_prepend_val(), and g_array_prepend_vals().
+ * 
+ * To access an element of an array, use g_array_index().
+ * 
+ * To set the size of an array, use g_array_set_size().
+ * 
+ * To free an array, use g_array_free().
+ * 
+ * <example>
+ * <title>Using a <structname>GArray</structname> to store <type>gint</type> values</title>
+ * <programlisting>
+ *   GArray *garray;
+ *   gint i;
+ * 
+ *   /*<!----> We create a new array to store gint values.
+ *      We don't want it zero-terminated or cleared to 0's. *<!---->/
+ *   garray = g_array_new (FALSE, FALSE, sizeof (gint));
+ *   for (i = 0; i < 10000; i++)
+ *     g_array_append_val (garray, i);
+ * 
+ *   for (i = 0; i < 10000; i++)
+ *     if (g_array_index (garray, gint, i) != i)
+ *       g_print ("ERROR: got &percnt;d instead of &percnt;d\n",
+ *                g_array_index (garray, gint, i), i);
+ * 
+ *   g_array_free (garray, TRUE);
+ * </programlisting></example>
+ */
+
+
 typedef struct _GRealArray  GRealArray;
 
 struct _GRealArray
@@ -69,7 +114,18 @@
 static gint g_nearest_pow        (gint        num) G_GNUC_CONST;
 static void g_array_maybe_expand (GRealArray *array,
 				  gint        len);
-
+/**
+ * g_array_new:
+ * @zero_terminated: %TRUE if the array should have an extra element at the end
+ *  which is set to 0.
+ * @clear_: %TRUE if #GArray elements should be automatically cleared to 0
+ *  when they are allocated.
+ * @element_size: the size of each element in bytes.
+ * 
+ * Creates a new #GArray.
+ * 
+ * Returns: the new #GArray.
+ */
 GArray*
 g_array_new (gboolean zero_terminated,
 	     gboolean clear,
@@ -78,6 +134,20 @@
   return (GArray*) g_array_sized_new (zero_terminated, clear, elt_size, 0);
 }
 
+/**
+ * g_array_sized_new:
+ * @zero_terminated: %TRUE if the array should have an extra element at the end with all bits cleared.
+ * @clear_: %TRUE if all bits in the array should be cleared to 0 on allocation.
+ * @element_size: size of each element in the array.
+ * @reserved_size: number of elements preallocated.
+ * 
+ * Creates a new #GArray with @reserved_size elements
+ * preallocated. This avoids frequent reallocation, if you are going to
+ * add many elements to the array. Note however that the size of the
+ * array is still 0.
+ * 
+ * Returns: the new #GArray.
+ */
 GArray* g_array_sized_new (gboolean zero_terminated,
 			   gboolean clear,
 			   guint    elt_size,
@@ -101,6 +171,25 @@
   return (GArray*) array;
 }
 
+/**
+ * g_array_free:
+ * @array: a #GArray.
+ * @free_segment: if %TRUE the actual element data is freed as well.
+ * 
+ * Frees the memory allocated for the #GArray.
+ * If @free_segment is %TRUE it frees the memory block holding the elements
+ * as well. Pass %FALSE if you want to free the #GArray wrapper but preserve
+ * the underlying array for use elsewhere.
+ * 
+ * <note>
+ * If array elements contain dynamically-allocated memory, they should be freed
+ * separately.
+ * 
+ * </note>
+ * 
+ * Returns: the element data if @free_segment is %FALSE, otherwise %NULL.
+ *  The element data should be freed using g_free().
+ */
 gchar*
 g_array_free (GArray  *array,
 	      gboolean free_segment)
@@ -122,6 +211,16 @@
   return segment;
 }
 
+/**
+ * g_array_append_vals:
+ * @array: a #GArray.
+ * @data: a pointer to the elements to append to the end of the array.
+ * @len: the number of elements to append.
+ * 
+ * Adds @len elements onto the end of the array.
+ * 
+ * Returns: the #GArray.
+ */
 GArray*
 g_array_append_vals (GArray       *farray,
 		     gconstpointer data,
@@ -141,6 +240,19 @@
   return farray;
 }
 
+/**
+ * g_array_prepend_vals:
+ * @array: a #GArray.
+ * @data: a pointer to the elements to prepend to the start of the array.
+ * @len: the number of elements to prepend.
+ * 
+ * Adds @len elements onto the start of the array.
+ * 
+ * This operation is slower than g_array_append_vals() since the existing elements
+ * in the array have to be moved to make space for the new elements.
+ * 
+ * Returns: the #GArray.
+ */
 GArray*
 g_array_prepend_vals (GArray        *farray,
 		      gconstpointer  data,
@@ -162,6 +274,17 @@
   return farray;
 }
 
+/**
+ * g_array_insert_vals:
+ * @array: a #GArray.
+ * @index_: the index to place the elements at.
+ * @data: a pointer to the elements to insert.
+ * @len: the number of elements to insert.
+ * 
+ * Inserts @len elements into a #GArray at the given index.
+ * 
+ * Returns: the #GArray.
+ */
 GArray*
 g_array_insert_vals (GArray        *farray,
 		     guint          index,
@@ -185,6 +308,16 @@
   return farray;
 }
 
+/**
+ * g_array_set_size:
+ * @array: a #GArray.
+ * @length: the new size of the #GArray.
+ * 
+ * Sets the size of the array, expanding it if necessary.
+ * If the array was created with @clear_ set to %TRUE, the new elements are set to 0.
+ * 
+ * Returns: the #GArray.
+ */
 GArray*
 g_array_set_size (GArray *farray,
 		  guint   length)
@@ -207,6 +340,16 @@
   return farray;
 }
 
+/**
+ * g_array_remove_index:
+ * @array: a #GArray.
+ * @index_: the index of the element to remove.
+ * 
+ * Removes the element at the given index from a #GArray.
+ * The following elements are moved down one place.
+ * 
+ * Returns: the #GArray.
+ */
 GArray*
 g_array_remove_index (GArray* farray,
 		      guint index)
@@ -232,6 +375,19 @@
   return farray;
 }
 
+
+/**
+ * g_array_remove_index_fast:
+ * @array: a @GArray.
+ * @index_: the index of the element to remove.
+ * 
+ * Removes the element at the given index from a #GArray.
+ * The last element in the array is used to fill in the space, so this function
+ * does not preserve the order of the #GArray. But it is faster than
+ * g_array_remove_index().
+ * 
+ * Returns: the #GArray.
+ */
 GArray*
 g_array_remove_index_fast (GArray* farray,
 			   guint   index)
@@ -257,6 +413,18 @@
   return farray;
 }
 
+/**
+ * g_array_remove_range:
+ * @array: a @GArray.
+ * @index_: the index of the first element to remove.
+ * @length: the number of elements to remove.
+ * 
+ * Removes the given number of elements starting at the given index from a
+ * #GArray.  The following elements are moved to close the gap.
+ * 
+ * Since: 2.4
+ * Returns: the #GArray.
+ */
 GArray*
 g_array_remove_range (GArray       *farray,
                       guint         index_,
@@ -282,6 +450,20 @@
   return farray;
 }
 
+
+
+/**
+ * g_array_sort:
+ * @array: a #GArray.
+ * @compare_func: comparison function.
+ * 
+ * Sorts a #GArray using @compare_func which should be a qsort()-style comparison
+ * function (returns less than zero for first arg is less than second arg, 
+ * zero for equal, greater zero if first arg is greater than second arg).
+ * 
+ * If two array elements compare equal, their order in the sorted array is
+ * undefined.
+ */
 void
 g_array_sort (GArray       *farray,
 	      GCompareFunc  compare_func)
@@ -296,6 +478,15 @@
 	 compare_func);
 }
 
+/**
+ * g_array_sort_with_data:
+ * @array: a #GArray.
+ * @compare_func: comparison function.
+ * @user_data: data to pass to @compare_func.
+ * 
+ * Like g_array_sort(), but the comparison function receives an extra user data
+ * argument.
+ */
 void
 g_array_sort_with_data (GArray           *farray,
 			GCompareDataFunc  compare_func,
@@ -345,9 +536,55 @@
     }
 }
 
-/* Pointer Array
+/**
+ * SECTION:arrays_pointer
+ * @Short_description: arrays of pointers to any type of data, 
+ *    which grow automatically as new elements are added
+ * @Title: Pointer Arrays
+ * 
+ * Pointer Arrays are similar to Arrays but are used only for storing pointers.
+ * 
+ * <note>
+ * If you remove elements from the array, elements at the end of the array
+ * are moved into the space previously occupied by the removed element.
+ * This means that you should not rely on the index of particular elements
+ * remaining the same. You should also be careful when deleting elements while
+ * iterating over the array.
+ * 
+ * </note>
+ * To create a pointer array, use g_ptr_array_new().
+ * 
+ * To add elements to a pointer array, use g_ptr_array_add().
+ * 
+ * To remove elements from a pointer array, use g_ptr_array_remove(),
+ * g_ptr_array_remove_index() or g_ptr_array_remove_index_fast().
+ * 
+ * To access an element of a pointer array, use g_ptr_array_index().
+ * 
+ * To set the size of a pointer array, use g_ptr_array_set_size().
+ * 
+ * To free a pointer array, use g_ptr_array_free().
+ * 
+ * <example>
+ * <title>Using a <structname>GPtrArray</structname></title>
+ * <programlisting>
+ *   GPtrArray *gparray;
+ *   gchar *string1 = "one", *string2 = "two", *string3 = "three";
+ * 
+ *   gparray = g_ptr_array_new (<!-- -->);
+ *   g_ptr_array_add (gparray, (gpointer) string1);
+ *   g_ptr_array_add (gparray, (gpointer) string2);
+ *   g_ptr_array_add (gparray, (gpointer) string3);
+ * 
+ *   if (g_ptr_array_index (gparray, 0) != (gpointer) string1)
+ *     g_print ("ERROR: got &percnt;p instead of &percnt;p\n",
+ *              g_ptr_array_index (gparray, 0), string1);
+ * 
+ *   g_ptr_array_free (gparray, TRUE);
+ * </programlisting></example>
  */
 
+
 typedef struct _GRealPtrArray  GRealPtrArray;
 
 struct _GRealPtrArray
@@ -359,13 +596,30 @@
 
 static void g_ptr_array_maybe_expand (GRealPtrArray *array,
 				      gint           len);
-
+/**
+ * g_ptr_array_new:
+ * 
+ * Creates a new #GPtrArray.
+ * 
+ * Returns: the new #GPtrArray.
+ */
 GPtrArray*
 g_ptr_array_new (void)
 {
   return g_ptr_array_sized_new (0);
 }
 
+/**
+ * g_ptr_array_sized_new:
+ * @reserved_size: number of pointers preallocated.
+ * 
+ * Creates a new #GPtrArray with @reserved_size pointers
+ * preallocated. This avoids frequent reallocation, if you are going to
+ * add many pointers to the array. Note however that the size of the
+ * array is still 0.
+ * 
+ * Returns: the new #GPtrArray.
+ */
 GPtrArray*  
 g_ptr_array_sized_new (guint reserved_size)
 {
@@ -381,6 +635,25 @@
   return (GPtrArray*) array;  
 }
 
+/**
+ * g_ptr_array_free:
+ * @array: a #GPtrArray.
+ * @free_seg: if %TRUE the actual pointer array is freed as well.
+ * 
+ * Frees the memory allocated for the #GPtrArray.
+ * If @free_segment is %TRUE it frees the memory block holding the elements
+ * as well. Pass %FALSE if you want to free the #GPtrArray wrapper but preserve
+ * the underlying array for use elsewhere.
+ * 
+ * <note>
+ * If array contents point to dynamically-allocated memory, they should be freed
+ * separately.
+ * 
+ * </note>
+ * 
+ * Returns: the pointer array if @free_seg is %FALSE, otherwise %NULL.
+ *  The pointer array should be freed using g_free().
+ */
 gpointer*
 g_ptr_array_free (GPtrArray   *array,
 		  gboolean  free_segment)
@@ -418,6 +691,14 @@
     }
 }
 
+/**
+ * g_ptr_array_set_size:
+ * @array: a #GPtrArray.
+ * @length: the new length of the pointer array.
+ * 
+ * Sets the size of the array, expanding it if necessary.
+ * New elements are set to %NULL.
+ */
 void
 g_ptr_array_set_size  (GPtrArray   *farray,
 		       gint	     length)
@@ -449,6 +730,16 @@
   array->len = length;
 }
 
+/**
+ * g_ptr_array_remove_index:
+ * @array: a #GPtrArray.
+ * @index_: the index of the pointer to remove.
+ * 
+ * Removes the pointer at the given index from the pointer array.
+ * The following elements are moved down one place.
+ * 
+ * Returns: the pointer which was removed.
+ */
 gpointer
 g_ptr_array_remove_index (GPtrArray* farray,
 			  guint      index)
@@ -474,6 +765,18 @@
   return result;
 }
 
+/**
+ * g_ptr_array_remove_index_fast:
+ * @array: a #GPtrArray.
+ * @index_: the index of the pointer to remove.
+ * 
+ * Removes the pointer at the given index from the pointer array.
+ * The last element in the array is used to fill in the space, so this function
+ * does not preserve the order of the array. But it is faster than
+ * g_ptr_array_remove_index().
+ * 
+ * Returns: the pointer which was removed.
+ */
 gpointer
 g_ptr_array_remove_index_fast (GPtrArray* farray,
 			       guint      index)
@@ -498,6 +801,18 @@
   return result;
 }
 
+
+/**
+ * g_ptr_array_remove_range:
+ * @array: a @GPtrArray.
+ * @index_: the index of the first pointer to remove.
+ * @length: the number of pointers to remove.
+ * 
+ * Removes the given number of pointers starting at the given index from a
+ * #GPtrArray.  The following elements are moved to close the gap.
+ * 
+ * Since: 2.4
+ */
 void
 g_ptr_array_remove_range (GPtrArray* farray,
                           guint      index_,
@@ -523,6 +838,20 @@
     }
 }
 
+/**
+ * g_ptr_array_remove:
+ * @array: a #GPtrArray.
+ * @data: the pointer to remove.
+ * 
+ * Removes the first occurrence of the given pointer from the pointer array.
+ * The following elements are moved down one place.
+ * 
+ * It returns %TRUE if the pointer was removed, or %FALSE if the pointer
+ * was not found.
+ * 
+ * Returns: %TRUE if the pointer is removed. %FALSE if the pointer is not found
+ *  in the array.
+ */
 gboolean
 g_ptr_array_remove (GPtrArray* farray,
 		    gpointer data)
@@ -544,6 +873,22 @@
   return FALSE;
 }
 
+
+/**
+ * g_ptr_array_remove_fast:
+ * @array: a #GPtrArray.
+ * @data: the pointer to remove.
+ * 
+ * Removes the first occurrence of the given pointer from the pointer array.
+ * The last element in the array is used to fill in the space, so this function
+ * does not preserve the order of the array. But it is faster than
+ * g_ptr_array_remove().
+ * 
+ * It returns %TRUE if the pointer was removed, or %FALSE if the pointer
+ * was not found.
+ * 
+ * Returns: %TRUE if the pointer was found in the array.
+ */
 gboolean
 g_ptr_array_remove_fast (GPtrArray* farray,
 			 gpointer data)
@@ -565,6 +910,14 @@
   return FALSE;
 }
 
+/**
+ * g_ptr_array_add:
+ * @array: a #GPtrArray.
+ * @data: the pointer to add.
+ * 
+ * Adds a pointer to the end of the pointer array.
+ * The array will grow in size automatically if necessary.
+ */
 void
 g_ptr_array_add (GPtrArray* farray,
 		 gpointer data)
@@ -578,6 +931,22 @@
   array->pdata[array->len++] = data;
 }
 
+/**
+ * g_ptr_array_sort:
+ * @array: a #GPtrArray.
+ * @compare_func: comparison function.
+ * 
+ * Sorts the array, using @compare_func which should be a qsort()-style comparison
+ * function (returns less than zero for first arg is less than second arg, 
+ * zero for equal, greater than zero if irst arg is greater than second arg).
+ * 
+ * If two array elements compare equal, their order in the sorted array is
+ * undefined.
+ * 
+ * The comparison function for g_ptr_array_sort() doesn't take the pointers 
+ * from the array as arguments, it takes pointers to the pointers in the array.
+ * </para></note>
+ */
 void
 g_ptr_array_sort (GPtrArray    *array,
 		  GCompareFunc  compare_func)
@@ -590,6 +959,21 @@
 	 compare_func);
 }
 
+/**
+ * g_ptr_array_sort_with_data:
+ * @array: a #GPtrArray.
+ * @compare_func: comparison function.
+ * @user_data: data to pass to @compare_func.
+ * 
+ * Like g_ptr_array_sort(), but the comparison function has an extra user data 
+ * argument.
+ * 
+ * The comparison function for g_ptr_array_sort_with_data() doesn't take the 
+ * pointers from the array as arguments, it takes pointers to the pointers in 
+ * the array.
+ * </para></note>
+ */
+
 void
 g_ptr_array_sort_with_data (GPtrArray        *array,
 			    GCompareDataFunc  compare_func,
@@ -627,25 +1011,100 @@
     (*func) (array->pdata[i], user_data);
 }
 
-/* Byte arrays 
+/**
+ * SECTION:arrays_byte
+ * @Short_description: arrays of bytes, which grow automatically as elements are added
+ * @Title: Byte Arrays
+ * 
+ * #GByteArray is based on #GArray, to provide arrays of bytes which grow
+ * automatically as elements are added.
+ * 
+ * To create a new #GByteArray use g_byte_array_new().
+ * 
+ * To add elements to a #GByteArray, use g_byte_array_append(), and
+ * g_byte_array_prepend().
+ * 
+ * To set the size of a #GByteArray, use g_byte_array_set_size().
+ * 
+ * To free a #GByteArray, use g_byte_array_free().
+ * 
+ * 
+ * <example>
+ * <title>Using a <structname>GByteArray</structname></title>
+ * <programlisting>
+ *   GByteArray *gbarray;
+ *   gint i;
+ * 
+ *   gbarray = g_byte_array_new (<!-- -->);
+ *   for (i = 0; i < 10000; i++)
+ *     g_byte_array_append (gbarray, (guint8*) "abcd", 4);
+ * 
+ *   for (i = 0; i < 10000; i++)
+ *     {
+ *       g_assert (gbarray->data[4*i] == 'a');
+ *       g_assert (gbarray->data[4*i+1] == 'b');
+ *       g_assert (gbarray->data[4*i+2] == 'c');
+ *       g_assert (gbarray->data[4*i+3] == 'd');
+ *     }
+ * 
+ *   g_byte_array_free (gbarray, TRUE);
+ * </programlisting></example>
  */
 
+/**
+ * g_byte_array_new:
+ * 
+ * Creates a new #GByteArray.
+ * 
+ * Returns: the new #GByteArray.
+ */
 GByteArray* g_byte_array_new      (void)
 {
   return (GByteArray*) g_array_sized_new (FALSE, FALSE, 1, 0);
 }
 
+/**
+ * g_byte_array_sized_new:
+ * @reserved_size: number of bytes preallocated.
+ * 
+ * Creates a new #GByteArray with @reserved_size bytes preallocated. This
+ * avoids frequent reallocation, if you are going to add many bytes to
+ * the array. Note however that the size of the array is still 0.
+ * 
+ * Returns: the new #GByteArray.
+ */
 GByteArray* g_byte_array_sized_new (guint reserved_size)
 {
   return (GByteArray*) g_array_sized_new (FALSE, FALSE, 1, reserved_size);
 }
 
+/**
+ * g_byte_array_free:
+ * @array: a #GByteArray.
+ * @free_segment: if %TRUE the actual byte data is freed as well.
+ * 
+ * Frees the memory allocated by the #GByteArray.
+ * If @free_segment is %TRUE it frees the actual byte data.
+ * 
+ * Returns: the element data if @free_segment is %FALSE, otherwise %NULL
+ */
 guint8*	    g_byte_array_free     (GByteArray *array,
 			           gboolean    free_segment)
 {
   return (guint8*) g_array_free ((GArray*) array, free_segment);
 }
 
+/**
+ * g_byte_array_append:
+ * @array: a #GByteArray.
+ * @data: the byte data to be added.
+ * @len: the number of bytes to add.
+ * 
+ * Adds the given bytes to the end of the #GByteArray.
+ * The array will grow in size automatically if necessary.
+ * 
+ * Returns: the #GByteArray.
+ */
 GByteArray* g_byte_array_append   (GByteArray *array,
 				   const guint8 *data,
 				   guint       len)
@@ -655,6 +1114,17 @@
   return array;
 }
 
+/**
+ * g_byte_array_prepend:
+ * @array: a #GByteArray.
+ * @data: the byte data to be added.
+ * @len: the number of bytes to add.
+ * 
+ * Adds the given data to the start of the #GByteArray.
+ * The array will grow in size automatically if necessary.
+ * 
+ * Returns: the #GByteArray.
+ */
 GByteArray* g_byte_array_prepend  (GByteArray *array,
 				   const guint8 *data,
 				   guint       len)
@@ -664,6 +1134,15 @@
   return array;
 }
 
+/**
+ * g_byte_array_set_size:
+ * @array: a #GByteArray.
+ * @length: the new size of the #GByteArray.
+ * 
+ * Sets the size of the #GByteArray, expanding it if necessary.
+ * 
+ * Returns: the #GByteArray.
+ */
 GByteArray* g_byte_array_set_size (GByteArray *array,
 				   guint       length)
 {
@@ -672,6 +1151,16 @@
   return array;
 }
 
+/**
+ * g_byte_array_remove_index:
+ * @array: a #GByteArray.
+ * @index_: the index of the byte to remove.
+ * 
+ * Removes the byte at the given index from a #GByteArray.
+ * The following bytes are moved down one place.
+ * 
+ * Returns: the #GByteArray.
+ */
 GByteArray* g_byte_array_remove_index (GByteArray *array,
 				       guint index)
 {
@@ -680,6 +1169,18 @@
   return array;
 }
 
+/**
+ * g_byte_array_remove_index_fast:
+ * @array: a #GByteArray.
+ * @index_: the index of the byte to remove.
+ * 
+ * Removes the byte at the given index from a #GByteArray.
+ * The last element in the array is used to fill in the space, so this function
+ * does not preserve the order of the #GByteArray. But it is faster than
+ * g_byte_array_remove_index().
+ * 
+ * Returns: the #GByteArray.
+ */
 GByteArray* g_byte_array_remove_index_fast (GByteArray *array,
 					    guint index)
 {
@@ -688,6 +1189,18 @@
   return array;
 }
 
+/**
+ * g_byte_array_remove_range:
+ * @array: a @GByteArray.
+ * @index_: the index of the first byte to remove.
+ * @length: the number of bytes to remove.
+ * 
+ * Removes the given number of bytes starting at the given index from a
+ * #GByteArray.  The following elements are moved to close the gap.
+ * 
+ * Since: 2.4
+ * Returns: the #GByteArray.
+ */
 GByteArray*
 g_byte_array_remove_range (GByteArray *array,
                            guint index_,
@@ -700,6 +1213,19 @@
   return (GByteArray *)g_array_remove_range ((GArray*) array, index_, length);
 }
 
+/**
+ * g_byte_array_sort:
+ * @array: a #GByteArray.
+ * @compare_func: comparison function.
+ * 
+ * Sorts a byte array, using @compare_func which should be a qsort()-style
+ * comparison function (returns less than zero for first arg is less than second 
+ * arg, zero for equal, greater than zero if first arg is greater than second 
+ * arg).
+ * 
+ * If two array elements compare equal, their order in the sorted array is
+ * undefined.
+ */
 void
 g_byte_array_sort (GByteArray   *array,
 		   GCompareFunc  compare_func)
@@ -707,6 +1233,15 @@
   g_array_sort ((GArray *) array, compare_func);
 }
 
+/**
+ * g_byte_array_sort_with_data:
+ * @array: a #GByteArray.
+ * @compare_func: comparison function.
+ * @user_data: data to pass to @compare_func.
+ * 
+ * Like g_byte_array_sort(), but the comparison function takes an extra user data
+ * argument.
+ */
 void
 g_byte_array_sort_with_data (GByteArray       *array,
 			     GCompareDataFunc  compare_func,
Index: glib/garray.h
===================================================================
--- glib/garray.h	(revision 7087)
+++ glib/garray.h	(working copy)
@@ -35,8 +35,34 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GArray:
+ * @data: a pointer to the element data. The data may be moved as elements are
+ *  added to the #GArray.
+ * @len: the number of elements in the #GArray.
+ * 
+ * Contains the public fields of an <link linkend="glib-arrays">Array</link>.
+ */
 typedef struct _GArray		GArray;
+
+/**
+ * GByteArray:
+ * @data: a pointer to the element data. The data may be moved as elements are
+ *  added to the #GByteArray.
+ * @len: the number of elements in the #GByteArray.
+ * 
+ * The <structname>GByteArray</structname> struct allows access to the public 
+ * fields of a <structname>GByteArray</structname>.
+ */
 typedef struct _GByteArray	GByteArray;
+
+/**
+ * GPtrArray:
+ * @pdata: points to the array of pointers, which may be moved when the array grows.
+ * @len: number of pointers in the array.
+ * 
+ * Contains the public fields of a pointer array.
+ */
 typedef struct _GPtrArray	GPtrArray;
 
 struct _GArray
@@ -62,9 +88,88 @@
  * order by moving the last element to the position of the removed.
  */
 
+/**
+ * g_array_append_val:
+ * @a: a #GArray.
+ * @v: the value to append to the #GArray.
+ * 
+ * Adds the value on to the end of the array.
+ * The array will grow in size automatically if necessary.
+ * 
+ * <note>
+ * g_array_append_val() is a macro which uses a reference to the value
+ * parameter @v. This means that you cannot use it with literal values
+ * such as "27". You must use variables.
+ * 
+ * </note>
+ * 
+ * Returns: the #GArray.
+ */
 #define g_array_append_val(a,v)	  g_array_append_vals (a, &(v), 1)
+
+/**
+ * g_array_prepend_val:
+ * @a: a #GArray.
+ * @v: the value to prepend to the #GArray.
+ * 
+ * Adds the value on to the start of the array.
+ * The array will grow in size automatically if necessary.
+ * 
+ * This operation is slower than g_array_append_val() since the existing elements
+ * in the array have to be moved to make space for the new element.
+ * 
+ * <note>
+ * g_array_prepend_val() is a macro which uses a reference to the value
+ * parameter @v. This means that you cannot use it with literal values
+ * such as "27". You must use variables.
+ * 
+ * </note>
+ * 
+ * Returns: the #GArray.
+ */
 #define g_array_prepend_val(a,v)  g_array_prepend_vals (a, &(v), 1)
+
+/**
+ * g_array_insert_val:
+ * @a: a #GArray.
+ * @i: the index to place the element at.
+ * @v: the value to insert into the array.
+ * 
+ * Inserts an element into an array at the given index.
+ * 
+ * <note>
+ * g_array_insert_val() is a macro which uses a reference to the value
+ * parameter @v. This means that you cannot use it with literal values
+ * such as "27". You must use variables.
+ * 
+ * </note>
+ * 
+ * Returns: the #GArray.
+ */
 #define g_array_insert_val(a,i,v) g_array_insert_vals (a, i, &(v), 1)
+
+/**
+ * g_array_index:
+ * @a: a #GArray.
+ * @t: the type of the elements.
+ * @i: the index of the element to return.
+ * 
+ * Returns the element of a #GArray at the given index.
+ * The return value is cast to the given type.
+ * 
+ * <example>
+ * <title>Getting a pointer to an element in a <structname>GArray</structname></title>
+ * <programlisting>
+ *   EDayViewEvent *event;
+ * 
+ *   /<!---->* This gets a pointer to the 4th element in the array of EDayViewEvent
+ *      structs. *<!---->/
+ *   event = &g_array_index (events, EDayViewEvent, 3);
+ * </programlisting>
+ * </example>
+ * 
+ * Returns: the element of the #GArray at the index given by @i.
+ */
 #define g_array_index(a,t,i)      (((t*) (void *) (a)->data) [(i)])
 
 GArray* g_array_new               (gboolean          zero_terminated,
@@ -105,6 +210,16 @@
  * than the above.  Add appends a pointer.  Remove fills any cleared 
  * spot and shortens the array. remove_fast will again distort order.  
  */
+
+/**
+ * g_ptr_array_index:
+ * @array: a #GPtrArray.
+ * @index_: the index of the pointer to return.
+ * 
+ * Returns the pointer at the given index of the pointer array.
+ * 
+ * Returns: the pointer at the given index.
+ */
 #define    g_ptr_array_index(array,index_) ((array)->pdata)[index_]
 GPtrArray* g_ptr_array_new                (void);
 GPtrArray* g_ptr_array_sized_new          (guint             reserved_size);
Index: glib/gkeyfile.c
===================================================================
--- glib/gkeyfile.c	(revision 7087)
+++ glib/gkeyfile.c	(working copy)
@@ -62,6 +62,102 @@
 
 #include "galias.h"
 
+/**
+ * SECTION:keyfile
+ * @Short_description: parses <filename>.ini</filename>-like config files
+ * @Title: Key-value file parser
+ * 
+ * #GKeyFile lets you parse, edit or create files containing groups of
+ * key-value pairs, which we call <firstterm>key files</firstterm> for 
+ * lack of a better name. Several freedesktop.org specifications use
+ * key files now, e.g the 
+ * <ulink url="http://freedesktop.org/Standards/desktop-entry-spec">Desktop
+ * Entry Specification</ulink> and the
+ * <ulink url="http://freedesktop.org/Standards/icon-theme-spec">Icon
+ * Theme Specification</ulink>. 
+ * 
+ * 
+ * The syntax of key files is described in detail in the 
+ * <ulink url="http://freedesktop.org/Standards/desktop-entry-spec">Desktop
+ * Entry Specification</ulink>, here is a quick summary: Key files
+ * consists of groups of key-value pairs, interspersed with comments.
+ * 
+ * 
+ * <informalexample><programlisting>
+ * # this is just an example
+ * # there can be comments before the first group
+ * 
+ * [First Group]
+ * 
+ * Name=Key File Example\tthis value shows\nescaping
+ * 
+ * # localized strings are stored in multiple key-value pairs
+ * Welcome=Hello
+ * Welcome[de]=Hallo
+ * Welcome[fr]=Bonjour
+ * Welcome[it]=Ciao
+ * 
+ * [Another Group]
+ * 
+ * Numbers=2;20;-200;0
+ * 
+ * Booleans=true;false;true;true
+ * 
+ * </programlisting></informalexample>
+ * 
+ * Lines beginning with a '#' and blank lines are considered comments.
+ * 
+ * 
+ * Groups are started by a header line containing the group name enclosed
+ * in '[' and ']', and ended implicitly by the start of the next group or
+ * the end of the file. Each key-value pair must be contained in a group.
+ * 
+ * 
+ * Key-value pairs generally have the form <literal>key=value</literal>, 
+ * with the exception of localized strings, which have the form 
+ * <literal>key[locale]=value</literal>. Space before and after the 
+ * '=' character are ignored. Newline, tab, carriage return and backslash 
+ * characters in value are escaped as \n, \t, \r, and \\, respectively. 
+ * To preserve leading spaces in values, these can also be escaped as \s.
+ * 
+ * 
+ * Key files can store strings (possibly with localized variants), integers,
+ * booleans and lists of these. Lists are separated by a separator character,
+ * typically ';' or ','. To use the list separator character in a value in
+ * a list, it has to be escaped by prefixing it with a backslash.
+ * 
+ * 
+ * This syntax is obviously inspired by the <filename>.ini</filename> 
+ * files commonly met on Windows, but there are some important differences:
+ * <itemizedlist>
+ * <filename>.ini</filename> files use the ';' character to begin comments,
+ *  key files use the '#' character.
+ * </para></listitem>
+ * Key files do not allow for ungrouped keys meaning only comments can 
+ * precede the first group.
+ * </para></listitem>
+ * Key files are always encoded in UTF-8.
+ * </para></listitem>
+ * Key and Group names are case-sensitive, for example a group called
+ * <literal>[GROUP]</literal> is a different group from <literal>[group]</literal>.
+ * </para></listitem>
+ * <filename>.ini</filename> files don't have a strongly typed boolean 
+ * entry type, they only have <literal>GetProfileInt</literal>. 
+ * In <structname>GKeyFile</structname> only <literal>true</literal> 
+ * and <literal>false</literal> (in lower case) are allowed.
+ * </para></listitem>
+ * </itemizedlist>
+ * 
+ * 
+ * Note that in contrast to the
+ * <ulink url="http://freedesktop.org/Standards/desktop-entry-spec">Desktop
+ * Entry Specification</ulink>, groups in key files may contain the same
+ * key multiple times; the last entry wins. Key files may also contain
+ * multiple groups with the same name; they are merged together.
+ * Another difference is that keys and group names in key files are not
+ * restricted to ASCII characters.
+ */
+
 typedef struct _GKeyFileGroup GKeyFileGroup;
 
 struct _GKeyFile
Index: glib/gmacros.h
===================================================================
--- glib/gmacros.h	(revision 7087)
+++ glib/gmacros.h	(working copy)
@@ -39,6 +39,75 @@
  */
 #include <stddef.h>
 
+/**
+ * SECTION:macros
+ * @Short_description: commonly-used macros.
+ * @Title: Standard Macros
+ * 
+ * These macros provide a few commonly-used features.
+ */
+
+/**
+ * SECTION:macros_misc
+ * @Short_description: specialized macros which are not used often
+ * @Title: Miscellaneous Macros
+ * 
+ * These macros provide more specialized features which are not needed so often
+ * by application programmers.
+ */
+
+/* These are GLib compile-time defined values. They are actually 
+ * defined in glibconfig.h, however, that file is generated at 
+ * compile time. 
+ */
+/**
+ * G_OS_BEOS:
+ * 
+ * This macro is defined only on BeOS. So you can bracket
+ * BeOS-specific code in "#ifdef G_OS_BEOS".
+ */
+/**
+ * G_OS_UNIX:
+ * 
+ * This macro is defined only on UNIX. So you can bracket
+ * UNIX-specific code in "#ifdef G_OS_UNIX".
+ */
+/**
+ * G_OS_WIN32:
+ * 
+ * This macro is defined only on Windows. So you can bracket
+ * Windows-specific code in "#ifdef G_OS_WIN32".
+ */
+
+
+/**
+ * G_GNUC_INTERNAL:
+ * 
+ * This attribute can be used for marking library functions as being used 
+ * internally to the library only, which may allow the compiler to handle
+ * function calls more efficiently. 
+ * Note that static functions do not need to be marked as internal in this way. 
+ * See the GNU C documentation for details. 
+ * 
+ * When using a compiler that supports the GNU C hidden visibility attribute, 
+ * this macro expands to <literal>__attribute__((visibility("hidden")))</literal>.
+ * When using the Sun Studio compiler, it expands to <literal>__hidden</literal>.
+ * 
+ * Note that for portability, the attribute should be placed before the
+ * function declaration. While GCC allows the macro after the declaration, 
+ * Sun Studio does not.
+ * 
+ * <informalexample><programlisting>
+ * G_GNUC_INTERNAL
+ * void _g_log_fallback_handler (const gchar    *log_domain,
+ *                               GLogLevelFlags  log_level,
+ *                               const gchar    *message,
+ *                               gpointer        unused_data);
+ * </programlisting></informalexample>
+ * 
+ * Since: 2.6
+ */
+
 /* Here we provide G_GNUC_EXTENSION as an alias for __extension__,
  * where this is valid. This allows for warningless compilation of
  * "long long" types even in the presence of '-ansi -pedantic'. 
@@ -51,22 +120,68 @@
 
 /* Provide macros to feature the GCC function attribute.
  */
+
 #if    __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 96)
 #define G_GNUC_PURE                            \
   __attribute__((__pure__))
 #define G_GNUC_MALLOC    			\
   __attribute__((__malloc__))
 #else
+/**
+ * G_GNUC_PURE:
+ * 
+ * Expands to the GNU C <literal>pure</literal> function attribute if the compiler is 
+ * <command>gcc</command>. Declaring a function as pure enables better optimization of 
+ * calls to the function. A pure function has no effects except its return value and the 
+ * return value depends only on the parameters and/or global variables.
+ * See the GNU C documentation for details. 
+ */
 #define G_GNUC_PURE
+/**
+ * G_GNUC_MALLOC:
+ * 
+ * Expands to the GNU C <literal>malloc</literal> function attribute if the 
+ * compiler is <command>gcc</command>. Declaring a function as malloc enables 
+ * better optimization of the function. A function can have the malloc attribute 
+ * if it returns a pointer which is guaranteed to not alias with any other pointer
+ * when the function returns (in practice, this means newly allocated memory).  
+ * See the GNU C documentation for details. 
+ * 
+ * Since: 2.6
+ */
 #define G_GNUC_MALLOC
 #endif
 
+/**
+ * G_GNUC_NULL_TERMINATED:
+ * 
+ * Expands to the GNU C <literal>sentinel</literal> function attribute if the 
+ * compiler is <command>gcc</command>, or "" if it isn't. This function attribute
+ * only applies to variadic functions and instructs the compiler to check that 
+ * the argument list is terminated with an explicit %NULL.
+ * See the GNU C documentation for details. 
+ * 
+ * 
+ * Since: 2.8
+ */
 #if     __GNUC__ >= 4
 #define G_GNUC_NULL_TERMINATED __attribute__((__sentinel__))
 #else
 #define G_GNUC_NULL_TERMINATED
 #endif
 
+/**
+ * G_GNUC_ALLOC_SIZE:
+ * @x: the index of the argument specifying the allocation size
+ * 
+ * Expands to the GNU C <literal>alloc_size</literal> function attribute if the 
+ * compiler is a new enough <command>gcc</command>. This attribute tells the
+ * compiler that the function returns a pointer to memory of a size that is
+ * specified by the @x<!-- -->th function parameter.
+ * See the GNU C documentation for details. 
+ * 
+ * Since: 2.18
+ */
 #if     (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
 #define G_GNUC_ALLOC_SIZE(x) __attribute__((__alloc_size__(x)))
 #define G_GNUC_ALLOC_SIZE2(x,y) __attribute__((__alloc_size__(x,y)))
@@ -75,6 +190,42 @@
 #define G_GNUC_ALLOC_SIZE2(x,y)
 #endif
 
+/**
+ * G_GNUC_PRINTF:
+ * @format_idx: the index of the argument corresponding to the format string.
+ *     (The arguments are numbered from 1).
+ * @arg_idx: the index of the first of the format arguments.
+ * 
+ * Expands to the GNU C <literal>format</literal> function attribute if the compiler is 
+ * <command>gcc</command>. This is used for declaring functions which take a variable number of
+ * arguments, with the same syntax as printf().
+ * It allows the compiler to type-check the arguments passed to the function.
+ * See the GNU C documentation for details. 
+ * 
+ * <informalexample><programlisting>
+ * gint g_snprintf (gchar  *string,
+ *                  gulong       n,
+ *                  gchar const *format,
+ *                  ...) G_GNUC_PRINTF (3, 4);
+ * </programlisting></informalexample>
+ */
+
+/**
+ * G_GNUC_FORMAT:
+ * @arg_idx: the index of the argument.
+ * 
+ * Expands to the GNU C %format_arg function attribute if the compiler is <command>gcc</command>.
+ * This function attribute specifies that a function takes a format
+ * string for a printf(), scanf(), strftime() or strfmon() style function and 
+ * modifies it, so that the result can be passed to a printf(), scanf(), 
+ * strftime() or strfmon() style function (with the remaining arguments to the 
+ * format function the same as  they would have been for the unmodified 
+ * string). See the GNU C documentation for details. 
+ * 
+ * <informalexample><programlisting>
+ * gchar *g_dgettext (gchar *domain_name, gchar *msgid) G_GNUC_FORMAT (2);
+ * </programlisting></informalexample>
+ */
 #if     __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
 #define G_GNUC_PRINTF( format_idx, arg_idx )    \
   __attribute__((__format__ (__printf__, format_idx, arg_idx)))
@@ -100,6 +251,18 @@
 #define G_GNUC_NO_INSTRUMENT
 #endif  /* !__GNUC__ */
 
+/**
+ * G_GNUC_DEPRECATED:
+ * 
+ * Expands to the GNU C <literal>deprecated</literal> attribute if the compiler 
+ * is <command>gcc</command>.
+ * It can be used to mark typedefs, variables and functions as deprecated. 
+ * When called with the <option>-Wdeprecated</option> option, the compiler will 
+ * generate warnings when deprecated interfaces are used.
+ * See the GNU C documentation for details. 
+ * 
+ * Since: 2.2
+ */
 #if    __GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 1)
 #define G_GNUC_DEPRECATED                            \
   __attribute__((__deprecated__))
@@ -167,6 +330,11 @@
  *  been defined. It is assumed that if they are already
  *  defined then the current definition is correct.
  */
+/**
+ * NULL:
+ * 
+ * Defines the standard %NULL pointer.
+ */
 #ifndef NULL
 #  ifdef __cplusplus
 #    define NULL        (0L)
@@ -175,29 +343,91 @@
 #  endif /* !__cplusplus */
 #endif
 
+/**
+ * FALSE:
+ * 
+ * Defines the %FALSE value for the #gboolean type.
+ */
 #ifndef	FALSE
 #define	FALSE	(0)
 #endif
 
+/**
+ * TRUE:
+ * 
+ * Defines the %TRUE value for the #gboolean type.
+ */
 #ifndef	TRUE
 #define	TRUE	(!FALSE)
 #endif
 
+/**
+ * MAX:
+ * @a: a numeric value.
+ * @b: a numeric value.
+ * 
+ * Calculates the maximum of @a and @b.
+ * 
+ * Returns: the maximum of @a and @b.
+ */
 #undef	MAX
 #define MAX(a, b)  (((a) > (b)) ? (a) : (b))
 
+/**
+ * MIN:
+ * @a: a numeric value.
+ * @b: a numeric value.
+ * 
+ * Calculates the minimum of @a and @b.
+ * 
+ * Returns: the minimum of @a and @b.
+ */
 #undef	MIN
 #define MIN(a, b)  (((a) < (b)) ? (a) : (b))
 
+/**
+ * ABS:
+ * @a: a numeric value.
+ * 
+ * Calculates the absolute value of @a.
+ * The absolute value is simply the number with any negative sign taken away.
+ * 
+ * For example,
+ * ABS(-10) is 10.
+ * ABS(10) is also 10.
+ * 
+ * Returns: the absolute value of @a.
+ */
 #undef	ABS
 #define ABS(a)	   (((a) < 0) ? -(a) : (a))
 
+/**
+ * CLAMP:
+ * @x: the value to clamp.
+ * @low: the minimum value allowed.
+ * @high: the maximum value allowed.
+ * 
+ * Ensures that @x is between the limits set by @low and @high. If @low is
+ * greater than @high the result is undefined.
+ * 
+ * For example,
+ * CLAMP(5, 10, 15) is 10.
+ * CLAMP(15, 5, 10) is 10.
+ * CLAMP(20, 15, 25) is 20.
+ * 
+ * Returns: the value of @x clamped to the range between @low and @high.
+ */
 #undef	CLAMP
 #define CLAMP(x, low, high)  (((x) > (high)) ? (high) : (((x) < (low)) ? (low) : (x)))
 
-/* Count the number of elements in an array. The array must be defined
- * as such; using this with a dynamically allocated array will give
- * incorrect results.
+/**
+ * G_N_ELEMENTS:
+ * @arr: the array
+ * 
+ * Determines the number of elements in an array. The array must be
+ * declared so the compiler knows its size at compile-time; this 
+ * macro will not work on an array allocated on the heap, only static
+ * arrays or arrays on the stack.
  */
 #define G_N_ELEMENTS(arr)		(sizeof (arr) / sizeof ((arr)[0]))
 
@@ -209,7 +439,15 @@
 /* Provide convenience macros for handling structure
  * fields through their offsets.
  */
-
+/**
+ * G_STRUCT_OFFSET:
+ * @struct_type: a structure type, e.g. <structname>GtkWidget</structname>.
+ * @member: a field in the structure, e.g. <structfield>window</structfield>.
+ * 
+ * Returns the offset, in bytes, of a member of a struct.
+ * 
+ * Returns: the offset of @member from the start of @struct_type.
+ */
 #if defined(__GNUC__)  && __GNUC__ >= 4
 #  define G_STRUCT_OFFSET(struct_type, member) \
       ((glong) __builtin_offsetof (struct_type, member))
@@ -218,8 +456,28 @@
       ((glong) ((guint8*) &((struct_type*) 0)->member))
 #endif
 
+/**
+ * G_STRUCT_MEMBER_P:
+ * @struct_p: a pointer to a struct.
+ * @struct_offset: the offset from the start of the struct, in bytes.
+ * 
+ * Returns an untyped pointer to a given offset of a struct.
+ * 
+ * Returns: an untyped pointer to @struct_p plus @struct_offset bytes.
+ */
 #define G_STRUCT_MEMBER_P(struct_p, struct_offset)   \
     ((gpointer) ((guint8*) (struct_p) + (glong) (struct_offset)))
+    
+/**
+ * G_STRUCT_MEMBER:
+ * @member_type: the type of the struct field.
+ * @struct_p: a pointer to a struct.
+ * @struct_offset: the offset of the field from the start of the struct, in bytes.
+ * 
+ * Returns a member of a structure at a given offset, using the given type.
+ * 
+ * Returns: the struct member.
+ */
 #define G_STRUCT_MEMBER(member_type, struct_p, struct_offset)   \
     (*(member_type*) G_STRUCT_MEMBER_P ((struct_p), (struct_offset)))
 
@@ -239,6 +497,19 @@
  * (usually char*) are const or not.  Don't try using this feature for
  * functions with C++ linkage.
  */
+/**
+ * G_CONST_RETURN:
+ * 
+ * If %G_DISABLE_CONST_RETURNS is defined, this macro expands to nothing.
+ * By default, the macro expands to <literal>const</literal>. The macro 
+ * should be used in place of <literal>const</literal> for functions that 
+ * return a value that should not be modified. The purpose of this macro is 
+ * to allow us to turn on <literal>const</literal> for returned constant 
+ * strings by default, while allowing programmers who find that annoying to 
+ * turn it off. This macro should only be used for return values and for
+ * <emphasis>out</emphasis> parameters, it doesn't make sense for 
+ * <emphasis>in</emphasis> parameters. 
+ */
 #ifdef G_DISABLE_CONST_RETURNS
 #define G_CONST_RETURN
 #else
Index: glib/gkeyfile.h
===================================================================
--- glib/gkeyfile.h	(revision 7087)
+++ glib/gkeyfile.h	(working copy)
@@ -31,6 +31,17 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GKeyFileError:
+ * @G_KEY_FILE_ERROR_UNKNOWN_ENCODING: the text being parsed was in an unknown encoding
+ * @G_KEY_FILE_ERROR_PARSE: document was ill-formed
+ * @G_KEY_FILE_ERROR_NOT_FOUND: the file was not found
+ * @G_KEY_FILE_ERROR_KEY_NOT_FOUND: a requested key was not found
+ * @G_KEY_FILE_ERROR_GROUP_NOT_FOUND: a requested group was not found
+ * @G_KEY_FILE_ERROR_INVALID_VALUE: a value could not be parsed
+ * 
+ * Error codes returned by key file parsing.
+ */
 typedef enum
 {
   G_KEY_FILE_ERROR_UNKNOWN_ENCODING,
@@ -41,12 +52,38 @@
   G_KEY_FILE_ERROR_INVALID_VALUE
 } GKeyFileError;
 
+
+/**
+ * G_KEY_FILE_ERROR:
+ * 
+ * Error domain for key file parsing. Errors in this domain will
+ * be from the #GKeyFileError enumeration. See #GError for information on 
+ * error domains.
+ */
 #define G_KEY_FILE_ERROR g_key_file_error_quark()
 
 GQuark g_key_file_error_quark (void);
 
+/**
+ * GKeyFile:
+ * 
+ * The <structname>GKeyFile</structname> struct contains only private fields
+ * and should not be used directly.
+ */
 typedef struct _GKeyFile GKeyFile;
 
+/**
+ * GKeyFileFlags:
+ * @G_KEY_FILE_NONE: No flags, default behaviour
+ * @G_KEY_FILE_KEEP_COMMENTS: Use this flag if you plan to write the (possibly modified)
+ *  contents of the key file back to a file; otherwise all comments will be lost when
+ *  the key file is written back.
+ * @G_KEY_FILE_KEEP_TRANSLATIONS: Use this flag if you plan to write the (possibly modified)
+ *  contents of the key file back to a file; otherwise only the translations for the current
+ *  language will be written back.
+ * 
+ * Flags which influence the parsing.
+ */
 typedef enum
 {
   G_KEY_FILE_NONE              = 0,
@@ -219,30 +256,290 @@
 					     GError              **error);
 
 /* Defines for handling freedesktop.org Desktop files */
+
+/**
+ * G_KEY_FILE_DESKTOP_GROUP:
+ * 
+ * The name of the main group of a desktop entry file, as defined in the
+ * <ulink url="http://freedesktop.org/Standards/desktop-entry-spec">Desktop
+ * Entry Specification</ulink>. Consult the specification for more
+ * details about the meanings of the keys below.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_GROUP                "Desktop Entry"
 
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_TYPE:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a string giving the type of the desktop entry. Usually
+ * <link linkend="G-KEY-FILE-DESKTOP-TYPE-APPLICATION:CAPS"><literal>G_KEY_FILE_DESKTOP_TYPE_APPLICATION</literal></link>,
+ * <link linkend="G-KEY-FILE-DESKTOP-TYPE-LINK:CAPS"><literal>G_KEY_FILE_DESKTOP_TYPE_LINK</literal></link>, or
+ * <link linkend="G-KEY-FILE-DESKTOP-TYPE-DIRECTORY:CAPS"><literal>G_KEY_FILE_DESKTOP_TYPE_DIRECTORY</literal></link>.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_TYPE             "Type"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_VERSION:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a string giving the version of the Desktop
+ * Entry Specification used for the desktop entry file.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_VERSION          "Version"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_NAME:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a localized string giving the specific name of the
+ * desktop entry.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_NAME             "Name"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_GENERIC_NAME:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a localized string giving the generic name of the
+ * desktop entry.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_GENERIC_NAME     "GenericName"
+
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_NO_DISPLAY:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a boolean stating whether the desktop entry should be
+ * shown in menus.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_NO_DISPLAY       "NoDisplay"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_COMMENT:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a localized string giving the tooltip for the desktop
+ * entry.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_COMMENT          "Comment"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_ICON:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a localized string giving the name of the icon to be
+ * displayed for the desktop entry.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_ICON             "Icon"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_HIDDEN:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a boolean stating whether the desktop entry has been
+ * deleted by the user.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_HIDDEN           "Hidden"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_ONLY_SHOW_IN:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a list of strings identifying the environments that
+ * should display the desktop entry.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_ONLY_SHOW_IN     "OnlyShowIn"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_NOT_SHOW_IN:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a list of strings identifying the environments that
+ * should not display the desktop entry.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_NOT_SHOW_IN      "NotShowIn"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_TRY_EXEC:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a string giving the file name of a binary on disk
+ * used to determine if the program is actually installed. It is only
+ * valid for desktop entries with the <literal>Application</literal>
+ * type.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_TRY_EXEC         "TryExec"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_EXEC:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a string giving the command line to execute. It is only
+ * valid for desktop entries with the <literal>Application</literal>
+ * type.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_EXEC             "Exec"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_PATH:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a string containing the working directory to run the
+ * program in. It is only valid for desktop entries with the
+ * <literal>Application</literal> type.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_PATH             "Path"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_TERMINAL:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a boolean stating whether the program should be
+ * run in a terminal window. It is only valid for desktop entries with
+ * the <literal>Application</literal> type.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_TERMINAL         "Terminal"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_MIME_TYPE:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a list of strings giving the MIME types supported
+ * by this desktop entry.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_MIME_TYPE        "MimeType"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_CATEGORIES:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a list of strings giving the categories in which the
+ * desktop entry should be shown in a menu.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_CATEGORIES       "Categories"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_STARTUP_NOTIFY:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a boolean stating whether the application supports
+ * the <ulink
+ * url="http://www.freedesktop.org/Standards/startup-notification-spec">Startup
+ * Notification Protocol Specification</ulink>.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_STARTUP_NOTIFY   "StartupNotify"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_STARTUP_WM_CLASS:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is string identifying the WM class or name hint of a
+ * window that the application will create, which can be used to emulate
+ * Startup Notification with older applications.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_STARTUP_WM_CLASS "StartupWMClass"
+
+/**
+ * G_KEY_FILE_DESKTOP_KEY_URL:
+ * 
+ * A key under <link
+ * linkend="G-KEY-FILE-DESKTOP-GROUP:CAPS"><literal>G_KEY_FILE_DESKTOP_GROUP</literal></link>
+ * whose value is a string giving the URL to access. It is only valid
+ * for desktop entries with the <literal>Link</literal> type.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_KEY_URL              "URL"
 
+/**
+ * G_KEY_FILE_DESKTOP_TYPE_APPLICATION:
+ * 
+ * The value of the <link
+ * linkend="G-KEY-FILE-DESKTOP-KEY-TYPE:CAPS"><literal>G_KEY_FILE_DESKTOP_KEY_TYPE</literal></link>
+ * key for desktop entries representing applications.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_TYPE_APPLICATION     "Application"
+
+/**
+ * G_KEY_FILE_DESKTOP_TYPE_LINK:
+ * 
+ * The value of the <link
+ * linkend="G-KEY-FILE-DESKTOP-KEY-TYPE:CAPS"><literal>G_KEY_FILE_DESKTOP_KEY_TYPE</literal></link>
+ * key for desktop entries representing links to documents.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_TYPE_LINK            "Link"
+
+/**
+ * G_KEY_FILE_DESKTOP_TYPE_DIRECTORY:
+ * 
+ * The value of the <link
+ * linkend="G-KEY-FILE-DESKTOP-KEY-TYPE:CAPS"><literal>G_KEY_FILE_DESKTOP_KEY_TYPE</literal></link>
+ * key for desktop entries representing directories.
+ * 
+ * Since: 2.14
+ */
 #define G_KEY_FILE_DESKTOP_TYPE_DIRECTORY       "Directory"
 
 G_END_DECLS
Index: glib/gbookmarkfile.c
===================================================================
--- glib/gbookmarkfile.c	(revision 7087)
+++ glib/gbookmarkfile.c	(working copy)
@@ -57,6 +57,82 @@
 
 #include "galias.h"
 
+/**
+ * SECTION:bookmarkfile
+ * @Short_description: parses files containing bookmarks
+ * @Title: Bookmark file parser
+ * 
+ * #GBookmarkFile lets you parse, edit or create files containing bookmarks
+ * to URI, along with some meta-data about the resource pointed by the URI like
+ * its MIME type, the application that is registering the bookmark and the
+ * icon that should be used to represent the bookmark. The data is stored using
+ * the
+ * <ulink url="http://www.gnome.org/~ebassi/bookmark-spec">Desktop Bookmark
+ * Specification</ulink>.
+ * 
+ * 
+ * The syntax of the bookmark files is described in detail inside the Desktop
+ * Bookmark Specification, here is a quick summary: bookmark files use a sub-class
+ * of the
+ * <ulink url="">XML Bookmark Exchange Language</ulink> specification, consisting
+ * of valid UTF-8 encoded XML, under the <literal>xbel</literal> root element;
+ * each bookmark is stored inside a <literal>bookmark</literal> element, using
+ * its URI: no relative paths can be used inside a bookmark file. The bookmark
+ * may have a user defined title and description, to be used instead of the URI.
+ * Under the <literal>metadata</literal> element, with its <literal>owner</literal>
+ * attribute set to <literal>http://freedesktop.org</literal>, is stored the
+ * meta-data about a resource pointed by its URI. The meta-data consists of
+ * the resource's MIME type; the applications that have registered a bookmark;
+ * the groups to which a bookmark belongs to; a visibility flag, used to set
+ * the bookmark as "private" to the applications and groups that has it
+ * registered; the URI and MIME type of an icon, to be used when displaying the
+ * bookmark inside a GUI.
+ * 
+ * 
+ * <informalexample><programlisting>
+ * <![CDATA[
+ * <?xml version="1.0"?>
+ * <!DOCTYPE xbel PUBLIC 
+ *   "+//IDN python.org//DTD XML Bookmark Exchange Language 1.0//EN//XML"
+ *   "http://www.python.org/topics/xml/dtds/xbel-1.0.dtd">
+ * <xbel version="1.0"
+ *       xmlns:mime="http://www.freedesktop.org/standards/shared-mime-info"
+ *       xmlns:bookmark="http://www.freedesktop.org/standards/desktop-bookmarks">
+ *   <bookmark href="file:///home/ebassi/bookmark-spec/bookmark-spec.xml">
+ *     <title>Desktop Bookmarks Spec</title>
+ *     <info>
+ *       <metadata owner="http://freedesktop.org">
+ *         <mime:mime-type>text/xml</mime:mime-type>
+ * 	<bookmark:applications>
+ *           <bookmark:application name="GEdit" count="2" exec="gedit %u" timestamp="1115726763"/>
+ *           <bookmark:application name="GViM" count="7" exec="gvim %f" timestamp="1115726812"/>
+ * 	</bookmark:applications>
+ * 	<bookmark:groups>
+ * 	  <bookmark:group>Editors</bookmark:group>
+ * 	</bookmark:groups>
+ *       </metadata>
+ *     </info>
+ *   </bookmark>
+ * </xbel>
+ * ]]>
+ * </programlisting></informalexample>
+ * 
+ * A bookmark file might contain more than one bookmark; each bookmark is accessed
+ * through its URI.
+ * 
+ * 
+ * The important caveat of bookmark files is that when you add a new bookmark you
+ * must also add the application that is registering it, using
+ * g_bookmark_file_add_application() or g_bookmark_file_set_app_info(). If a
+ * bookmark has no applications then it won't be dumped when creating the
+ * on disk representation, using g_bookmark_file_to_data() or
+ * g_bookmark_file_to_file().
+ * 
+ * 
+ * The #GBookmarkFile parser was added in GLib 2.12.
+ */
+
+
 /* XBEL 1.0 standard entities */
 #define XBEL_VERSION		"1.0"
 #define XBEL_DTD_NICK		"xbel"
Index: glib/gbookmarkfile.h
===================================================================
--- glib/gbookmarkfile.h	(revision 7087)
+++ glib/gbookmarkfile.h	(working copy)
@@ -29,10 +29,31 @@
 
 G_BEGIN_DECLS
 
-/* GError enumeration
+
+/**
+ * G_BOOKMARK_FILE_ERROR:
+ * 
+ * Error domain for bookmark file parsing. Errors in this domain will be
+ * from the #GBookmarkFileError enumeration. See #GError for informations
+ * on error domains.
  */
 #define G_BOOKMARK_FILE_ERROR	(g_bookmark_file_error_quark ())
 
+/**
+ * GBookmarkFileError:
+ * @G_BOOKMARK_FILE_ERROR_INVALID_URI: URI was ill-formed
+ * @G_BOOKMARK_FILE_ERROR_INVALID_VALUE: a requested field was not found
+ * @G_BOOKMARK_FILE_ERROR_APP_NOT_REGISTERED: a requested application did not
+ *  register a bookmark
+ * @G_BOOKMARK_FILE_ERROR_URI_NOT_FOUND: a requested URI was not found
+ * @G_BOOKMARK_FILE_ERROR_READ: document was ill formed
+ * @G_BOOKMARK_FILE_ERROR_UNKNOWN_ENCODING: the text being parsed was in an
+ *  unknown encoding
+ * @G_BOOKMARK_FILE_ERROR_WRITE: an error occurred while writing
+ * @G_BOOKMARK_FILE_ERROR_FILE_NOT_FOUND: requested file was not found
+ * 
+ * Error codes returned by bookmark file parsing.
+ */
 typedef enum
 {
   G_BOOKMARK_FILE_ERROR_INVALID_URI,
@@ -47,8 +68,11 @@
 
 GQuark g_bookmark_file_error_quark (void);
 
-/*
- * GBookmarkFile
+/**
+ * GBookmarkFile:
+ * 
+ * The <structname>GBookmarkFile</structname> struct contains only private data
+ * and should not be used directly.
  */
 typedef struct _GBookmarkFile GBookmarkFile;
 
Index: glib/giowin32.c
===================================================================
--- glib/giowin32.c	(revision 7087)
+++ glib/giowin32.c	(working copy)
@@ -1863,6 +1863,17 @@
   g_io_win32_sock_get_flags,
 };
 
+/**
+ * g_io_channel_win32_new_messages:
+ * @hwnd: a window handle.
+ * 
+ * Creates a new #GIOChannel given a window handle on Windows.
+ * 
+ * This function creates a #GIOChannel that can be used to poll for
+ * Windows messages for the window in question.
+ * 
+ * Returns: a new #GIOChannel.
+ */
 GIOChannel *
 g_io_channel_win32_new_messages (guint hwnd)
 {
@@ -1922,6 +1933,35 @@
   return channel;
 }
 
+/**
+ * g_io_channel_win32_new_fd:
+ * @fd: a C library file descriptor.
+ * 
+ * Creates a new #GIOChannel given a file descriptor on Windows. 
+ * This works for file descriptors from the C runtime.
+ * 
+ * This function works for file descriptors as returned by the open(),
+ * creat(), pipe() and fileno() calls in the Microsoft C runtime. In
+ * order to meaningfully use this function your code should use the same
+ * C runtime as GLib uses, which is msvcrt.dll. Note that in current
+ * Microsoft compilers it is near impossible to convince it to build code
+ * that would use msvcrt.dll. The last Microsoft compiler version that
+ * supported using msvcrt.dll as the C runtime was version 6. The GNU
+ * compiler and toolchain for Windows, also known as Mingw, fully
+ * supports msvcrt.dll.
+ * 
+ * If you have created a #GIOChannel for a file descriptor and started
+ * watching (polling) it, you shouldn't call read() on the file
+ * descriptor. This is because adding polling for a file descriptor is
+ * implemented in GLib on Windows by starting a thread that sits blocked
+ * in a read() from the file descriptor most of the time. All reads from
+ * the file descriptor should be done by this internal GLib thread. Your
+ * code should call only g_io_channel_read().
+ * 
+ * This function is available only in GLib on Windows.
+ * 
+ * Returns: a new #GIOChannel.
+ */
 GIOChannel *
 g_io_channel_win32_new_fd (gint fd)
 {
@@ -1944,6 +1984,21 @@
   return win32_channel->fd;
 }
 
+/**
+ * g_io_channel_win32_new_socket:
+ * @socket: a Winsock socket
+ * 
+ * Creates a new #GIOChannel given a socket on Windows.
+ * 
+ * This function works for sockets created by Winsock. 
+ * It's available only in GLib on Windows.
+ * 
+ * Polling a #GSource created to watch a channel for a socket 
+ * puts the socket in non-blocking mode. This is a side-effect 
+ * of the implementation and unavoidable.
+ * 
+ * Returns: a new #GIOChannel
+ */
 GIOChannel *
 g_io_channel_win32_new_socket (int socket)
 {
Index: glib/glist.c
===================================================================
--- glib/glist.c	(revision 7087)
+++ glib/glist.c	(working copy)
@@ -33,14 +33,95 @@
 #include "glib.h"
 #include "galias.h"
 
+/**
+ * SECTION:linked_lists_double
+ * @Short_description: linked lists containing integer values or pointers to 
+ * data, with the ability to iterate over the list in both directions
+ * @Title: Doubly-Linked Lists
+ * 
+ * The #GList structure and its associated functions provide a standard
+ * doubly-linked list data structure.
+ * 
+ * Each element in the list contains a piece of data, together with pointers
+ * which link to the previous and next elements in the list.
+ * Using these pointers it is possible to move through the list in both
+ * directions (unlike the
+ * <link linkend="glib-Singly-Linked-lists">Singly-Linked Lists</link>
+ * which only allows movement through the list in the forward direction).
+ * 
+ * The data contained in each element can be either integer values, by using one
+ * of the
+ * <link linkend="glib-Type-Conversion-Macros">Type Conversion Macros</link>,
+ * or simply pointers to any type of data.
+ * 
+ * List elements are allocated from the <link linkend="glib-Memory-Slices">slice
+ * allocator</link>, which is more efficient than allocating elements 
+ * individually.
+ * 
+ * Note that most of the #GList functions expect to be passed a pointer to
+ * the first element in the list. The functions which insert elements return
+ * the new start of the list, which may have changed.
+ * 
+ * There is no function to create a #GList. %NULL is considered to be the empty
+ * list so you simply set a #GList* to %NULL.
+ * 
+ * To add elements, use g_list_append(), g_list_prepend(), g_list_insert()
+ * and g_list_insert_sorted().
+ * 
+ * To remove elements, use g_list_remove().
+ * 
+ * To find elements in the list use g_list_first(), g_list_last(), g_list_next(),
+ * g_list_previous(), g_list_nth(), g_list_nth_data(), g_list_find() and
+ * g_list_find_custom().
+ * 
+ * To find the index of an element use g_list_position() and g_list_index().
+ * 
+ * To call a function for each element in the list use g_list_foreach().
+ * 
+ * To free the entire list, use g_list_free().
+ */
 
+/**
+ * g_list_push_allocator:
+ * @allocator: the #GAllocator to use when allocating #GList elements.
+ * 
+ * Sets the allocator to use to allocate #GList elements.
+ * Use g_list_pop_allocator() to restore the previous allocator.
+ * 
+ * Note that this function is not available if GLib has been compiled
+ * with <option>--disable-mem-pools</option>
+ * 
+ * Deprecated: 2.10: It does nothing, since #GList has been
+ *  converted to the <link linkend="glib-Memory-Slices">slice allocator</link>
+ */
 void g_list_push_allocator (gpointer dummy) { /* present for binary compat only */ }
+
+/**
+ * g_list_pop_allocator:
+ * 
+ * Restores the previous #GAllocator, used when allocating #GList elements.
+ * 
+ * Note that this function is not available if GLib has been compiled
+ * with <option>--disable-mem-pools</option>
+ * 
+ * Deprecated: 2.10: It does nothing, since #GList has been
+ *  converted to the <link linkend="glib-Memory-Slices">slice allocator</link>
+ */
 void g_list_pop_allocator  (void)           { /* present for binary compat only */ }
 
 #define _g_list_alloc()         g_slice_new (GList)
 #define _g_list_alloc0()        g_slice_new0 (GList)
 #define _g_list_free1(list)     g_slice_free (GList, list)
 
+/**
+ * g_list_alloc:
+ * 
+ * Allocates space for one #GList element.
+ * It is called by g_list_append(), g_list_prepend(), g_list_insert() and
+ * g_list_insert_sorted() and so is rarely used on its own.
+ * 
+ * Returns: a pointer to the newly-allocated #GList element.
+ */
 GList*
 g_list_alloc (void)
 {
Index: glib/glist.h
===================================================================
--- glib/glist.h	(revision 7087)
+++ glib/glist.h	(working copy)
@@ -35,6 +35,16 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GList:
+ * @data: holds the element's data, which can be a pointer to any kind of data, 
+ *  or any integer value using the
+ *  <link linkend="glib-Type-Conversion-Macros">Type Conversion Macros</link>.
+ * @next: contains the link to the next element in the list.
+ * @prev: contains the link to the previous element in the list.
+ * 
+ * The #GList struct is used for each element in a doubly-linked list.
+ */
 typedef struct _GList GList;
 
 struct _GList
@@ -49,6 +59,12 @@
 GList*   g_list_alloc                   (void) G_GNUC_WARN_UNUSED_RESULT;
 void     g_list_free                    (GList            *list);
 void     g_list_free_1                  (GList            *list);
+
+/**
+ * g_list_free1:
+ * 
+ * Another name for g_list_free_1().
+ */
 #define  g_list_free1                   g_list_free_1
 GList*   g_list_append                  (GList            *list,
 					 gpointer          data) G_GNUC_WARN_UNUSED_RESULT;
@@ -106,8 +122,24 @@
 gpointer g_list_nth_data                (GList            *list,
 					 guint             n);
 
+/**
+ * g_list_previous:
+ * @list: an element in a #GList.
+ * 
+ * A convenience macro to gets the previous element in a #GList.
+ * 
+ * Returns: the previous element, or %NULL if there are no previous elements.
+ */
+#define g_list_previous(list)	        ((list) ? (((GList *)(list))->prev) : NULL)
 
-#define g_list_previous(list)	        ((list) ? (((GList *)(list))->prev) : NULL)
+/**
+ * g_list_next:
+ * @list: an element in a #GList.
+ * 
+ * A convenience macro to gets the next element in a #GList.
+ * 
+ * Returns: the next element, or %NULL if there are no more elements.
+ */
 #define g_list_next(list)	        ((list) ? (((GList *)(list))->next) : NULL)
 
 #ifndef G_DISABLE_DEPRECATED
Index: glib/gasyncqueue.c
===================================================================
--- glib/gasyncqueue.c	(revision 7087)
+++ glib/gasyncqueue.c	(working copy)
@@ -29,6 +29,57 @@
 #include "glib.h"
 #include "galias.h"
 
+/**
+ * SECTION:async_queues
+ * @Short_description: asynchronous communication between threads
+ * @Title: Asynchronous Queues
+ * 
+ * Often you need to communicate between different threads. In general
+ * it's safer not to do this by shared memory, but by explicit message
+ * passing. These messages only make sense asynchronously for
+ * multi-threaded applications though, as a synchronous operation could as
+ * well be done in the same thread.
+ * 
+ * 
+ * Asynchronous queues are an exception from most other GLib data
+ * structures, as they can be used simultaneously from multiple threads
+ * without explicit locking and they bring their own builtin reference
+ * counting. This is because the nature of an asynchronous queue is that
+ * it will always be used by at least 2 concurrent threads.
+ * 
+ * 
+ * For using an asynchronous queue you first have to create one with
+ * g_async_queue_new(). A newly-created queue will get the reference
+ * count 1. Whenever another thread is creating a new reference of (that
+ * is, pointer to) the queue, it has to increase the reference count
+ * (using g_async_queue_ref()). Also, before removing this reference, the
+ * reference count has to be decreased (using
+ * g_async_queue_unref()). After that the queue might no longer exist so
+ * you must not access it after that point.
+ * 
+ * 
+ * A thread, which wants to send a message to that queue simply calls
+ * g_async_queue_push() to push the message to the queue.
+ * 
+ * 
+ * A thread, which is expecting messages from an asynchronous queue
+ * simply calls g_async_queue_pop() for that queue. If no message is
+ * available in the queue at that point, the thread is now put to sleep
+ * until a message arrives. The message will be removed from the queue
+ * and returned. The functions g_async_queue_try_pop() and
+ * g_async_queue_timed_pop() can be used to only check for the presence
+ * of messages or to only wait a certain time for messages respectively.
+ * 
+ * 
+ * For almost every function there exist two variants, one that locks the
+ * queue and one that doesn't. That way you can hold the queue lock
+ * (acquire it with g_async_queue_lock() and release it with
+ * g_async_queue_unlock()) over multiple queue accessing
+ * instructions. This can be necessary to ensure the integrity of the
+ * queue, but should only be used when really necessary, as it can make
+ * your life harder if used unwisely. Normally you should only use the
+ * locking function variants (those without the suffix _unlocked)
+ */
 
 struct _GAsyncQueue
 {
Index: glib/gbase64.c
===================================================================
--- glib/gbase64.c	(revision 7087)
+++ glib/gbase64.c	(working copy)
@@ -37,6 +37,28 @@
 	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
 /**
+ * SECTION:base64
+ * @Short_description: encodes and decodes data in Base64 format
+ * @Title: Base64 Encoding
+ * 
+ * Base64 is an encoding that allows to encode a sequence of arbitrary
+ * bytes as a sequence of printable ASCII characters. For the definition
+ * of Base64, see <ulink url="http://www.ietf.org/rfc/rfc1421.txt">RFC 
+ * 1421</ulink> or <ulink url="http://www.ietf.org/rfc/rfc2045.txt">RFC
+ * 2045</ulink>. Base64 is most commonly used as a MIME transfer encoding
+ * for email.
+ * 
+ * 
+ * GLib supports incremental encoding using g_base64_encode_step() and
+ * g_base64_encode_close(). Incremental decoding can be done with
+ * g_base64_decode_step(). To encode or decode data in one go, use 
+ * g_base64_encode() or g_base64_decode(). 
+ * 
+ * 
+ * Support for Base64 encoding has been added in GLib 2.12.
+ */
+
+/**
  * g_base64_encode_step:
  * @in: the binary data to encode
  * @len: the length of @in
Index: glib/gi18n.h
===================================================================
--- glib/gi18n.h	(revision 7087)
+++ glib/gi18n.h	(working copy)
@@ -24,9 +24,114 @@
 
 #include <libintl.h>
 
+/**
+ * SECTION:i18n
+ * @Short_description: gettext support macros
+ * @Title: Internationalization
+ * @See_also:The gettext manual.
+ * 
+ * GLib doesn't force any particular localization method upon its users.
+ * But since GLib itself is localized using the gettext() mechanism, it seems
+ * natural to offer the de-facto standard gettext() support macros in an 
+ * easy-to-use form.
+ * 
+ * In order to use these macros in an application, you must include 
+ * <filename>glib/gi18n.h</filename>. For use in a library, must include
+ * <filename>glib/gi18n-lib.h</filename> <emphasis>after</emphasis> defining
+ * the GETTEXT_PACKAGE macro suitably for your library:
+ * <informalexample><programlisting>
+ * #define GETTEXT_PACKAGE "gtk20"
+ * #include <glib/gi18n-lib.h>
+ * </programlisting></informalexample>
+ * The gettext manual covers details of how to set up message extraction
+ * with xgettext.
+ */
+
 #define  _(String) gettext (String)
+
+/**
+ * Q_:
+ * @String: the string to be translated, with a '|'-separated prefix which 
+ *  must not be translated
+ * 
+ * Like _(), but handles context in message ids. This has the advantage that 
+ * the string can be adorned with a prefix to guarantee uniqueness and provide 
+ * context to the translator. 
+ * 
+ * One use case given in the gettext manual is GUI translation, where one could 
+ * e.g. disambiguate two "Open" menu entries as "File|Open" and "Printer|Open". 
+ * Another use case is the string "Russian" which may have to be translated
+ * differently depending on whether it's the name of a character set or a 
+ * language. This could be solved by using "charset|Russian" and 
+ * "language|Russian".
+ * 
+ * See the C_() macro for a different way to mark up translatable strings
+ * with context.
+ * 
+ * If you are using the Q_() macro, you need to make sure that you 
+ * pass <option>--keyword=Q_</option> to xgettext when extracting messages.
+ * If you are using GNU gettext >= 0.15, you can also use
+ * <option>--keyword=Q_:1g</option> to let xgettext split the context
+ * string off into a msgctxt line in the po file.
+ * </para></note>
+ * 
+ * Since: 2.4
+ * Returns: the translated message
+ */
 #define Q_(String) g_dpgettext (NULL, String, 0)
+
+/**
+ * N_:
+ * @String: the string to be translated
+ * 
+ * Only marks a string for translation.
+ * This is useful in situations where the translated strings can't
+ * be directly used, e.g. in string array initializers. 
+ * To get the translated string, call gettext() at runtime.
+ * 
+ * <informalexample><programlisting>
+ *      {
+ *        static const char *messages[] = {
+ *          N_("some very meaningful message"),
+ *          N_("and another one")
+ *        };
+ *        const char *string;
+ *        ...
+ *        string
+ *          = index > 1 ? _("a default message") : gettext (messages[index]);
+ * <!-- -->     
+ *        fputs (string);
+ *        ...
+ *      }
+ * </programlisting></informalexample>
+ * 
+ * Since: 2.4
+ */
 #define N_(String) (String)
+
+/**
+ * C_:
+ * @Context: a message context, must be a string literal
+ * @String: a message id, must be a string literal
+ * 
+ * Uses gettext to get the translation for @msgid. @msgctxt is 
+ * used as a context. This is mainly useful for short strings which 
+ * may need different translations, depending on the context in which 
+ * they are used.
+ * <informalexample><programlisting>
+ * label1 = C_("Navigation", "Back");
+ * label2 = C_("Body part", "Back");
+ * </programlisting></informalexample> 
+ * 
+ * 
+ * If you are using the C_() macro, you need to make sure that you 
+ * pass <option>--keyword=C_:1c,2</option> to xgettext when extracting 
+ * messages. Note that this only works with GNU gettext >= 0.15. 
+ * </para></note>
+ * 
+ * Since: 2.16
+ * Returns: the translated message
+ */
 #define C_(Context,String) g_dpgettext (NULL, Context "\004" String, strlen (Context) + 1)
 
 #endif  /* __G_I18N_H__ */
Index: glib/gasyncqueue.h
===================================================================
--- glib/gasyncqueue.h	(revision 7087)
+++ glib/gasyncqueue.h	(working copy)
@@ -35,6 +35,13 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GAsyncQueue:
+ * 
+ * The #GAsyncQueue struct is an opaque data structure, which represents
+ * an asynchronous queue. It should only be accessed through the
+ * <function>g_async_queue_*</function> functions.
+ */
 typedef struct _GAsyncQueue GAsyncQueue;
 
 /* Asyncronous Queues, can be used to communicate between threads */
Index: glib/gurifuncs.c
===================================================================
--- glib/gurifuncs.c	(revision 7087)
+++ glib/gurifuncs.c	(working copy)
@@ -28,7 +28,8 @@
 
 /**
  * SECTION:gurifuncs
- * @short_description: URI Functions
+ * @Title: URI Functions
+ * @short_description: functions for manipulating URIs
  * 
  * Functions for manipulating Universal Resource Identifiers (URIs) as 
  * defined by RFC 3986. It is highly recommended that you have read and
Index: glib/gregex.c
===================================================================
--- glib/gregex.c	(revision 7087)
+++ glib/gregex.c	(working copy)
@@ -40,6 +40,67 @@
 
 #include "galias.h"
 
+/**
+ * SECTION:gregex
+ * @Short_description: matches strings against regular expressions
+ * @Title: Perl-compatible regular expressions
+ * 
+ * The <function>g_regex_*()</function> functions implement regular
+ * expression pattern matching using syntax and semantics similar to
+ * Perl regular expression.
+ * 
+ * Some functions accept a <parameter>start_position</parameter> argument,
+ * setting it differs from just passing over a shortened string and setting
+ * #G_REGEX_MATCH_NOTBOL in the case of a pattern that begins with any kind
+ * of lookbehind assertion.
+ * For example, consider the pattern "\Biss\B" which finds occurrences of "iss"
+ * in the middle of words. ("\B" matches only if the current position in the
+ * subject is not a word boundary.) When applied to the string "Mississipi"
+ * from the fourth byte, namely "issipi", it does not match, because "\B" is
+ * always false at the start of the subject, which is deemed to be a word
+ * boundary. However, if the entire string is passed , but with
+ * <parameter>start_position</parameter> set to 4, it finds the second
+ * occurrence of "iss" because it is able to look behind the starting point
+ * to discover that it is preceded by a letter.
+ * 
+ * Note that, unless you set the #G_REGEX_RAW flag, all the strings passed
+ * to these functions must be encoded in UTF-8. The lengths and the positions
+ * inside the strings are in bytes and not in characters, so, for instance,
+ * "\xc3\xa0" (i.e. "&agrave;") is two bytes long but it is treated as a single
+ * character. If you set #G_REGEX_RAW the strings can be non-valid UTF-8
+ * strings and a byte is treated as a character, so "\xc3\xa0" is two bytes
+ * and two characters long.
+ * 
+ * When matching a pattern, "\n" matches only against a "\n" character in the
+ * string, and "\r" matches only a "\r" character. To match any newline sequence
+ * use "\R". This particular group matches either the two-character sequence
+ * CR + LF ("\r\n"), or one of the single characters LF (linefeed, U+000A, "\n"), VT
+ * (vertical tab, U+000B, "\v"), FF (formfeed, U+000C, "\f"), CR (carriage return,
+ * U+000D, "\r"), NEL (next line, U+0085), LS (line separator, U+2028), or PS
+ * (paragraph separator, U+2029).
+ * 
+ * The behaviour of the dot, circumflex, and dollar metacharacters are affected by
+ * newline characters, the default is to recognize any newline character (the same
+ * characters recognized by "\R"). This can be changed with #G_REGEX_NEWLINE_CR,
+ * #G_REGEX_NEWLINE_LF and #G_REGEX_NEWLINE_CRLF compile options,
+ * and with #G_REGEX_MATCH_NEWLINE_ANY, #G_REGEX_MATCH_NEWLINE_CR,
+ * #G_REGEX_MATCH_NEWLINE_LF and #G_REGEX_MATCH_NEWLINE_CRLF match options.
+ * These settings are also relevant when compiling a pattern if
+ * #G_REGEX_EXTENDED is set, and an unescaped "#" outside a character class is
+ * encountered. This indicates a comment that lasts until after the next
+ * newline.
+ * 
+ * Creating and manipulating the same #GRegex structure from different
+ * threads is not a problem as #GRegex does not modify its internal
+ * state between creation and destruction, on the other hand #GMatchInfo is
+ * not threadsafe.
+ * 
+ * The regular expressions low level functionalities are obtained through
+ * the excellent <ulink url="http://www.pcre.org/">PCRE</ulink> library
+ * written by Philip Hazel.
+ */
+
+
 /* Mask of all the possible values for GRegexCompileFlags. */
 #define G_REGEX_COMPILE_MASK (G_REGEX_CASELESS		| \
 			      G_REGEX_MULTILINE		| \
Index: glib/giounix.c
===================================================================
--- glib/giounix.c	(revision 7087)
+++ glib/giounix.c	(working copy)
@@ -561,6 +561,33 @@
   return channel;
 }
 
+/**
+ * g_io_channel_unix_new:
+ * @fd: a file descriptor.
+ * 
+ * Creates a new #GIOChannel given a file descriptor.
+ * On UNIX systems this works for plain files, pipes, and sockets.
+ * 
+ * The returned #GIOChannel has a reference count of 1.
+ * 
+ * The default encoding for #GIOChannel is UTF-8. If your application
+ * is reading output from a command using via pipe, you may need to
+ * set the encoding to the encoding of the current locale (see
+ * g_get_charset()) with the g_io_channel_set_encoding() function.
+ * 
+ * If you want to read raw binary data without interpretation, then
+ * call the g_io_channel_set_encoding() function with %NULL for the
+ * encoding argument.
+ * 
+ * This function is available in GLib on Windows, too, but you should
+ * avoid using it on Windows. The domain of file descriptors and sockets
+ * overlap. There is no way for GLib to know which one you mean in case
+ * the argument you pass to this function happens to be both a valid file
+ * descriptor and socket. If that happens a warning is issued, and GLib
+ * assumes that it is the file descriptor you mean.
+ * 
+ * Returns: a new #GIOChannel.
+ */
 GIOChannel *
 g_io_channel_unix_new (gint fd)
 {
@@ -590,6 +617,16 @@
   return channel;
 }
 
+/**
+ * g_io_channel_unix_get_fd:
+ * @channel: a #GIOChannel, created with g_io_channel_unix_new().
+ * 
+ * Returns the file descriptor of the #GIOChannel.
+ * 
+ * On Windows this function returns the file descriptor or socket of the #GIOChannel.
+ * 
+ * Returns: the file descriptor of the #GIOChannel.
+ */
 gint
 g_io_channel_unix_get_fd (GIOChannel *channel)
 {
Index: glib/gmem.c
===================================================================
--- glib/gmem.c	(revision 7087)
+++ glib/gmem.c	(working copy)
@@ -38,6 +38,42 @@
 #include "gthreadprivate.h"
 #include "galias.h"
 
+/**
+ * SECTION:allocators
+ * @Short_description: deprecated way to allocate chunks of memory for GList, GSList and GNode
+ * @Title: Memory Allocators
+ * 
+ * 
+ * Prior to 2.10, #GAllocator was used as an efficient way to allocate 
+ * small pieces of memory for use with the #GList, #GSList and #GNode data 
+ * structures. Since 2.10, it has been completely replaced by the 
+ * <link linkend="glib-Memory-Slices">slice allocator</link> and deprecated.
+ */
+
+/**
+ * SECTION:memory
+ * @Short_description: general memory-handling
+ * @Title: Memory Allocation
+ * 
+ * These functions provide support for allocating and freeing memory.
+ * 
+ * 
+ * <note>
+ * If any call to allocate memory fails, the application is terminated.
+ * This also means that there is no need to check if the call succeeded.
+ * 
+ * </note>
+ * 
+ * <note>
+ * It's important to match g_malloc() with g_free(), plain malloc() with free(),
+ * and (if you're using C++) new with delete and new[] with delete[]. Otherwise
+ * bad things can happen, since these allocators may use different memory
+ * pools (and new/delete call constructors and destructors). See also
+ * g_mem_set_vtable().
+ * 
+ * </note>
+ */
+
 #define MEM_PROFILE_TABLE_SIZE 4096
 
 
@@ -119,6 +155,16 @@
 
 
 /* --- functions --- */
+
+/**
+ * g_malloc:
+ * @n_bytes: the number of bytes to allocate
+ * 
+ * Allocates @n_bytes bytes of memory.
+ * If @n_bytes is 0 it returns %NULL.
+ * 
+ * Returns: a pointer to the allocated memory
+ */
 gpointer
 g_malloc (gsize n_bytes)
 {
@@ -139,6 +185,15 @@
   return NULL;
 }
 
+/**
+ * g_malloc0:
+ * @n_bytes: the number of bytes to allocate
+ * 
+ * Allocates @n_bytes bytes of memory, initialized to 0's.
+ * If @n_bytes is 0 it returns %NULL.
+ * 
+ * Returns: a pointer to the allocated memory
+ */
 gpointer
 g_malloc0 (gsize n_bytes)
 {
@@ -159,6 +214,19 @@
   return NULL;
 }
 
+/**
+ * g_realloc:
+ * @mem: the memory to reallocate
+ * @n_bytes: new size of the memory in bytes
+ * 
+ * Reallocates the memory pointed to by @mem, so that it now has space for
+ * @n_bytes bytes of memory. It returns the new address of the memory, which may
+ * have been moved. @mem may be %NULL, in which case it's considered to 
+ * have zero-length. @n_bytes may be 0, in which case %NULL will be returned
+ * and @mem will be freed unless it is %NULL.
+ * 
+ * Returns: the new address of the allocated memory
+ */
 gpointer
 g_realloc (gpointer mem,
 	   gsize    n_bytes)
@@ -181,6 +249,13 @@
   return NULL;
 }
 
+/**
+ * g_free:
+ * @mem: the memory to free
+ * 
+ * Frees the memory pointed to by @mem.
+ * If @mem is %NULL it simply returns.
+ */
 void
 g_free (gpointer mem)
 {
@@ -190,6 +265,15 @@
     glib_mem_vtable.free (mem);
 }
 
+/**
+ * g_try_malloc:
+ * @n_bytes: number of bytes to allocate.
+ * 
+ * Attempts to allocate @n_bytes, and returns %NULL on failure. 
+ * Contrast with g_malloc(), which aborts the program on failure.
+ * 
+ * Returns: the allocated memory, or %NULL.
+ */
 gpointer
 g_try_malloc (gsize n_bytes)
 {
@@ -201,6 +285,16 @@
     return NULL;
 }
 
+/**
+ * g_try_malloc0:
+ * @n_bytes: number of bytes to allocate
+ * 
+ * Attempts to allocate @n_bytes, initialized to 0's, and returns %NULL on 
+ * failure. Contrast with g_malloc0(), which aborts the program on failure.
+ * 
+ * Since: 2.8
+ * Returns: the allocated memory, or %NULL
+ */
 gpointer
 g_try_malloc0 (gsize n_bytes)
 { 
@@ -214,6 +308,17 @@
   return mem;
 }
 
+/**
+ * g_try_realloc:
+ * @mem: previously-allocated memory, or %NULL.
+ * @n_bytes: number of bytes to allocate.
+ * 
+ * Attempts to realloc @mem to a new size, @n_bytes, and returns %NULL
+ * on failure. Contrast with g_realloc(), which aborts the program
+ * on failure. If @mem is %NULL, behaves the same as g_try_malloc().
+ * 
+ * Returns: the allocated memory, or %NULL.
+ */
 gpointer
 g_try_realloc (gpointer mem,
 	       gsize    n_bytes)
@@ -263,6 +368,18 @@
   return !vtable_set;
 }
 
+/**
+ * g_mem_set_vtable:
+ * @vtable: table of memory allocation routines.
+ * 
+ * Sets the #GMemVTable to use for memory allocation. You can use this to provide
+ * custom memory allocation routines. <emphasis>This function must be called 
+ * before using any other GLib functions.</emphasis> The @vtable only needs to 
+ * provide malloc(), realloc(), and free() functions; GLib can provide default 
+ * implementations of the others. The malloc() and realloc() implementations 
+ * should return %NULL on failure, GLib will handle error-checking for you. 
+ * @vtable is copied, so need not persist after this function has been called.
+ */
 void
 g_mem_set_vtable (GMemVTable *vtable)
 {
@@ -388,6 +505,20 @@
     g_print (" --- none ---\n");
 }
 
+/**
+ * g_mem_profile:
+ * 
+ * Outputs a summary of memory usage.
+ * 
+ * It outputs the frequency of allocations of different sizes,
+ * the total number of bytes which have been allocated,
+ * the total number of bytes which have been freed,
+ * and the difference between the previous two values, i.e. the number of bytes
+ * still in use.
+ * 
+ * Note that this function will not output anything unless you have
+ * previously installed the #glib_mem_profiler_table with g_mem_set_vtable().
+ */
 void
 g_mem_profile (void)
 {
@@ -599,6 +730,116 @@
 #endif	/* !G_DISABLE_CHECKS */
 
 /* --- MemChunks --- */
+/**
+ * SECTION:memory_chunks
+ * @Short_description: deprecated way to allocate groups of equal-sized chunks of memory
+ * @Title: Memory Chunks
+ * 
+ * Memory chunks provide an space-efficient way to allocate equal-sized 
+ * pieces of memory, called atoms. However, due to the administrative 
+ * overhead (in particular for #G_ALLOC_AND_FREE, and when used from multiple 
+ * threads), they are in practise often slower than direct use of g_malloc().
+ * Therefore, memory chunks have been deprecated in favor of the 
+ * <link linkend="glib-Memory-Slices">slice allocator</link>,
+ * which has been added in 2.10. All internal uses of memory chunks in
+ * GLib have been converted to the <literal>g_slice</literal> API.
+ * 
+ * There are two types of memory chunks, #G_ALLOC_ONLY, and #G_ALLOC_AND_FREE.
+ * <itemizedlist>
+ * #G_ALLOC_ONLY chunks only allow allocation of atoms. The atoms can never
+ * be freed individually. The memory chunk can only be free in its entirety.
+ * </para></listitem>
+ * #G_ALLOC_AND_FREE chunks do allow atoms to be freed individually.
+ * The disadvantage of this is that the memory chunk has to keep track of which
+ * atoms have been freed. This results in more memory being used and a slight
+ * degradation in performance.
+ * </para></listitem>
+ * 
+ * </itemizedlist>
+ * 
+ * To create a memory chunk use g_mem_chunk_new() or the convenience macro
+ * g_mem_chunk_create().
+ * 
+ * To allocate a new atom use g_mem_chunk_alloc(), g_mem_chunk_alloc0(),
+ * or the convenience macros g_chunk_new() or g_chunk_new0(). 
+ * 
+ * To free an atom use g_mem_chunk_free(), or the convenience macro
+ * g_chunk_free(). (Atoms can only be freed if the memory chunk is created
+ * with the type set to #G_ALLOC_AND_FREE.)
+ * 
+ * To free any blocks of memory which are no longer being used, use
+ * g_mem_chunk_clean(). To clean all memory chunks, use g_blow_chunks().
+ * 
+ * To reset the memory chunk, freeing all of the atoms, use g_mem_chunk_reset().
+ * 
+ * To destroy a memory chunk, use g_mem_chunk_destroy().
+ * 
+ * To help debug memory chunks, use g_mem_chunk_info() and g_mem_chunk_print().
+ * 
+ * 
+ * <example>
+ * <title>Using a <structname>GMemChunk</structname></title>
+ * <programlisting>
+ *   GMemChunk *mem_chunk;
+ *   gchar *mem[10000];
+ *   gint i;
+ * 
+ *   /<!-- -->* Create a GMemChunk with atoms 50 bytes long, and memory blocks holding
+ *      100 bytes. Note that this means that only 2 atoms fit into each memory
+ *      block and so isn't very efficient. *<!-- -->/
+ *   mem_chunk = g_mem_chunk_new ("test mem chunk", 50, 100, G_ALLOC_AND_FREE);
+ * 
+ *   // Now allocate 10000 atoms.
+ *   for (i = 0; i < 10000; i++)
+ *     {
+ *       mem[i] = g_chunk_new (gchar, mem_chunk);
+ * 
+ *       // Fill in the atom memory with some junk.
+ *       for (j = 0; j < 50; j++)
+ * 	mem[i][j] = i * j;
+ *     }
+ * 
+ *   /<!-- -->* Now free all of the atoms. Note that since we are going to destroy the
+ *      GMemChunk, this wouldn't normally be used. *<!-- -->/
+ *   for (i = 0; i < 10000; i++)
+ *     {
+ *       g_mem_chunk_free (mem_chunk, mem[i]);
+ *     }
+ * 
+ *   // We are finished with the GMemChunk, so we destroy it.
+ *   g_mem_chunk_destroy (mem_chunk);
+ * </programlisting></example>
+ * 
+ * <example>
+ * <title>Using a <structname>GMemChunk</structname> with data structures</title>
+ * <programlisting>
+ *   GMemChunk *array_mem_chunk;
+ *   GRealArray *array;
+ * 
+ *   /<!-- -->* Create a GMemChunk to hold GRealArray structures, using the
+ *      g_mem_chunk_create(<!-- -->) convenience macro. We want 1024 atoms in each
+ *      memory block, and we want to be able to free individual atoms. *<!-- -->/
+ *   array_mem_chunk = g_mem_chunk_create (GRealArray, 1024, G_ALLOC_AND_FREE);
+ * 
+ *   // Allocate one atom, using the g_chunk_new(<!-- -->) convenience macro.
+ *   array = g_chunk_new (GRealArray, array_mem_chunk);
+ * 
+ *   // We can now use array just like a normal pointer to a structure.
+ *   array->data            = NULL;
+ *   array->len             = 0;
+ *   array->alloc           = 0;
+ *   array->zero_terminated = (zero_terminated ? 1 : 0);
+ *   array->clear           = (clear ? 1 : 0);
+ *   array->elt_size        = elt_size;
+ * 
+ *   // We can free the element, so it can be reused.
+ *   g_chunk_free (array, array_mem_chunk);
+ * 
+ *   // We destroy the GMemChunk when we are finished with it.
+ *   g_mem_chunk_destroy (array_mem_chunk);
+ * </programlisting></example>
+ */
+
 #ifndef G_ALLOC_AND_FREE
 typedef struct _GAllocator GAllocator;
 typedef struct _GMemChunk  GMemChunk;
@@ -610,6 +851,26 @@
   guint alloc_size;           /* the size of an atom */
 };
 
+/**
+ * g_mem_chunk_new:
+ * @name: a string to identify the #GMemChunk. It is not copied so it
+ *  should be valid for the lifetime of the #GMemChunk. It is only used in
+ *  g_mem_chunk_print(), which is used for debugging.
+ * @atom_size: the size, in bytes, of each element in the #GMemChunk.
+ * @area_size: the size, in bytes, of each block of memory allocated to contain
+ *  the atoms.
+ * @type: the type of the #GMemChunk.
+ *  #G_ALLOC_AND_FREE is used if the atoms will be freed individually.
+ *  #G_ALLOC_ONLY should be used if atoms will never be freed individually.
+ *  #G_ALLOC_ONLY is quicker, since it does not need to track free atoms,
+ *  but it obviously wastes memory if you no longer need many of the atoms.
+ * 
+ * Creates a new #GMemChunk.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice allocator</link>
+ *  instead
+ * Returns: the new #GMemChunk.
+ */
 GMemChunk*
 g_mem_chunk_new (const gchar  *name,
 		 gint          atom_size,
@@ -624,6 +885,15 @@
   return mem_chunk;
 }
 
+/**
+ * g_mem_chunk_destroy:
+ * @mem_chunk: a #GMemChunk.
+ * 
+ * Frees all of the memory allocated for a #GMemChunk.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice 
+ *  allocator</link> instead
+ */
 void
 g_mem_chunk_destroy (GMemChunk *mem_chunk)
 {
@@ -632,6 +902,15 @@
   g_slice_free (GMemChunk, mem_chunk);
 }
 
+/**
+ * g_mem_chunk_alloc:
+ * @mem_chunk: a #GMemChunk.
+ * 
+ * Allocates an atom of memory from a #GMemChunk.
+ * 
+ * Deprecated: 2.10: Use g_slice_alloc() instead
+ * Returns: a pointer to the allocated atom.
+ */
 gpointer
 g_mem_chunk_alloc (GMemChunk *mem_chunk)
 {
@@ -640,6 +919,15 @@
   return g_slice_alloc (mem_chunk->alloc_size);
 }
 
+/**
+ * g_mem_chunk_alloc0:
+ * @mem_chunk: a #GMemChunk.
+ * 
+ * Allocates an atom of memory from a #GMemChunk, setting the memory to 0.
+ * 
+ * Deprecated: 2.10:  Use g_slice_alloc0() instead
+ * Returns: a pointer to the allocated atom.
+ */
 gpointer
 g_mem_chunk_alloc0 (GMemChunk *mem_chunk)
 {
@@ -648,6 +936,17 @@
   return g_slice_alloc0 (mem_chunk->alloc_size);
 }
 
+/**
+ * g_mem_chunk_free:
+ * @mem_chunk: a #GMemChunk.
+ * @mem: a pointer to the atom to free.
+ * 
+ * Frees an atom in a #GMemChunk.
+ * This should only be called if the #GMemChunk was created with
+ * #G_ALLOC_AND_FREE. Otherwise it will simply return.
+ * 
+ * Deprecated: 2.10: Use g_slice_free1() instead
+ */
 void
 g_mem_chunk_free (GMemChunk *mem_chunk,
 		  gpointer   mem)
@@ -657,12 +956,78 @@
   g_slice_free1 (mem_chunk->alloc_size, mem);
 }
 
+/**
+ * g_mem_chunk_clean:
+ * @mem_chunk: a #GMemChunk.
+ * 
+ * Frees any blocks in a #GMemChunk which are no longer being used.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice 
+ *  allocator</link> instead
+ */
 void	g_mem_chunk_clean	(GMemChunk *mem_chunk)	{}
+
+/**
+ * g_mem_chunk_reset:
+ * @mem_chunk: a #GMemChunk.
+ * 
+ * Resets a GMemChunk to its initial state.
+ * It frees all of the currently allocated blocks of memory.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice 
+ *  allocator</link> instead
+ */
 void	g_mem_chunk_reset	(GMemChunk *mem_chunk)	{}
+
+/**
+ * g_mem_chunk_print:
+ * @mem_chunk: a #GMemChunk.
+ * 
+ * Outputs debugging information for a #GMemChunk.
+ * It outputs the name of the #GMemChunk (set with g_mem_chunk_new()),
+ * the number of bytes used, and the number of blocks of memory allocated.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice 
+ *  allocator</link> instead
+ */
 void	g_mem_chunk_print	(GMemChunk *mem_chunk)	{}
+
+/**
+ * g_mem_chunk_info:
+ * 
+ * Outputs debugging information for all #GMemChunk objects currently in use.
+ * It outputs the number of #GMemChunk objects currently allocated,
+ * and calls g_mem_chunk_print() to output information on each one.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice 
+ *  allocator</link> instead
+ */
 void	g_mem_chunk_info	(void)			{}
+/**
+ * g_blow_chunks:
+ * 
+ * Calls g_mem_chunk_clean() on all #GMemChunk objects.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice 
+ *  allocator</link> instead
+ */
 void	g_blow_chunks		(void)			{}
 
+/**
+ * g_allocator_new:
+ * @name: the name of the #GAllocator. This name is used to set the name of the
+ *  #GMemChunk used by the #GAllocator, and is only used for debugging.
+ * @n_preallocs: the number of elements in each block of memory allocated.
+ *  Larger blocks mean less calls to g_malloc(), but some memory may be wasted.
+ *  (GLib uses 128 elements per block by default.) The value must be between 1
+ *  and 65535.
+ * 
+ * Creates a new #GAllocator.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice allocator</link>
+ *  instead
+ * Returns: a new #GAllocator.
+ */
 GAllocator*
 g_allocator_new (const gchar *name,
 		 guint        n_preallocs)
@@ -682,6 +1047,15 @@
   return (void*) &dummy;
 }
 
+/**
+ * g_allocator_free:
+ * @allocator: a #GAllocator.
+ * 
+ * Frees all of the memory allocated by the #GAllocator.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice allocator</link>
+ *  instead
+ */
 void
 g_allocator_free (GAllocator *allocator)
 {
Index: glib/gregex.h
===================================================================
--- glib/gregex.h	(revision 7087)
+++ glib/gregex.h	(working copy)
@@ -31,6 +31,56 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GRegexError:
+ * @G_REGEX_ERROR_COMPILE: Compilation of the regular expression failed.
+ * @G_REGEX_ERROR_OPTIMIZE: Optimization of the regular expression failed.
+ * @G_REGEX_ERROR_REPLACE: Replacement failed due to an ill-formed replacement string.
+ * @G_REGEX_ERROR_MATCH: The match process failed.
+ * @G_REGEX_ERROR_INTERNAL: Internal error of the regular expression engine. Since 2.16
+ * @G_REGEX_ERROR_STRAY_BACKSLASH: "\\" at end of pattern. Since 2.16
+ * @G_REGEX_ERROR_MISSING_CONTROL_CHAR: "\\c" at end of pattern. Since 2.16
+ * @G_REGEX_ERROR_UNRECOGNIZED_ESCAPE: Unrecognized character follows "\\". Since 2.16
+ * @G_REGEX_ERROR_QUANTIFIERS_OUT_OF_ORDER: Numbers out of order in "{}" quantifier. Since 2.16
+ * @G_REGEX_ERROR_QUANTIFIER_TOO_BIG: Number too big in "{}" quantifier. Since 2.16
+ * @G_REGEX_ERROR_UNTERMINATED_CHARACTER_CLASS: Missing terminating "]" for character class. Since 2.16
+ * @G_REGEX_ERROR_INVALID_ESCAPE_IN_CHARACTER_CLASS: Invalid escape sequence in character class. Since 2.16
+ * @G_REGEX_ERROR_RANGE_OUT_OF_ORDER: Range out of order in character class. Since 2.16
+ * @G_REGEX_ERROR_NOTHING_TO_REPEAT: Nothing to repeat. Since 2.16
+ * @G_REGEX_ERROR_UNRECOGNIZED_CHARACTER: Unrecognized character after "(?", "(?&lt;" or "(?P". Since 2.16
+ * @G_REGEX_ERROR_POSIX_NAMED_CLASS_OUTSIDE_CLASS: POSIX named classes are supported only within a class. Since 2.16
+ * @G_REGEX_ERROR_UNMATCHED_PARENTHESIS: Missing terminating ")" or ")" without opening "(". Since 2.16
+ * @G_REGEX_ERROR_INEXISTENT_SUBPATTERN_REFERENCE: Reference to non-existent subpattern. Since 2.16
+ * @G_REGEX_ERROR_UNTERMINATED_COMMENT: Missing terminating ")" after comment. Since 2.16
+ * @G_REGEX_ERROR_EXPRESSION_TOO_LARGE: Regular expression too large. Since 2.16
+ * @G_REGEX_ERROR_MEMORY_ERROR: Failed to get memory. Since 2.16
+ * @G_REGEX_ERROR_VARIABLE_LENGTH_LOOKBEHIND: Lookbehind assertion is not fixed length. Since 2.16
+ * @G_REGEX_ERROR_MALFORMED_CONDITION: Malformed number or name after "(?(". Since 2.16
+ * @G_REGEX_ERROR_TOO_MANY_CONDITIONAL_BRANCHES: Conditional group contains more than two branches. Since 2.16
+ * @G_REGEX_ERROR_ASSERTION_EXPECTED: Assertion expected after "(?(". Since 2.16
+ * @G_REGEX_ERROR_UNKNOWN_POSIX_CLASS_NAME: Unknown POSIX class name. Since 2.16
+ * @G_REGEX_ERROR_POSIX_COLLATING_ELEMENTS_NOT_SUPPORTED: POSIX collating elements are not supported. Since 2.16
+ * @G_REGEX_ERROR_HEX_CODE_TOO_LARGE: Character value in "\\x{...}" sequence is too large. Since 2.16
+ * @G_REGEX_ERROR_INVALID_CONDITION: Invalid condition "(?(0)". Since 2.16
+ * @G_REGEX_ERROR_SINGLE_BYTE_MATCH_IN_LOOKBEHIND: \\C not allowed in lookbehind assertion. Since 2.16
+ * @G_REGEX_ERROR_INFINITE_LOOP: Recursive call could loop indefinitely. Since 2.16
+ * @G_REGEX_ERROR_MISSING_SUBPATTERN_NAME_TERMINATOR: Missing terminator in subpattern name. Since 2.16
+ * @G_REGEX_ERROR_DUPLICATE_SUBPATTERN_NAME: Two named subpatterns have the same name. Since 2.16
+ * @G_REGEX_ERROR_MALFORMED_PROPERTY: Malformed "\\P" or "\\p" sequence. Since 2.16
+ * @G_REGEX_ERROR_UNKNOWN_PROPERTY: Unknown property name after "\\P" or "\\p". Since 2.16
+ * @G_REGEX_ERROR_SUBPATTERN_NAME_TOO_LONG: Subpattern name is too long (maximum 32 characters). Since 2.16
+ * @G_REGEX_ERROR_TOO_MANY_SUBPATTERNS: Too many named subpatterns (maximum 10,000). Since 2.16
+ * @G_REGEX_ERROR_INVALID_OCTAL_VALUE: Octal value is greater than "\\377". Since 2.16
+ * @G_REGEX_ERROR_TOO_MANY_BRANCHES_IN_DEFINE: "DEFINE" group contains more than one branch. Since 2.16
+ * @G_REGEX_ERROR_DEFINE_REPETION: Repeating a "DEFINE" group is not allowed. Since 2.16
+ * @G_REGEX_ERROR_INCONSISTENT_NEWLINE_OPTIONS: Inconsistent newline options. Since 2.16
+ * @G_REGEX_ERROR_MISSING_BACK_REFERENCE: "\\g" is not followed by a braced name or an
+ *  optionally braced non-zero number. Since 2.16
+ * 
+ * Error codes returned by regular expressions functions.
+ * 
+ * Since: 2.14
+ */
 typedef enum
 {
   G_REGEX_ERROR_COMPILE,
@@ -79,12 +129,78 @@
   G_REGEX_ERROR_MISSING_BACK_REFERENCE = 157
 } GRegexError;
 
+/**
+ * G_REGEX_ERROR:
+ * 
+ * Error domain for regular expressions. Errors in this domain will be from the #GRegexError enumeration. See #GError for information on error domains.
+ * 
+ * Since: 2.14
+ */
 #define G_REGEX_ERROR g_regex_error_quark ()
 
 GQuark g_regex_error_quark (void);
 
 /* Remember to update G_REGEX_COMPILE_MASK in gregex.c after
  * adding a new flag. */
+/**
+ * GRegexCompileFlags:
+ * @G_REGEX_CASELESS: Letters in the pattern match both upper and lower case
+ *  letters. It be changed within a pattern by a "(?i)" option setting.
+ * @G_REGEX_MULTILINE: By default, GRegex treats the strings as consisting
+ *  of a single line of characters (even if it actually contains newlines).
+ *  The "start of line" metacharacter ("^") matches only at the start of the
+ *  string, while the "end of line" metacharacter ("$") matches only at the
+ *  end of the string, or before a terminating newline (unless
+ *  #G_REGEX_DOLLAR_ENDONLY is set). When #G_REGEX_MULTILINE is set,
+ *  the "start of line" and "end of line" constructs match immediately following
+ *  or immediately before any newline in the string, respectively, as well
+ *  as at the very start and end. This can be changed within a pattern by a
+ *  "(?m)" option setting.
+ * @G_REGEX_DOTALL: A dot metacharater (".") in the pattern matches all
+ *  characters, including newlines. Without it, newlines are excluded. This
+ *  option can be changed within a pattern by a ("?s") option setting.
+ * @G_REGEX_EXTENDED: Whitespace data characters in the pattern are
+ *  totally ignored except when escaped or inside a character class.
+ *  Whitespace does not include the VT character (code 11). In addition,
+ *  characters between an unescaped "#" outside a character class and
+ *  the next newline character, inclusive, are also ignored. This can be
+ *  changed within a pattern by a "(?x)" option setting.
+ * @G_REGEX_ANCHORED: The pattern is forced to be "anchored", that is,
+ *  it is constrained to match only at the first matching point in the string
+ *  that is being searched. This effect can also be achieved by appropriate
+ *  constructs in the pattern itself such as the "^" metacharater.
+ * @G_REGEX_DOLLAR_ENDONLY: A dollar metacharacter ("$") in the pattern
+ *  matches only at the end of the string. Without this option, a dollar also
+ *  matches immediately before the final character if it is a newline (but
+ *  not before any other newlines). This option is ignored if
+ *  #G_REGEX_MULTILINE is set.
+ * @G_REGEX_UNGREEDY: Inverts the "greediness" of the
+ *  quantifiers so that they are not greedy by default, but become greedy
+ *  if followed by "?". It can also be set by a "(?U)" option setting within
+ *  the pattern.
+ * @G_REGEX_RAW: Usually strings must be valid UTF-8 strings, using this
+ *  flag they are considered as a raw sequence of bytes.
+ * @G_REGEX_NO_AUTO_CAPTURE: Disables the use of numbered capturing
+ *  parentheses in the pattern. Any opening parenthesis that is not followed
+ *  by "?" behaves as if it were followed by "?:" but named parentheses can
+ *  still be used for capturing (and they acquire numbers in the usual way).
+ * @G_REGEX_OPTIMIZE: Optimize the regular expression. If the pattern will
+ *  be used many times, then it may be worth the effort to optimize it to
+ *  improve the speed of matches.
+ * @G_REGEX_DUPNAMES: Names used to identify capturing subpatterns need not
+ *  be unique. This can be helpful for certain types of pattern when it is known
+ *  that only one instance of the named subpattern can ever be matched.
+ * @G_REGEX_NEWLINE_CR: Usually any newline character is recognized, if this
+ *  option is set, the only recognized newline character is '\r'.
+ * @G_REGEX_NEWLINE_LF: Usually any newline character is recognized, if this
+ *  option is set, the only recognized newline character is '\n'.
+ * @G_REGEX_NEWLINE_CRLF: Usually any newline character is recognized, if this
+ *  option is set, the only recognized newline character sequence is '\r\n'.
+ * 
+ * Flags specifying compile-time options.
+ * 
+ * Since: 2.14
+ */
 typedef enum
 {
   G_REGEX_CASELESS          = 1 << 0,
@@ -105,6 +221,45 @@
 
 /* Remember to update G_REGEX_MATCH_MASK in gregex.c after
  * adding a new flag. */
+/**
+ * GRegexMatchFlags:
+ * @G_REGEX_MATCH_ANCHORED: The pattern is forced to be "anchored", that is,
+ *  it is constrained to match only at the first matching point in the string
+ *  that is being searched. This effect can also be achieved by appropriate
+ *  constructs in the pattern itself such as the "^" metacharater.
+ * @G_REGEX_MATCH_NOTBOL: Specifies that first character of the string is
+ *  not the beginning of a line, so the circumflex metacharacter should not
+ *  match before it. Setting this without G_REGEX_MULTILINE (at compile time)
+ *  causes circumflex never to match. This option affects only the behaviour of
+ *  the circumflex metacharacter, it does not affect "\A".
+ * @G_REGEX_MATCH_NOTEOL: Specifies that the end of the subject string is
+ *  not the end of a line, so the dollar metacharacter should not match it nor
+ *  (except in multiline mode) a newline immediately before it. Setting this
+ *  without G_REGEX_MULTILINE (at compile time) causes dollar never to match.
+ *  This option affects only the behaviour of the dollar metacharacter, it does
+ *  not affect "\Z" or "\z".
+ * @G_REGEX_MATCH_NOTEMPTY: An empty string is not considered to be a valid
+ *  match if this option is set. If there are alternatives in the pattern, they
+ *  are tried. If all the alternatives match the empty string, the entire match
+ *  fails. For example, if the pattern "a?b?" is applied to a string not beginning
+ *  with "a" or "b", it matches the empty string at the start of the string.
+ *  With this flag set, this match is not valid, so GRegex searches further
+ *  into the string for occurrences of "a" or "b".
+ * @G_REGEX_MATCH_PARTIAL: Turns on the partial matching feature, for more
+ *  documentation on partial matching see g_regex_is_partial_match().
+ * @G_REGEX_MATCH_NEWLINE_CR: Overrides the newline definition set when creating
+ *  a new #GRegex, setting the '\r' character as line terminator.
+ * @G_REGEX_MATCH_NEWLINE_LF: Overrides the newline definition set when creating
+ *  a new #GRegex, setting the '\n' character as line terminator.
+ * @G_REGEX_MATCH_NEWLINE_CRLF: Overrides the newline definition set when creating
+ *  a new #GRegex, setting the '\r\n' characters as line terminator.
+ * @G_REGEX_MATCH_NEWLINE_ANY: Overrides the newline definition set when creating
+ *  a new #GRegex, any newline character or character sequence is recognized.
+ * 
+ * Flags specifying match-time options.
+ * 
+ * Since: 2.14
+ */
 typedef enum
 {
   G_REGEX_MATCH_ANCHORED      = 1 << 4,
@@ -118,9 +273,44 @@
   G_REGEX_MATCH_NEWLINE_ANY   = 1 << 22
 } GRegexMatchFlags;
 
+
+/**
+ * GRegex:
+ * 
+ * A GRegex is the "compiled" form of a regular expression pattern. This
+ * structure is opaque and its fields cannot be accessed directly.
+ * 
+ * Since: 2.14
+ */
 typedef struct _GRegex		GRegex;
+
+/**
+ * GMatchInfo:
+ * 
+ * #GMatchInfo is used to retrieve information about the regular expression match
+ * which created it.
+ * This structure is opaque and its fields cannot be accessed directly.
+ * 
+ * Since: 2.14
+ */
 typedef struct _GMatchInfo	GMatchInfo;
 
+/**
+ * GRegexEvalCallback:
+ * @match_info: the #GMatchInfo generated by the match. 
+ *  Use g_match_info_get_regex() and g_match_info_get_string() if you 
+ *  need the #GRegex or the matched string.
+ * @result: a #GString containing the new string
+ * @user_data: user data passed to g_regex_replace_eval()
+ * 
+ * Specifies the type of the function passed to g_regex_replace_eval().
+ * It is called for each occurance of the pattern in the string passed
+ * to g_regex_replace_eval(), and it should append the replacement to
+ * @result.
+ * 
+ * Since: 2.14
+ * Returns: %FALSE to continue the replacement process, %TRUE to stop it
+ */
 typedef gboolean (*GRegexEvalCallback)		(const GMatchInfo *match_info,
 						 GString          *result,
 						 gpointer          user_data);
Index: glib/gmem.h
===================================================================
--- glib/gmem.h	(revision 7087)
+++ glib/gmem.h	(working copy)
@@ -36,9 +36,27 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GMemVTable:
+ * @malloc: function to use for allocating memory.
+ * @realloc: function to use for reallocating memory.
+ * @free: function to use to free memory.
+ * @calloc: function to use for allocating zero-filled memory.
+ * @try_malloc: function to use for allocating memory without a default error handler.
+ * @try_realloc: function to use for reallocating memory without a default error handler.
+ * 
+ * A set of functions used to perform memory allocation. The same #GMemVTable must
+ * be used for all allocations in the same program; a call to g_mem_set_vtable(),
+ * if it exists, should be prior to any use of GLib.
+ */
 typedef struct _GMemVTable GMemVTable;
 
-
+/**
+ * G_MEM_ALIGN:
+ * 
+ * Indicates the number of bytes to which memory will be aligned on the
+ * current platform.
+ */
 #if GLIB_SIZEOF_VOID_P > GLIB_SIZEOF_LONG
 #  define G_MEM_ALIGN	GLIB_SIZEOF_VOID_P
 #else	/* GLIB_SIZEOF_VOID_P <= GLIB_SIZEOF_LONG */
@@ -61,17 +79,104 @@
 
 /* Convenience memory allocators
  */
+/**
+ * g_new:
+ * @struct_type: the type of the elements to allocate
+ * @n_structs: the number of elements to allocate
+ * 
+ * Allocates @n_structs elements of type @struct_type.
+ * The returned pointer is cast to a pointer to the given type.
+ * If @n_structs is 0 it returns %NULL.
+ * 
+ * Since the returned pointer is already casted to the right type,
+ * it is normally unnecessary to cast it explicitly, and doing
+ * so might hide memory allocation errors.
+ * 
+ * Returns: a pointer to the allocated memory, cast to a pointer to @struct_type
+ */
 #define g_new(struct_type, n_structs)		\
     ((struct_type *) g_malloc (((gsize) sizeof (struct_type)) * ((gsize) (n_structs))))
+
+/**
+ * g_new0:
+ * @struct_type: the type of the elements to allocate.
+ * @n_structs: the number of elements to allocate.
+ * 
+ * Allocates @n_structs elements of type @struct_type, initialized to 0's.
+ * The returned pointer is cast to a pointer to the given type.
+ * If @n_structs is 0 it returns %NULL.
+ * 
+ * Since the returned pointer is already casted to the right type,
+ * it is normally unnecessary to cast it explicitly, and doing
+ * so might hide memory allocation errors.
+ * 
+ * Returns: a pointer to the allocated memory, cast to a pointer to @struct_type.
+ */
 #define g_new0(struct_type, n_structs)		\
     ((struct_type *) g_malloc0 (((gsize) sizeof (struct_type)) * ((gsize) (n_structs))))
+
+/**
+ * g_renew:
+ * @struct_type: the type of the elements to allocate
+ * @mem: the currently allocated memory
+ * @n_structs: the number of elements to allocate
+ * 
+ * Reallocates the memory pointed to by @mem, so that it now has space for
+ * @n_structs elements of type @struct_type. It returns the new address of 
+ * the memory, which may have been moved.
+ * 
+ * Returns: a pointer to the new allocated memory, cast to a pointer to @struct_type
+ */
 #define g_renew(struct_type, mem, n_structs)	\
     ((struct_type *) g_realloc ((mem), ((gsize) sizeof (struct_type)) * ((gsize) (n_structs))))
-
+    
+/**
+ * g_try_new:
+ * @struct_type: the type of the elements to allocate
+ * @n_structs: the number of elements to allocate
+ * 
+ * Attempts to allocate @n_structs elements of type @struct_type, and returns 
+ * %NULL on failure. Contrast with g_new(), which aborts the program on failure.
+ * The returned pointer is cast to a pointer to the given type. 
+ * If @n_structs is 0 it returns %NULL.
+ * 
+ * Since: 2.8
+ * Returns: a pointer to the allocated memory, cast to a pointer to @struct_type
+ */
 #define g_try_new(struct_type, n_structs)		\
     ((struct_type *) g_try_malloc (((gsize) sizeof (struct_type)) * ((gsize) (n_structs))))
+
+/**
+ * g_try_new0:
+ * @struct_type: the type of the elements to allocate
+ * @n_structs: the number of elements to allocate
+ * 
+ * Attempts to allocate @n_structs elements of type @struct_type, initialized 
+ * to 0's, and returns %NULL on failure. Contrast with g_new0(), which aborts 
+ * the program on failure.
+ * The returned pointer is cast to a pointer to the given type.
+ * The function returns %NULL when @n_structs is 0.
+ * 
+ * Since: 2.8
+ * Returns: a pointer to the allocated memory, cast to a pointer to @struct_type
+ */
 #define g_try_new0(struct_type, n_structs)		\
     ((struct_type *) g_try_malloc0 (((gsize) sizeof (struct_type)) * ((gsize) (n_structs))))
+
+/**
+ * g_try_renew:
+ * @struct_type: the type of the elements to allocate
+ * @mem: the currently allocated memory
+ * @n_structs: the number of elements to allocate
+ * 
+ * Attempts to reallocate the memory pointed to by @mem, so that it now has 
+ * space for @n_structs elements of type @struct_type, and returns %NULL on 
+ * failure. Contrast with g_renew(), which aborts the program on failure.
+ * It returns the new address of the memory, which may have been moved.
+ * 
+ * Since: 2.8
+ * Returns: a pointer to the new allocated memory, cast to a pointer to @struct_type
+ */
 #define g_try_renew(struct_type, mem, n_structs)	\
     ((struct_type *) g_try_realloc ((mem), ((gsize) sizeof (struct_type)) * ((gsize) (n_structs))))
 
@@ -96,9 +201,21 @@
 void	 g_mem_set_vtable (GMemVTable	*vtable);
 gboolean g_mem_is_system_malloc (void);
 
+/**
+ * g_mem_gc_friendly:
+ * 
+ * This variable is %TRUE if the <envar>G_DEBUG</envar> environment variable
+ * includes the key <link linkend="G_DEBUG">gc-friendly</link>.  
+ */
 GLIB_VAR gboolean g_mem_gc_friendly;
 
-/* Memory profiler and checker, has to be enabled via g_mem_set_vtable()
+/**
+ * glib_mem_profiler_table:
+ * 
+ * A #GMemVTable containing profiling variants of the memory
+ * allocation functions. Use them together with g_mem_profile()
+ * in order to get information about the memory allocation pattern
+ * of your program. This must be set by g_mem_set_vtable().
  */
 GLIB_VAR GMemVTable	*glib_mem_profiler_table;
 void	g_mem_profile	(void);
@@ -106,24 +223,113 @@
 
 /* deprecated memchunks and allocators */
 #if !defined (G_DISABLE_DEPRECATED) || defined (GTK_COMPILATION) || defined (GDK_COMPILATION)
+/**
+ * GAllocator:
+ * 
+ * The <structname>GAllocator</structname> struct contains private data. and 
+ * should only be accessed using the following functions.
+ */
 typedef struct _GAllocator GAllocator;
+
+/**
+ * GMemChunk:
+ * 
+ * The #GMemChunk struct is an opaque data structure representing a memory
+ * chunk. It should be accessed only through the use of the following functions.
+ */
 typedef struct _GMemChunk  GMemChunk;
+
+
+/**
+ * g_mem_chunk_create:
+ * @type: the type of the atoms, typically a structure name.
+ * @pre_alloc: the number of atoms to store in each block of memory.
+ * @alloc_type: the type of the #GMemChunk.
+ *  #G_ALLOC_AND_FREE is used if the atoms will be freed individually.
+ *  #G_ALLOC_ONLY should be used if atoms will never be freed individually.
+ *  #G_ALLOC_ONLY is quicker, since it does not need to track free atoms,
+ *  but it obviously wastes memory if you no longer need many of the atoms.
+ * 
+ * A convenience macro for creating a new #GMemChunk.
+ * It calls g_mem_chunk_new(), using the given type to create the #GMemChunk
+ * name. The atom size is determined using <function>sizeof()</function>, and the
+ * area size is calculated by multiplying the @pre_alloc parameter with
+ * the atom size.
+ * 
+ * Deprecated: 2.10: Use the <link linkend="glib-Memory-Slices">slice 
+ *  allocator</link> instead
+ * Returns: the new #GMemChunk.
+ */
 #define g_mem_chunk_create(type, pre_alloc, alloc_type)	( \
   g_mem_chunk_new (#type " mem chunks (" #pre_alloc ")", \
 		   sizeof (type), \
 		   sizeof (type) * (pre_alloc), \
 		   (alloc_type)) \
 )
+
+/**
+ * g_chunk_new:
+ * @type: the type of the #GMemChunk atoms, typically a structure name.
+ * @chunk: a #GMemChunk.
+ * 
+ * A convenience macro to allocate an atom of memory from a #GMemChunk.
+ * It calls g_mem_chunk_alloc() and casts the returned atom to a pointer to
+ * the given type, avoiding a type cast in the source code.
+ * 
+ * Deprecated: 2.10: Use g_slice_new() instead
+ * Returns: a pointer to the allocated atom, cast to a pointer to @type.
+ */
 #define g_chunk_new(type, chunk)	( \
   (type *) g_mem_chunk_alloc (chunk) \
 )
+
+/**
+ * g_chunk_new0:
+ * @type: the type of the #GMemChunk atoms, typically a structure name.
+ * @chunk: a #GMemChunk.
+ * 
+ * A convenience macro to allocate an atom of memory from a #GMemChunk.
+ * It calls g_mem_chunk_alloc0() and casts the returned atom to a pointer to
+ * the given type, avoiding a type cast in the source code.
+ * 
+ * Deprecated: 2.10: Use g_slice_new0() instead
+ * Returns: a pointer to the allocated atom, cast to a pointer to @type.
+ */
 #define g_chunk_new0(type, chunk)	( \
   (type *) g_mem_chunk_alloc0 (chunk) \
 )
+/**
+ * g_chunk_free:
+ * @mem: a pointer to the atom to be freed.
+ * @mem_chunk: a #GMemChunk.
+ * 
+ * A convenience macro to free an atom of memory from a #GMemChunk.
+ * It simply switches the arguments and calls g_mem_chunk_free()
+ * It is included simply to complement the other convenience macros, g_chunk_new()
+ * and g_chunk_new0().
+ * 
+ * Deprecated: 2.10: Use g_slice_free() instead
+ */
 #define g_chunk_free(mem, mem_chunk)	G_STMT_START { \
   g_mem_chunk_free ((mem_chunk), (mem)); \
 } G_STMT_END
+
+/**
+ * G_ALLOC_ONLY:
+ * 
+ * Specifies the type of a #GMemChunk.
+ * Used in g_mem_chunk_new() and g_mem_chunk_create() to specify that atoms
+ * will never be freed individually.
+ */
 #define G_ALLOC_ONLY	  1
+
+/**
+ * G_ALLOC_AND_FREE:
+ * 
+ * Specifies the type of a #GMemChunk.
+ * Used in g_mem_chunk_new() and g_mem_chunk_create() to specify that atoms
+ * will be freed individually.
+ */
 #define G_ALLOC_AND_FREE  2
 GMemChunk* g_mem_chunk_new     (const gchar *name,
 				gint         atom_size,
